@@ -19,7 +19,6 @@ package org.apache.cloudstack.api.command.admin.pod;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiConstants;
@@ -35,7 +34,6 @@ import com.cloud.utils.Pair;
 @APICommand(name = "listPods", description = "Lists all Pods.", responseObject = PodResponse.class,
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class ListPodsByCmd extends BaseListCmd {
-    public static final Logger s_logger = Logger.getLogger(ListPodsByCmd.class.getName());
 
 
     /////////////////////////////////////////////////////
