@@ -20,6 +20,8 @@ import org.apache.cloudstack.vm.UnmanagedInstanceTO;
 
 public class ConvertInstanceAnswer extends Answer {
 
+    private String temporaryConvertUuid;
+
     public ConvertInstanceAnswer() {
         super();
     }
@@ -34,6 +36,15 @@ public class ConvertInstanceAnswer extends Answer {
         this.convertedInstance = convertedInstance;
     }
 
+    public ConvertInstanceAnswer(Command command, String temporaryConvertUuid) {
+        super(command, true, "");
+        this.temporaryConvertUuid = temporaryConvertUuid;
+    }
+
+    public String getTemporaryConvertUuid() {
+        return temporaryConvertUuid;
+    }
+
     public UnmanagedInstanceTO getConvertedInstance() {
         return convertedInstance;
     }
