@@ -20,8 +20,11 @@
 package com.cloud.agent.api.storage;
 
 import com.cloud.agent.api.Command;
+import com.cloud.agent.api.LogLevel;
 import com.cloud.agent.api.to.StorageFilerTO;
 
+import java.util.Arrays;
+
 public class ResizeVolumeCommand extends Command {
     private String path;
     private StorageFilerTO pool;
@@ -35,6 +38,10 @@ public class ResizeVolumeCommand extends Command {
     private boolean managed;
     private String iScsiName;
 
+    @LogLevel(LogLevel.Log4jLevel.Off)
+    private byte[] passphrase;
+    private String encryptFormat;
+
     protected ResizeVolumeCommand() {
     }
 
@@ -48,6 +55,13 @@ public class ResizeVolumeCommand extends Command {
         this.managed = false;
     }
 
+    public ResizeVolumeCommand(String path, StorageFilerTO pool, Long currentSize, Long newSize, boolean shrinkOk, String vmInstance,
+                               String chainInfo, byte[] passphrase, String encryptFormat) {
+        this(path, pool, currentSize, newSize, shrinkOk, vmInstance, chainInfo);
+        this.passphrase = passphrase;
+        this.encryptFormat = encryptFormat;
+    }
+
     public ResizeVolumeCommand(String path, StorageFilerTO pool, Long currentSize, Long newSize, boolean shrinkOk, String vmInstance, String chainInfo) {
         this(path, pool, currentSize, newSize, shrinkOk, vmInstance);
         this.chainInfo = chainInfo;
@@ -89,6 +103,16 @@ public class ResizeVolumeCommand extends Command {
 
     public String getChainInfo() {return chainInfo; }
 
+    public String getEncryptFormat() { return encryptFormat; }
+
+    public byte[] getPassphrase() { return passphrase; }
+
+    public void clearPassphrase() {
+        if (this.passphrase != null) {
+            Arrays.fill(this.passphrase, (byte) 0);
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
