@@ -52,7 +52,8 @@ import org.apache.cloudstack.diagnostics.PrepareFilesCommand;
 import org.apache.cloudstack.utils.security.KeyStoreUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.net.util.SubnetUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.joda.time.Duration;
 
 import com.cloud.agent.api.Answer;
@@ -86,7 +87,7 @@ import com.cloud.utils.exception.CloudRuntimeException;
  **/
 public class VirtualRoutingResource {
 
-    private static final Logger s_logger = Logger.getLogger(VirtualRoutingResource.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private VirtualRouterDeployer _vrDeployer;
     private Map<String, Queue<NetworkElementCommand>> _vrAggregateCommandsSet;
     protected Map<String, Lock> _vrLockMap = new HashMap<String, Lock>();
@@ -118,7 +119,7 @@ public class VirtualRoutingResource {
         try {
             ExecutionResult rc = _vrDeployer.prepareCommand(cmd);
             if (!rc.isSuccess()) {
-                s_logger.error("Failed to prepare VR command due to " + rc.getDetails());
+                logger.error("Failed to prepare VR command due to " + rc.getDetails());
                 return new Answer(cmd, false, rc.getDetails());
             }
 
@@ -169,7 +170,7 @@ public class VirtualRoutingResource {
             if (!aggregated) {
                 ExecutionResult rc = _vrDeployer.cleanupCommand(cmd);
                 if (!rc.isSuccess()) {
-                    s_logger.error("Failed to cleanup VR command due to " + rc.getDetails());
+                    logger.error("Failed to cleanup VR command due to " + rc.getDetails());
                 }
             }
         }
@@ -225,15 +226,15 @@ public class VirtualRoutingResource {
         } else if (cmd instanceof GetRouterMonitorResultsCommand) {
             return execute((GetRouterMonitorResultsCommand)cmd);
         } else {
-            s_logger.error("Unknown query command in VirtualRoutingResource!");
+            logger.error("Unknown query command in VirtualRoutingResource!");
             return Answer.createUnsupportedCommandAnswer(cmd);
         }
     }
 
-    private static String getRouterSshControlIp(NetworkElementCommand cmd) {
+    private String getRouterSshControlIp(NetworkElementCommand cmd) {
         String routerIp = cmd.getAccessDetail(NetworkElementCommand.ROUTER_IP);
-        if (s_logger.isDebugEnabled())
-            s_logger.debug("Use router's private IP for SSH control. IP : " + routerIp);
+        if (logger.isDebugEnabled())
+            logger.debug("Use router's private IP for SSH control. IP : " + routerIp);
         return routerIp;
     }
 
@@ -248,24 +249,24 @@ public class VirtualRoutingResource {
                 String subnet = address.split("/")[1];
                 ExecutionResult result = _vrDeployer.executeInVR(routerIp, VRScripts.VR_UPDATE_INTERFACE_CONFIG,
                         ipAddressTO.getPublicIp() + " " + subnet + " " + ipAddressTO.getMtu() + " " + 15);
-                if (s_logger.isDebugEnabled())
-                    s_logger.debug("result: " + result.isSuccess() + ", output: " + result.getDetails());
+                if (logger.isDebugEnabled())
+                    logger.debug("result: " + result.isSuccess() + ", output: " + result.getDetails());
                 if (!Boolean.TRUE.equals(result.isSuccess())) {
                     if (result.getDetails().contains(String.format("Interface with IP %s not found", ipAddressTO.getPublicIp()))) {
-                        s_logger.warn(String.format("Skipping IP: %s as it isn't configured on router interface", ipAddressTO.getPublicIp()));
+                        logger.warn(String.format("Skipping IP: %s as it isn't configured on router interface", ipAddressTO.getPublicIp()));
                     } else if (ipAddressTO.getDetails().get(ApiConstants.REDUNDANT_STATE).equals(VirtualRouter.RedundantState.PRIMARY.name())) {
-                        s_logger.warn(String.format("Failed to update interface mtu to %s on interface with ip: %s",
+                        logger.warn(String.format("Failed to update interface mtu to %s on interface with ip: %s",
                                 ipAddressTO.getMtu(), ipAddressTO.getPublicIp()));
                         finalResult = false;
                     }
                     continue;
                 }
-                s_logger.info(String.format("Successfully updated mtu to %s on interface with ip: %s",
+                logger.info(String.format("Successfully updated mtu to %s on interface with ip: %s",
                         ipAddressTO.getMtu(), ipAddressTO.getPublicIp()));
                 finalResult &= true;
             } catch (Exception e) {
                 String msg = "Prepare UpdateNetwork failed due to " + e.toString();
-                s_logger.error(msg, e);
+                logger.error(msg, e);
                 return new Answer(cmd, e);
             }
         }
@@ -315,9 +316,9 @@ public class VirtualRoutingResource {
         for (ConfigItem configItem : cfg) {
             long startTimestamp = System.currentTimeMillis();
             ExecutionResult result = applyConfigToVR(cmd.getRouterAccessIp(), configItem, VRScripts.VR_SCRIPT_EXEC_TIMEOUT);
-            if (s_logger.isDebugEnabled()) {
+            if (logger.isDebugEnabled()) {
                 long elapsed = System.currentTimeMillis() - startTimestamp;
-                s_logger.debug("Processing " + configItem + " took " + elapsed + "ms");
+                logger.debug("Processing " + configItem + " took " + elapsed + "ms");
             }
             if (result == null) {
                 result = new ExecutionResult(false, "null execution result");
@@ -329,7 +330,7 @@ public class VirtualRoutingResource {
 
         // Not sure why this matters, but log it anyway
         if (cmd.getAnswersCount() != results.size()) {
-            s_logger.warn("Expected " + cmd.getAnswersCount() + " answers while executing " + cmd.getClass().getSimpleName() + " but received " + results.size());
+            logger.warn("Expected " + cmd.getAnswersCount() + " answers while executing " + cmd.getClass().getSimpleName() + " but received " + results.size());
         }
 
         if (results.size() == 1) {
@@ -378,7 +379,7 @@ public class VirtualRoutingResource {
             } else if (!readingFailedChecks && readingMonitorResults) { // Reading monitor checks result
                 monitorResults.append(line);
             } else {
-                s_logger.error("Unexpected lines reached while parsing health check response. Skipping line:- " + line);
+                logger.error("Unexpected lines reached while parsing health check response. Skipping line:- " + line);
             }
         }
 
@@ -398,16 +399,16 @@ public class VirtualRoutingResource {
         }
 
         String args = cmd.shouldPerformFreshChecks() ? "true" : "false";
-        s_logger.info("Fetching health check result for " + routerIp + " and executing fresh checks: " + args);
+        logger.info("Fetching health check result for " + routerIp + " and executing fresh checks: " + args);
         ExecutionResult result = _vrDeployer.executeInVR(routerIp, VRScripts.ROUTER_MONITOR_RESULTS, args);
 
         if (!result.isSuccess()) {
-            s_logger.warn("Result of " + cmd + " failed with details: " + result.getDetails());
+            logger.warn("Result of " + cmd + " failed with details: " + result.getDetails());
             return new GetRouterMonitorResultsAnswer(cmd, false, null, result.getDetails());
         }
 
         if (result.getDetails().isEmpty()) {
-            s_logger.warn("Result of " + cmd + " received no details.");
+            logger.warn("Result of " + cmd + " received no details.");
             return new GetRouterMonitorResultsAnswer(cmd, false, null, "No results available.");
         }
 
@@ -417,12 +418,12 @@ public class VirtualRoutingResource {
     private Pair<Boolean, String> checkRouterFileSystem(String routerIp) {
         ExecutionResult fileSystemWritableTestResult = _vrDeployer.executeInVR(routerIp, VRScripts.ROUTER_FILESYSTEM_WRITABLE_CHECK, null);
         if (fileSystemWritableTestResult.isSuccess()) {
-            s_logger.debug("Router connectivity and file system writable check passed");
+            logger.debug("Router connectivity and file system writable check passed");
             return new Pair<Boolean, String>(true, "success");
         }
 
         String resultDetails = fileSystemWritableTestResult.getDetails();
-        s_logger.warn("File system writable check failed with details: " + resultDetails);
+        logger.warn("File system writable check failed with details: " + resultDetails);
         if (StringUtils.isNotBlank(resultDetails)) {
             final String readOnlyFileSystemError = "Read-only file system";
             if (resultDetails.contains(readOnlyFileSystemError)) {
@@ -507,8 +508,8 @@ public class VirtualRoutingResource {
         if (params.get("router.aggregation.command.each.timeout") != null) {
             String value = (String)params.get("router.aggregation.command.each.timeout");
             _eachTimeout = Duration.standardSeconds(NumbersUtil.parseLong(value, 600));
-            if (s_logger.isDebugEnabled()){
-                s_logger.debug("The router.aggregation.command.each.timeout in seconds is set to " + _eachTimeout.getStandardSeconds());
+            if (logger.isDebugEnabled()){
+                logger.debug("The router.aggregation.command.each.timeout in seconds is set to " + _eachTimeout.getStandardSeconds());
             }
         }
 
@@ -529,8 +530,8 @@ public class VirtualRoutingResource {
 
         value = (String)params.get("router.aggregation.command.each.timeout");
         _eachTimeout = Duration.standardSeconds(NumbersUtil.parseInt(value, (int)VRScripts.VR_SCRIPT_EXEC_TIMEOUT.getStandardSeconds()));
-        if (s_logger.isDebugEnabled()){
-            s_logger.debug("The router.aggregation.command.each.timeout in seconds is set to " + _eachTimeout.getStandardSeconds());
+        if (logger.isDebugEnabled()){
+            logger.debug("The router.aggregation.command.each.timeout in seconds is set to " + _eachTimeout.getStandardSeconds());
         }
 
         if (_vrDeployer == null) {
@@ -553,8 +554,8 @@ public class VirtualRoutingResource {
         for (int i = 0; i <= retry; i++) {
             SocketChannel sch = null;
             try {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Trying to connect to " + ipAddress);
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Trying to connect to " + ipAddress);
                 }
                 sch = SocketChannel.open();
                 sch.configureBlocking(true);
@@ -563,8 +564,8 @@ public class VirtualRoutingResource {
                 sch.connect(addr);
                 return true;
             } catch (final IOException e) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Could not connect to " + ipAddress);
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Could not connect to " + ipAddress);
                 }
             } finally {
                 if (sch != null) {
@@ -580,7 +581,7 @@ public class VirtualRoutingResource {
             }
         }
 
-        s_logger.debug("Unable to logon to " + ipAddress);
+        logger.debug("Unable to logon to " + ipAddress);
 
         return false;
     }
@@ -590,7 +591,7 @@ public class VirtualRoutingResource {
          * [TODO] Still have to migrate LoadBalancerConfigCommand and BumpUpPriorityCommand
          * [FIXME] Have a look at SetSourceNatConfigItem
          */
-        s_logger.debug("Transforming " + cmd.getClass().getCanonicalName() + " to ConfigItems");
+        logger.debug("Transforming " + cmd.getClass().getCanonicalName() + " to ConfigItems");
 
         final AbstractConfigItemFacade configItemFacade = AbstractConfigItemFacade.getInstance(cmd.getClass());
 
@@ -620,7 +621,7 @@ public class VirtualRoutingResource {
                     answerCounts += command.getAnswersCount();
                     List<ConfigItem> cfg = generateCommandCfg(command);
                     if (cfg == null) {
-                        s_logger.warn("Unknown commands for VirtualRoutingResource, but continue: " + cmd.toString());
+                        logger.warn("Unknown commands for VirtualRoutingResource, but continue: " + cmd.toString());
                         continue;
                     }
 
@@ -635,8 +636,8 @@ public class VirtualRoutingResource {
                 ScriptConfigItem scriptConfigItem = new ScriptConfigItem(VRScripts.VR_CFG, "-c " + VRScripts.CONFIG_CACHE_LOCATION + cfgFileName);
                 // 120s is the minimal timeout
                 Duration timeout = _eachTimeout.withDurationAdded(_eachTimeout.getStandardSeconds(), answerCounts);
-                if (s_logger.isDebugEnabled()){
-                    s_logger.debug("Aggregate action timeout in seconds is " + timeout.getStandardSeconds());
+                if (logger.isDebugEnabled()){
+                    logger.debug("Aggregate action timeout in seconds is " + timeout.getStandardSeconds());
                 }
 
                 ExecutionResult result = applyConfigToVR(cmd.getRouterAccessIp(), fileConfigItem, timeout);
