@@ -26,7 +26,16 @@ public class ConsoleProxyConnectionInfo {
     public String tag;
     public long createTime;
     public long lastUsedTime;
+    protected String sessionUuid;
 
     public ConsoleProxyConnectionInfo() {
     }
+
+    public String getSessionUuid() {
+        return sessionUuid;
+    }
+
+    public void setSessionUuid(String sessionUuid) {
+        this.sessionUuid = sessionUuid;
+    }
 }
