@@ -16,10 +16,14 @@
 // under the License.
 package com.cloud.network.dao;
 
+import java.util.List;
+
 import com.cloud.utils.db.GenericDao;
 
 public interface InlineLoadBalancerNicMapDao extends GenericDao<InlineLoadBalancerNicMapVO, Long> {
     InlineLoadBalancerNicMapVO findByPublicIpAddress(String publicIpAddress);
 
     InlineLoadBalancerNicMapVO findByNicId(long nicId);
+    int expungeByNicList(List<Long> nicIds, Long batchSize);
+
 }
