@@ -18,12 +18,13 @@ package com.cloud.storage.dao;
 
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
+import java.util.ArrayList;
 import java.util.List;
 
 import javax.annotation.PostConstruct;
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
+import org.apache.commons.collections.CollectionUtils;
 import org.springframework.stereotype.Component;
 
 import com.cloud.server.ResourceTag.ResourceObjectType;
@@ -51,7 +52,6 @@ import com.cloud.vm.dao.VMInstanceDao;
 
 @Component
 public class SnapshotDaoImpl extends GenericDaoBase<SnapshotVO, Long> implements SnapshotDao {
-    public static final Logger s_logger = Logger.getLogger(SnapshotDaoImpl.class.getName());
     // TODO: we should remove these direct sqls
     private static final String GET_LAST_SNAPSHOT =
         "SELECT snapshots.id FROM snapshot_store_ref, snapshots where snapshots.id = snapshot_store_ref.snapshot_id AND snapshosts.volume_id = ? AND snapshot_store_ref.role = ? ORDER BY created DESC";
@@ -197,7 +197,7 @@ public class SnapshotDaoImpl extends GenericDaoBase<SnapshotVO, Long> implements
                 return rs.getLong(1);
             }
         } catch (Exception ex) {
-            s_logger.error("error getting last snapshot", ex);
+            logger.error("error getting last snapshot", ex);
         }
         return 0;
     }
@@ -287,4 +287,16 @@ public class SnapshotDaoImpl extends GenericDaoBase<SnapshotVO, Long> implements
         sc.setParameters("status", (Object[]) status);
         return listBy(sc, null);
     }
+
+    @Override
+    public List<SnapshotVO> searchByVolumes(List<Long> volumeIds) {
+        if (CollectionUtils.isEmpty(volumeIds)) {
+            return new ArrayList<>();
+        }
+        SearchBuilder<SnapshotVO> sb = createSearchBuilder();
+        sb.and("volumeIds", sb.entity().getVolumeId(), SearchCriteria.Op.IN);
+        SearchCriteria<SnapshotVO> sc = sb.create();
+        sc.setParameters("volumeIds", volumeIds.toArray());
+        return search(sc, null);
+    }
 }
