@@ -19,6 +19,7 @@ package com.cloud.storage.dao;
 import java.util.List;
 import java.util.Map;
 
+import com.cloud.cpu.CPU;
 import com.cloud.hypervisor.Hypervisor.HypervisorType;
 import com.cloud.storage.Storage;
 import com.cloud.storage.VMTemplateVO;
@@ -67,13 +68,19 @@ public interface VMTemplateDao extends GenericDao<VMTemplateVO, Long>, StateDao<
 
     public List<VMTemplateVO> userIsoSearch(boolean listRemoved);
 
+    List<VMTemplateVO> listAllReadySystemVMTemplates(Long zoneId);
+
     VMTemplateVO findSystemVMTemplate(long zoneId);
 
     VMTemplateVO findSystemVMReadyTemplate(long zoneId, HypervisorType hypervisorType);
 
+    List<VMTemplateVO> findSystemVMReadyTemplates(long zoneId, HypervisorType hypervisorType, String preferredArch);
+
     VMTemplateVO findRoutingTemplate(HypervisorType type, String templateName);
 
-    VMTemplateVO findLatestTemplateByTypeAndHypervisor(HypervisorType hypervisorType, Storage.TemplateType type);
+    List<VMTemplateVO> findRoutingTemplates(HypervisorType type, String templateName, String preferredArch);
+
+    VMTemplateVO findLatestTemplateByTypeAndHypervisorAndArch(HypervisorType hypervisorType, CPU.CPUArch arch, Storage.TemplateType type);
 
     public Long countTemplatesForAccount(long accountId);
 
@@ -85,12 +92,11 @@ public interface VMTemplateDao extends GenericDao<VMTemplateVO, Long>, StateDao<
 
     List<VMTemplateVO> listByParentTemplatetId(long parentTemplatetId);
 
-    VMTemplateVO findLatestTemplateByName(String name);
+    VMTemplateVO findLatestTemplateByName(String name, CPU.CPUArch arch);
 
     List<VMTemplateVO> findTemplatesLinkedToUserdata(long userdataId);
 
     List<VMTemplateVO> listByIds(List<Long> ids);
 
-    List<VMTemplateVO> listByTemplateTag(String tag);
-
+    List<Long> listIdsByTemplateTag(String tag);
 }
