@@ -53,7 +53,7 @@ public interface ResourceDetailsDao<R extends ResourceDetail> extends GenericDao
      * Removes all details for the resource specified
      * @param resourceId
      */
-    public void removeDetails(long resourceId);
+    void removeDetails(long resourceId);
 
 
     /**
@@ -76,7 +76,7 @@ public interface ResourceDetailsDao<R extends ResourceDetail> extends GenericDao
      * @param resourceId
      * @return list of details each implementing ResourceDetail interface
      */
-    public List<R> listDetails(long resourceId);
+    List<R> listDetails(long resourceId);
 
     /**
      * List details for resourceId having display field = forDisplay value passed in
@@ -84,19 +84,23 @@ public interface ResourceDetailsDao<R extends ResourceDetail> extends GenericDao
      * @param forDisplay
      * @return
      */
-    public List<R> listDetails(long resourceId, boolean forDisplay);
+    List<R> listDetails(long resourceId, boolean forDisplay);
 
-    public Map<String, String> listDetailsKeyPairs(long resourceId);
+    Map<String, String> listDetailsKeyPairs(long resourceId);
 
-    public Map<String, String> listDetailsKeyPairs(long resourceId, boolean forDisplay);
+    Map<String, String> listDetailsKeyPairs(long resourceId, List<String> keys);
+
+    Map<String, String> listDetailsKeyPairs(long resourceId, boolean forDisplay);
 
     Map<String, Boolean> listDetailsVisibility(long resourceId);
 
-    public void saveDetails(List<R> details);
+    void saveDetails(List<R> details);
 
-    public void addDetail(long resourceId, String key, String value, boolean display);
+    void addDetail(long resourceId, String key, String value, boolean display);
 
-    public List<Long> findResourceIdsByNameAndValueIn(String name, Object[] values);
+    List<Long> findResourceIdsByNameAndValueIn(String name, Object[] values);
 
-    public long batchExpungeForResources(List<Long> ids, Long batchSize);
+    long batchExpungeForResources(List<Long> ids, Long batchSize);
+
+    String getActualValue(ResourceDetail resourceDetail);
 }
