@@ -26,6 +26,7 @@ import java.util.Map;
 import javax.inject.Inject;
 import javax.naming.ConfigurationException;
 
+import com.cloud.storage.StoragePool;
 import org.apache.cloudstack.engine.subsystem.api.storage.StrategyPriority;
 import org.apache.cloudstack.engine.subsystem.api.storage.VMSnapshotStrategy;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
@@ -162,8 +163,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
             Map<String, String> srcVolumeDestSnapshotMap = new HashMap<>();
             List<VolumeObjectTO> volumeTOs = vmSnapshotHelper.getVolumeTOList(userVm.getId());
 
-            final Long storagePoolId = vmSnapshotHelper.getStoragePoolForVM(userVm.getId());
-            StoragePoolVO storagePool = storagePoolDao.findById(storagePoolId);
+            StoragePoolVO storagePool = vmSnapshotHelper.getStoragePoolForVM(userVm);
             long prev_chain_size = 0;
             long virtual_size=0;
             for (VolumeObjectTO volume : volumeTOs) {
@@ -188,7 +188,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
                 vmSnapshotVO.setParent(current.getId());
 
             try {
-                final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+                final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
                 SnapshotGroup snapshotGroup = client.takeSnapshot(srcVolumeDestSnapshotMap);
                 if (snapshotGroup == null) {
                     throw new CloudRuntimeException("Failed to take VM snapshot on PowerFlex storage pool");
@@ -291,7 +291,8 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
         boolean result = false;
         try {
             List<VolumeObjectTO> volumeTOs = vmSnapshotHelper.getVolumeTOList(userVm.getId());
-            Long storagePoolId = vmSnapshotHelper.getStoragePoolForVM(userVm.getId());
+            StoragePoolVO storagePool = vmSnapshotHelper.getStoragePoolForVM(userVm);
+            Long storagePoolId = storagePool.getId();
             Map<String, String> srcSnapshotDestVolumeMap = new HashMap<>();
             for (VolumeObjectTO volume : volumeTOs) {
                 VMSnapshotDetailsVO vmSnapshotDetail = vmSnapshotDetailsDao.findDetail(vmSnapshotVO.getId(), "Vol_" + volume.getId() + "_Snapshot");
@@ -305,7 +306,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
                 throw new CloudRuntimeException("Failed to get the system id for PowerFlex storage pool for reverting VM snapshot: " + vmSnapshot.getName());
             }
 
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             result = client.revertSnapshot(systemId, srcSnapshotDestVolumeMap);
             if (!result) {
                 throw new CloudRuntimeException("Failed to revert VM snapshot on PowerFlex storage pool");
@@ -314,7 +315,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
             finalizeRevert(vmSnapshotVO, volumeTOs);
             result = true;
         } catch (Exception e) {
-            String errMsg = "Revert VM: " + userVm.getInstanceName() + " to snapshot: " + vmSnapshotVO.getName() + " failed due to " + e.getMessage();
+            String errMsg = String.format("Revert VM: %s to snapshot: %s failed due to %s", userVm, vmSnapshotVO, e.getMessage());
             logger.error(errMsg, e);
             throw new CloudRuntimeException(errMsg);
         } finally {
@@ -378,8 +379,8 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
 
         try {
             List<VolumeObjectTO> volumeTOs = vmSnapshotHelper.getVolumeTOList(vmSnapshot.getVmId());
-            Long storagePoolId = vmSnapshotHelper.getStoragePoolForVM(userVm.getId());
-            String systemId = storagePoolDetailsDao.findDetail(storagePoolId, ScaleIOGatewayClient.STORAGE_POOL_SYSTEM_ID).getValue();
+            StoragePoolVO storagePool = vmSnapshotHelper.getStoragePoolForVM(userVm);
+            String systemId = storagePoolDetailsDao.findDetail(storagePool.getId(), ScaleIOGatewayClient.STORAGE_POOL_SYSTEM_ID).getValue();
             if (systemId == null) {
                 throw new CloudRuntimeException("Failed to get the system id for PowerFlex storage pool for deleting VM snapshot: " + vmSnapshot.getName());
             }
@@ -390,7 +391,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
             }
 
             String snapshotGroupId = vmSnapshotDetailsVO.getValue();
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             int volumesDeleted = client.deleteSnapshotGroup(systemId, snapshotGroupId);
             if (volumesDeleted <= 0) {
                 throw new CloudRuntimeException("Failed to delete VM snapshot: " + vmSnapshot.getName());
@@ -509,7 +510,7 @@ public class ScaleIOVMSnapshotStrategy extends ManagerBase implements VMSnapshot
         }
     }
 
-    private ScaleIOGatewayClient getScaleIOClient(final Long storagePoolId) throws Exception {
-        return ScaleIOGatewayClientConnectionPool.getInstance().getClient(storagePoolId, storagePoolDetailsDao);
+    private ScaleIOGatewayClient getScaleIOClient(final StoragePool storagePool) throws Exception {
+        return ScaleIOGatewayClientConnectionPool.getInstance().getClient(storagePool, storagePoolDetailsDao);
     }
 }
