@@ -55,6 +55,7 @@ public class RemoteHostEndPoint implements EndPoint {
     protected Logger logger = LogManager.getLogger(getClass());
 
     private long hostId;
+    private String hostUuid;
     private String hostAddress;
     private String publicAddress;
 
@@ -74,6 +75,7 @@ public class RemoteHostEndPoint implements EndPoint {
 
     private void configure(Host host) {
         hostId = host.getId();
+        hostUuid = host.getUuid();
         hostAddress = host.getPrivateIpAddress();
         publicAddress = host.getPublicIpAddress();
         if (Host.Type.SecondaryStorageVM == host.getType()) {
@@ -106,6 +108,11 @@ public class RemoteHostEndPoint implements EndPoint {
         return hostId;
     }
 
+    @Override
+    public String getUuid() {
+        return hostUuid;
+    }
+
     // used when HypervisorGuruManager choose a different host to send command
     private void setId(long id) {
         HostVO host = _hostDao.findById(id);
