@@ -18,10 +18,13 @@
  */
 package org.apache.cloudstack.spring.lifecycle;
 
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.springframework.context.SmartLifecycle;
 
 public abstract class AbstractSmartLifeCycle implements SmartLifecycle {
 
+    protected Logger logger = LogManager.getLogger(getClass());
     boolean running = false;
 
     @Override
