@@ -50,6 +50,7 @@ import com.cloud.dc.VmwareDatacenter;
 import com.cloud.hypervisor.vmware.VmwareDatacenterZoneMap;
 import com.cloud.dc.dao.VmwareDatacenterDao;
 import com.cloud.hypervisor.vmware.dao.VmwareDatacenterZoneMapDao;
+import com.cloud.storage.dao.VolumeDao;
 import com.cloud.user.User;
 import com.cloud.utils.Pair;
 import com.cloud.utils.component.AdapterBase;
@@ -109,6 +110,8 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     private AgentManager agentMgr;
     @Inject
     private VirtualMachineManager virtualMachineManager;
+    @Inject
+    private VolumeDao volumeDao;
 
     protected VeeamClient getClient(final Long zoneId) {
         try {
@@ -173,7 +176,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         final String clonedJobName = getGuestBackupName(vm.getInstanceName(), vm.getUuid());
 
         if (!client.cloneVeeamJob(parentJob, clonedJobName)) {
-            logger.error("Failed to clone pre-defined Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " but will check the list of jobs again if it was eventually succeeded.");
+            logger.error("Failed to clone pre-defined Veeam job (backup offering) for backup offering [id: {}, name: {}] but will check the list of jobs again if it was eventually succeeded.", backupOffering.getExternalId(), backupOffering.getName());
         }
 
         for (final BackupOffering job : client.listJobs()) {
@@ -182,7 +185,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
                 if (BooleanUtils.isTrue(clonedJob.getScheduleConfigured()) && !clonedJob.getScheduleEnabled()) {
                     client.toggleJobSchedule(clonedJob.getId());
                 }
-                logger.debug("Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " found, now trying to assign the VM to the job.");
+                logger.debug("Veeam job (backup offering) for backup offering [id: {}, name: {}] found, now trying to assign the VM to the job.", backupOffering.getExternalId(), backupOffering.getName());
                 final VmwareDatacenter vmwareDC = findVmwareDatacenterForVM(vm);
                 if (client.addVMToVeeamJob(job.getExternalId(), vm.getInstanceName(), vmwareDC.getVcenterHost())) {
                     ((VMInstanceVO) vm).setBackupExternalId(job.getExternalId());
@@ -197,6 +200,9 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public boolean removeVMFromBackupOffering(final VirtualMachine vm) {
         final VeeamClient client = getClient(vm.getDataCenterId());
         final VmwareDatacenter vmwareDC = findVmwareDatacenterForVM(vm);
+        if (vm.getBackupExternalId() == null) {
+            throw new CloudRuntimeException("The VM does not have a backup job assigned.");
+        }
         try {
             if (!client.removeVMFromVeeamJob(vm.getBackupExternalId(), vm.getInstanceName(), vmwareDC.getVcenterHost())) {
                 logger.warn("Failed to remove VM from Veeam Job id: " + vm.getBackupExternalId());
@@ -229,7 +235,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public boolean deleteBackup(Backup backup, boolean forced) {
         VMInstanceVO vm = vmInstanceDao.findByIdIncludingRemoved(backup.getVmId());
         if (vm == null) {
-            throw new CloudRuntimeException(String.format("Could not find any VM associated with the Backup [uuid: %s, externalId: %s].", backup.getUuid(), backup.getExternalId()));
+            throw new CloudRuntimeException(String.format("Could not find any VM associated with the Backup [uuid: %s, name: %s, externalId: %s].", backup.getUuid(), backup.getName(), backup.getExternalId()));
         }
         if (!forced) {
             logger.debug(String.format("Veeam backup provider does not have a safe way to remove a single restore point, which results in all backup chain being removed. "
@@ -315,8 +321,8 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
             }
 
             Metric metric = backendMetrics.get(vm.getUuid());
-            logger.debug(String.format("Metrics for VM [uuid: %s, name: %s] is [backup size: %s, data size: %s].", vm.getUuid(),
-                    vm.getInstanceName(), metric.getBackupSize(), metric.getDataSize()));
+            logger.debug("Metrics for VM [{}] is [backup size: {}, data size: {}].", vm,
+                    metric.getBackupSize(), metric.getDataSize());
             metrics.put(vm, metric);
         }
         return metrics;
@@ -331,8 +337,8 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         for (final Backup backup : backupsInDb) {
             if (restorePoint.getId().equals(backup.getExternalId())) {
                 if (metric != null) {
-                    logger.debug(String.format("Update backup with [uuid: %s, external id: %s] from [size: %s, protected size: %s] to [size: %s, protected size: %s].",
-                            backup.getUuid(), backup.getExternalId(), backup.getSize(), backup.getProtectedSize(), metric.getBackupSize(), metric.getDataSize()));
+                    logger.debug("Update backup with [id: {}, uuid: {}, name: {}, external id: {}] from [size: {}, protected size: {}] to [size: {}, protected size: {}].",
+                            backup.getId(), backup.getUuid(), backup.getName(), backup.getExternalId(), backup.getSize(), backup.getProtectedSize(), metric.getBackupSize(), metric.getDataSize());
 
                     ((BackupVO) backup).setSize(metric.getBackupSize());
                     ((BackupVO) backup).setProtectedSize(metric.getDataSize());
@@ -348,7 +354,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public void syncBackups(VirtualMachine vm, Backup.Metric metric) {
         List<Backup.RestorePoint> restorePoints = listRestorePoints(vm);
         if (CollectionUtils.isEmpty(restorePoints)) {
-            logger.debug(String.format("Can't find any restore point to VM: [uuid: %s, name: %s].", vm.getUuid(), vm.getInstanceName()));
+            logger.debug("Can't find any restore point to VM: {}", vm);
             return;
         }
         Transaction.execute(new TransactionCallbackNoReturn() {
@@ -378,10 +384,10 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
                         backup.setAccountId(vm.getAccountId());
                         backup.setDomainId(vm.getDomainId());
                         backup.setZoneId(vm.getDataCenterId());
+                        backup.setBackedUpVolumes(BackupManagerImpl.createVolumeInfoFromVolumes(volumeDao.findByInstance(vm.getId())));
 
-                        logger.debug(String.format("Creating a new entry in backups: [uuid: %s, vm_id: %s, external_id: %s, type: %s, date: %s, backup_offering_id: %s, account_id: %s, "
-                                        + "domain_id: %s, zone_id: %s].", backup.getUuid(), backup.getVmId(), backup.getExternalId(), backup.getType(), backup.getDate(),
-                                backup.getBackupOfferingId(), backup.getAccountId(), backup.getDomainId(), backup.getZoneId()));
+                        logger.debug("Creating a new entry in backups: [id: {}, uuid: {}, name: {}, vm_id: {}, external_id: {}, type: {}, date: {}, backup_offering_id: {}, account_id: {}, "
+                                + "domain_id: {}, zone_id: {}].", backup.getId(), backup.getUuid(), backup.getName(), backup.getVmId(), backup.getExternalId(), backup.getType(), backup.getDate(), backup.getBackupOfferingId(), backup.getAccountId(), backup.getDomainId(), backup.getZoneId());
                         backupDao.persist(backup);
 
                         ActionEventUtils.onCompletedActionEvent(User.UID_SYSTEM, vm.getAccountId(), EventVO.LEVEL_INFO, EventTypes.EVENT_VM_BACKUP_CREATE,
