@@ -19,7 +19,6 @@ package com.cloud.api.commands;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiConstants;
@@ -42,7 +41,6 @@ import com.cloud.user.Account;
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class EnableCiscoNexusVSMCmd extends BaseAsyncCmd {
 
-    public static final Logger s_logger = Logger.getLogger(EnableCiscoNexusVSMCmd.class.getName());
     @Inject
     CiscoNexusVSMElementService _ciscoNexusVSMService;
 
