@@ -17,7 +17,6 @@
 package com.cloud.hypervisor.xenserver.resource;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 import org.apache.xmlrpc.XmlRpcException;
 
 import com.xensource.xenapi.Connection;
@@ -29,7 +28,6 @@ import static com.cloud.utils.NumbersUtil.toHumanReadableSize;
 
 public class XcpServerResource extends CitrixResourceBase {
 
-    private final static Logger s_logger = Logger.getLogger(XcpServerResource.class);
     private final static long mem_32m = 33554432L;
 
     @Override
@@ -89,8 +87,8 @@ public class XcpServerResource extends CitrixResourceBase {
     @Override
     protected void setMemory(final Connection conn, final VM vm, final long minMemsize, final long maxMemsize) throws XmlRpcException, XenAPIException {
         //setMemoryLimits(staticMin, staticMax, dynamicMin, dynamicMax)
-        if (s_logger.isDebugEnabled()) {
-           s_logger.debug("Memory Limits for VM [" + vm.getNameLabel(conn) + "[staticMin:" + toHumanReadableSize(mem_32m) + ", staticMax:" + toHumanReadableSize(maxMemsize) + ", dynamicMin: " + toHumanReadableSize(minMemsize) +
+        if (logger.isDebugEnabled()) {
+           logger.debug("Memory Limits for VM [" + vm.getNameLabel(conn) + "[staticMin:" + toHumanReadableSize(mem_32m) + ", staticMax:" + toHumanReadableSize(maxMemsize) + ", dynamicMin: " + toHumanReadableSize(minMemsize) +
                     ", dynamicMax:" + toHumanReadableSize(maxMemsize) + "]]");
         }
         vm.setMemoryLimits(conn, mem_32m, maxMemsize, minMemsize, maxMemsize);
