@@ -21,7 +21,6 @@ package com.cloud.hypervisor.xenserver.resource.wrapper.xenbase;
 
 import java.util.Set;
 
-import org.apache.log4j.Logger;
 import org.apache.xmlrpc.XmlRpcException;
 
 import com.cloud.agent.api.Answer;
@@ -37,7 +36,6 @@ import com.xensource.xenapi.Types.XenAPIException;
 @ResourceWrapper(handles =  GetStorageStatsCommand.class)
 public final class CitrixGetStorageStatsCommandWrapper extends CommandWrapper<GetStorageStatsCommand, Answer, CitrixResourceBase> {
 
-    private static final Logger s_logger = Logger.getLogger(CitrixGetStorageStatsCommandWrapper.class);
 
     @Override
     public Answer execute(final GetStorageStatsCommand command, final CitrixResourceBase citrixResourceBase) {
@@ -46,7 +44,7 @@ public final class CitrixGetStorageStatsCommandWrapper extends CommandWrapper<Ge
             final Set<SR> srs = SR.getByNameLabel(conn, command.getStorageId());
             if (srs.size() != 1) {
                 final String msg = "There are " + srs.size() + " storageid: " + command.getStorageId();
-                s_logger.warn(msg);
+                logger.warn(msg);
                 return new GetStorageStatsAnswer(command, msg);
             }
             final SR sr = srs.iterator().next();
@@ -56,15 +54,15 @@ public final class CitrixGetStorageStatsCommandWrapper extends CommandWrapper<Ge
             return new GetStorageStatsAnswer(command, capacity, used);
         } catch (final XenAPIException e) {
             final String msg = "GetStorageStats Exception:" + e.toString() + "host:" + citrixResourceBase.getHost().getUuid() + "storageid: " + command.getStorageId();
-            s_logger.warn(msg);
+            logger.warn(msg);
             return new GetStorageStatsAnswer(command, msg);
         } catch (final XmlRpcException e) {
             final String msg = "GetStorageStats Exception:" + e.getMessage() + "host:" + citrixResourceBase.getHost().getUuid() + "storageid: " + command.getStorageId();
-            s_logger.warn(msg);
+            logger.warn(msg);
             return new GetStorageStatsAnswer(command, msg);
         }  catch (final Exception e) {
             final String msg = "GetStorageStats Exception:" + e.getMessage() + "host:" + citrixResourceBase.getHost().getUuid() + "storageid: " + command.getStorageId();
-            s_logger.warn(msg);
+            logger.warn(msg);
             return new GetStorageStatsAnswer(command, msg);
         }
     }
