@@ -23,10 +23,8 @@ import java.io.FileWriter;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Objects;
-import java.util.Set;
 import java.util.stream.Collectors;
 
 import javax.inject.Inject;
@@ -206,14 +204,12 @@ public class KubernetesClusterActionWorker {
 
     protected String getControlNodeLoginUser() {
         List<KubernetesClusterVmMapVO> vmMapVOList = getKubernetesClusterVMMaps();
-        if (vmMapVOList.size() > 0) {
+        if (!vmMapVOList.isEmpty()) {
             long vmId = vmMapVOList.get(0).getVmId();
             UserVmVO userVM = userVmDao.findById(vmId);
             if (userVM == null) {
                 throw new CloudRuntimeException("Failed to find login user, Unable to log in to node to fetch details");
             }
-            Set<String> vm = new HashSet<>();
-            vm.add(userVM.getName());
             UserVmDetailVO vmDetail = userVmDetailsDao.findDetail(vmId, VmDetailConstants.CKS_CONTROL_NODE_LOGIN_USER);
             if (vmDetail != null && !org.apache.commons.lang3.StringUtils.isEmpty(vmDetail.getValue())) {
                 return vmDetail.getValue();
@@ -309,7 +305,7 @@ public class KubernetesClusterActionWorker {
     }
 
     protected KubernetesClusterVmMapVO addKubernetesClusterVm(final long kubernetesClusterId, final long vmId, boolean isControlNode) {
-        return Transaction.execute(new TransactionCallback<KubernetesClusterVmMapVO>() {
+        return Transaction.execute(new TransactionCallback<>() {
             @Override
             public KubernetesClusterVmMapVO doInTransaction(TransactionStatus status) {
                 KubernetesClusterVmMapVO newClusterVmMap = new KubernetesClusterVmMapVO(kubernetesClusterId, vmId, isControlNode);
@@ -361,7 +357,12 @@ public class KubernetesClusterActionWorker {
         }
         IpAddress address = ipAddressDao.findByUuid(detailsVO.getValue());
         if (address == null || !Objects.equals(network.getVpcId(), address.getVpcId())) {
-            logger.warn(String.format("Public IP with ID: %s linked to the Kubernetes cluster: %s is not usable", detailsVO.getValue(), kubernetesCluster.getName()));
+            logger.warn("Public IP with ID: {} linked to the Kubernetes cluster: {} is not usable", detailsVO.getValue(), kubernetesCluster.getName());
+            if (address == null) {
+                logger.warn("Public IP with ID: {} was not found by uuid", detailsVO.getValue());
+            } else {
+                logger.warn("Public IP with ID: {} was associated with vpc {} instead of {}", detailsVO.getValue(), address.getVpcId(), network.getVpcId());
+            }
             return null;
         }
         return address;
@@ -480,7 +481,7 @@ public class KubernetesClusterActionWorker {
             try {
                 templateService.attachIso(iso.getId(), vm.getId(), true);
                 if (logger.isInfoEnabled()) {
-                    logger.info(String.format("Attached binaries ISO for VM : %s in cluster: %s", vm.getDisplayName(), kubernetesCluster.getName()));
+                    logger.info("Attached binaries ISO for VM: {} in cluster: {}", vm, kubernetesCluster);
                 }
             } catch (CloudRuntimeException ex) {
                 logTransitStateAndThrow(Level.ERROR, String.format("Failed to attach binaries ISO for VM : %s in the Kubernetes cluster name: %s", vm.getDisplayName(), kubernetesCluster.getName()), kubernetesCluster.getId(), failedEvent, ex);
@@ -502,23 +503,22 @@ public class KubernetesClusterActionWorker {
             try {
                 result = templateService.detachIso(vm.getId(), true);
             } catch (CloudRuntimeException ex) {
-                logger.warn(String.format("Failed to detach binaries ISO from VM : %s in the Kubernetes cluster : %s ", vm.getDisplayName(), kubernetesCluster.getName()), ex);
+                logger.warn("Failed to detach binaries ISO from VM: {} in the Kubernetes cluster: {} ", vm, kubernetesCluster, ex);
             } finally {
                 CallContext.unregister();
             }
             if (result) {
                 if (logger.isInfoEnabled()) {
-                    logger.info(String.format("Detached Kubernetes binaries from VM : %s in the Kubernetes cluster : %s", vm.getDisplayName(), kubernetesCluster.getName()));
+                    logger.info("Detached Kubernetes binaries from VM: {} in the Kubernetes cluster: {}", vm, kubernetesCluster);
                 }
                 continue;
             }
-            logger.warn(String.format("Failed to detach binaries ISO from VM : %s in the Kubernetes cluster : %s ", vm.getDisplayName(), kubernetesCluster.getName()));
+            logger.warn("Failed to detach binaries ISO from VM: {} in the Kubernetes cluster: {} ", vm, kubernetesCluster);
         }
     }
 
     protected List<KubernetesClusterVmMapVO> getKubernetesClusterVMMaps() {
-        List<KubernetesClusterVmMapVO> clusterVMs = kubernetesClusterVmMapDao.listByClusterId(kubernetesCluster.getId());
-        return clusterVMs;
+        return kubernetesClusterVmMapDao.listByClusterId(kubernetesCluster.getId());
     }
 
     protected List<KubernetesClusterVmMapVO> getKubernetesClusterVMMapsForNodes(List<Long> nodeIds) {
