@@ -76,8 +76,8 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                 || kubernetesCluster.getState().equals(KubernetesCluster.State.Alert)
                 || kubernetesCluster.getState().equals(KubernetesCluster.State.Error)
                 || kubernetesCluster.getState().equals(KubernetesCluster.State.Destroying))) {
-            String msg = String.format("Cannot perform delete operation on cluster : %s in state: %s",
-                kubernetesCluster.getName(), kubernetesCluster.getState());
+            String msg = String.format("Cannot perform delete operation on cluster %s in state: %s",
+                    kubernetesCluster, kubernetesCluster.getState());
             logger.warn(msg);
             throw new PermissionDeniedException(msg);
         }
@@ -100,15 +100,16 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                 try {
                     UserVm vm = userVmService.destroyVm(vmID, true);
                     if (!userVmManager.expunge(userVM)) {
-                        logger.warn(String.format("Unable to expunge VM %s : %s, destroying Kubernetes cluster will probably fail",
-                            vm.getInstanceName() , vm.getUuid()));
+                        logger.warn("Unable to expunge VM {}, destroying Kubernetes cluster will probably fail", vm);
                     }
                     kubernetesClusterVmMapDao.expunge(clusterVM.getId());
                     if (logger.isInfoEnabled()) {
-                        logger.info(String.format("Destroyed VM : %s as part of Kubernetes cluster : %s cleanup", vm.getDisplayName(), kubernetesCluster.getName()));
+                        logger.info("Destroyed VM {} as part of Kubernetes cluster : {} cleanup", vm, kubernetesCluster);
                     }
                 } catch (ResourceUnavailableException | ConcurrentOperationException e) {
-                    logger.warn(String.format("Failed to destroy VM : %s part of the Kubernetes cluster : %s cleanup. Moving on with destroying remaining resources provisioned for the Kubernetes cluster", userVM.getDisplayName(), kubernetesCluster.getName()), e);
+                    logger.warn("Failed to destroy VM {} part of the Kubernetes cluster {} " +
+                            "cleanup. Moving on with destroying remaining resources provisioned " +
+                            "for the Kubernetes cluster", userVM, kubernetesCluster, e);
                     return false;
                 } finally {
                     CallContext.unregister();
@@ -132,13 +133,12 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
             ReservationContext context = new ReservationContextImpl(null, null, callerUser, owner);
             boolean networkDestroyed = networkMgr.destroyNetwork(kubernetesCluster.getNetworkId(), context, true);
             if (!networkDestroyed) {
-                String msg = String.format("Failed to destroy network : %s as part of Kubernetes cluster : %s cleanup", network.getName(), kubernetesCluster.getName());
+                String msg = String.format("Failed to destroy network: %s as part of Kubernetes cluster: %s cleanup", network, kubernetesCluster);
                 logger.warn(msg);
                 throw new ManagementServerException(msg);
             }
             if (logger.isInfoEnabled()) {
-                logger.info(String.format("Destroyed network : %s as part of Kubernetes cluster : %s cleanup",
-                    network.getName(), kubernetesCluster.getName()));
+                logger.info("Destroyed network: {} as part of Kubernetes cluster: {} cleanup", network, kubernetesCluster);
             }
         }
     }
@@ -245,6 +245,10 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
         init();
         validateClusterSate();
         this.clusterVMs = kubernetesClusterVmMapDao.listByClusterId(kubernetesCluster.getId());
+        List<VMInstanceVO> vms = this.clusterVMs.stream().map(vmMap -> vmInstanceDao.findById(vmMap.getVmId())).collect(Collectors.toList());
+        if (KubernetesClusterManagerImpl.checkIfVmsAssociatedWithBackupOffering(vms)) {
+            throw new CloudRuntimeException("Unable to delete Kubernetes cluster, as node(s) are associated to a backup offering");
+        }
         boolean cleanupNetwork = true;
         final KubernetesClusterDetailsVO clusterDetails = kubernetesClusterDetailsDao.findDetail(kubernetesCluster.getId(), "networkCleanup");
         if (clusterDetails != null) {
@@ -270,11 +274,11 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                     }
                 }
             } else {
-                logger.error(String.format("Failed to find network for Kubernetes cluster : %s", kubernetesCluster.getName()));
+                logger.error("Failed to find network for Kubernetes cluster : {}", kubernetesCluster);
             }
         }
         if (logger.isInfoEnabled()) {
-            logger.info(String.format("Destroying Kubernetes cluster : %s", kubernetesCluster.getName()));
+            logger.info("Destroying Kubernetes cluster : {}", kubernetesCluster);
         }
         stateTransitTo(kubernetesCluster.getId(), KubernetesCluster.Event.DestroyRequested);
         boolean vmsDestroyed = destroyClusterVMs();
@@ -285,7 +289,7 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                 try {
                     destroyKubernetesClusterNetwork();
                 } catch (ManagementServerException e) {
-                    String msg = String.format("Failed to destroy network of Kubernetes cluster : %s cleanup", kubernetesCluster.getName());
+                    String msg = String.format("Failed to destroy network of Kubernetes cluster: %s cleanup", kubernetesCluster);
                     logger.warn(msg, e);
                     updateKubernetesClusterEntryForGC();
                     throw new CloudRuntimeException(msg, e);
@@ -294,7 +298,7 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                 try {
                     checkForRulesToDelete();
                 } catch (ManagementServerException e) {
-                    String msg = String.format("Failed to remove network rules of Kubernetes cluster : %s", kubernetesCluster.getName());
+                    String msg = String.format("Failed to remove network rules of Kubernetes cluster: %s", kubernetesCluster);
                     logger.warn(msg, e);
                     updateKubernetesClusterEntryForGC();
                     throw new CloudRuntimeException(msg, e);
@@ -302,14 +306,14 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
                 try {
                     releaseVpcTierPublicIpIfNeeded();
                 } catch (InsufficientAddressCapacityException e) {
-                    String msg = String.format("Failed to release public IP for VPC tier used by Kubernetes cluster : %s", kubernetesCluster.getName());
+                    String msg = String.format("Failed to release public IP for VPC tier used by Kubernetes cluster: %s", kubernetesCluster);
                     logger.warn(msg, e);
                     updateKubernetesClusterEntryForGC();
                     throw new CloudRuntimeException(msg, e);
                 }
             }
         } else {
-            String msg = String.format("Failed to destroy one or more VMs as part of Kubernetes cluster : %s cleanup", kubernetesCluster.getName());
+            String msg = String.format("Failed to destroy one or more VMs as part of Kubernetes cluster: %s cleanup", kubernetesCluster);
             logger.warn(msg);
             updateKubernetesClusterEntryForGC();
             throw new CloudRuntimeException(msg);
@@ -319,12 +323,12 @@ public class KubernetesClusterDestroyWorker extends KubernetesClusterResourceMod
         kubernetesClusterDetailsDao.removeDetails(kubernetesCluster.getId());
         boolean deleted = kubernetesClusterDao.remove(kubernetesCluster.getId());
         if (!deleted) {
-            logMessage(Level.WARN, String.format("Failed to delete Kubernetes cluster : %s", kubernetesCluster.getName()), null);
+            logMessage(Level.WARN, String.format("Failed to delete Kubernetes cluster: %s", kubernetesCluster), null);
             updateKubernetesClusterEntryForGC();
             return false;
         }
         if (logger.isInfoEnabled()) {
-            logger.info(String.format("Kubernetes cluster : %s is successfully deleted", kubernetesCluster.getName()));
+            logger.info("Kubernetes cluster: {} is successfully deleted", kubernetesCluster);
         }
         return true;
     }
