@@ -17,7 +17,6 @@ package com.cloud.api.commands;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.ApiConstants;
@@ -43,7 +42,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
         requestHasSensitiveInfo = true, responseHasSensitiveInfo = false)
 public class RegisterNetscalerControlCenterCmd extends BaseAsyncCmd {
 
-    public static final Logger s_logger = Logger.getLogger(RegisterNetscalerControlCenterCmd.class.getName());
     @Inject
     NetscalerLoadBalancerElementService _netsclarLbService;
 
@@ -78,9 +76,6 @@ public class RegisterNetscalerControlCenterCmd extends BaseAsyncCmd {
     }
 
 
-    public static Logger getsLogger() {
-        return s_logger;
-    }
 
     public NetscalerLoadBalancerElementService get_netsclarLbService() {
         return _netsclarLbService;
