@@ -114,22 +114,19 @@ StaticNatServiceProvider, IpDeployer {
     }
 
     protected boolean canHandle(final Network network, final Service service) {
-        logger.debug("Checking if OvsElement can handle service "
-                + service.getName() + " on network " + network.getDisplayText());
+        logger.debug(String.format("Checking if OvsElement can handle service %s on network %s", service.getName(), network));
         if (network.getBroadcastDomainType() != BroadcastDomainType.Vswitch) {
             return false;
         }
 
         if (!_networkModel.isProviderForNetwork(getProvider(), network.getId())) {
-            logger.debug("OvsElement is not a provider for network "
-                    + network.getDisplayText());
+            logger.debug(String.format("OvsElement is not a provider for network %s", network));
             return false;
         }
 
         if (!_ntwkSrvcDao.canProviderSupportServiceInNetwork(network.getId(),
                 service, Network.Provider.Ovs)) {
-            logger.debug("OvsElement can't provide the " + service.getName()
-                    + " service on network " + network.getDisplayText());
+            logger.debug(String.format("OvsElement can't provide the %s service on network %s", service.getName(), network));
             return false;
         }
 
@@ -149,9 +146,7 @@ StaticNatServiceProvider, IpDeployer {
             final DeployDestination dest, final ReservationContext context)
                     throws ConcurrentOperationException, ResourceUnavailableException,
                     InsufficientCapacityException {
-        logger.debug("entering OvsElement implement function for network "
-                + network.getDisplayText() + " (state " + network.getState()
-                + ")");
+        logger.debug(String.format("entering OvsElement implement function for network %s (state %s)", network, network.getState()));
 
         if (!canHandle(network, Service.Connectivity)) {
             return false;
@@ -437,9 +432,8 @@ StaticNatServiceProvider, IpDeployer {
             final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(
                     network.getId(), Role.VIRTUAL_ROUTER);
             if (routers == null || routers.isEmpty()) {
-                logger.debug("Virtual router element doesn't need to associate ip addresses on the backend; virtual "
-                        + "router doesn't exist in the network "
-                        + network.getId());
+                logger.debug(String.format("Virtual router element doesn't need to associate ip" +
+                        " addresses on the backend; virtual router doesn't exist in the network %s", network));
                 return true;
             }
 
@@ -462,8 +456,8 @@ StaticNatServiceProvider, IpDeployer {
         final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(
                 network.getId(), Role.VIRTUAL_ROUTER);
         if (routers == null || routers.isEmpty()) {
-            logger.debug("Ovs element doesn't need to apply static nat on the backend; virtual "
-                    + "router doesn't exist in the network " + network.getId());
+            logger.debug(String.format("Ovs element doesn't need to apply static nat on the " +
+                    "backend; virtual router doesn't exist in the network %s", network));
             return true;
         }
 
@@ -485,8 +479,8 @@ StaticNatServiceProvider, IpDeployer {
         final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(
                 network.getId(), Role.VIRTUAL_ROUTER);
         if (routers == null || routers.isEmpty()) {
-            logger.debug("Ovs element doesn't need to apply firewall rules on the backend; virtual "
-                    + "router doesn't exist in the network " + network.getId());
+            logger.debug(String.format("Ovs element doesn't need to apply firewall rules on the" +
+                    " backend; virtual router doesn't exist in the network %s", network));
             return true;
         }
 
@@ -511,9 +505,8 @@ StaticNatServiceProvider, IpDeployer {
             final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(
                     network.getId(), Role.VIRTUAL_ROUTER);
             if (routers == null || routers.isEmpty()) {
-                logger.debug("Virtual router elemnt doesn't need to apply load balancing rules on the backend; virtual "
-                        + "router doesn't exist in the network "
-                        + network.getId());
+                logger.debug(String.format("Virtual router element doesn't need to apply load " +
+                        "balancing rules on the backend; virtual router doesn't exist in the network %s", network));
                 return true;
             }
 
@@ -523,7 +516,7 @@ StaticNatServiceProvider, IpDeployer {
             for (final DomainRouterVO domainRouterVO : routers) {
                 result = result && networkTopology.applyLoadBalancingRules(network, rules, domainRouterVO);
                 if (!result) {
-                    logger.debug("Failed to apply load balancing rules in network " + network.getId());
+                    logger.debug(String.format("Failed to apply load balancing rules in network %s", network));
                 }
             }
         }
@@ -603,18 +596,13 @@ StaticNatServiceProvider, IpDeployer {
                 }
                 if (expire != null
                         && !containsOnlyNumbers(expire, timeEndChar)) {
-                    throw new InvalidParameterValueException(
-                            "Failed LB in validation rule id: " + rule.getId()
-                            + " Cause: expire is not in timeformat: "
-                            + expire);
+                    throw new InvalidParameterValueException(String.format("Failed LB in validation rule id: %s Cause: expire is not in time format: %s",
+                            rule.getUuid(), expire));
                 }
                 if (tablesize != null
                         && !containsOnlyNumbers(tablesize, "kmg")) {
-                    throw new InvalidParameterValueException(
-                            "Failed LB in validation rule id: "
-                                    + rule.getId()
-                                    + " Cause: tablesize is not in size format: "
-                                    + tablesize);
+                    throw new InvalidParameterValueException(String.format("Failed LB in validation rule id: %s Cause: table size is not in size format: %s",
+                            rule.getUuid(), tablesize));
 
                 }
             } else if (StickinessMethodType.AppCookieBased.getName()
@@ -634,18 +622,14 @@ StaticNatServiceProvider, IpDeployer {
                 }
 
                 if (length != null && !containsOnlyNumbers(length, null)) {
-                    throw new InvalidParameterValueException(
-                            "Failed LB in validation rule id: " + rule.getId()
-                            + " Cause: length is not a number: "
-                            + length);
+                    throw new InvalidParameterValueException(String.format("Failed LB in validation rule id: %s Cause: length is not a number: %s",
+                            rule.getUuid(), length));
                 }
                 if (holdTime != null
                         && !containsOnlyNumbers(holdTime, timeEndChar) && !containsOnlyNumbers(
                                 holdTime, null)) {
-                    throw new InvalidParameterValueException(
-                            "Failed LB in validation rule id: " + rule.getId()
-                            + " Cause: holdtime is not in timeformat: "
-                            + holdTime);
+                    throw new InvalidParameterValueException(String.format("Failed LB in validation rule id: %s Cause: holdtime is not in time format: %s",
+                            rule.getUuid(), holdTime));
                 }
             }
         }
