@@ -151,8 +151,12 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         sdcManager = new ScaleIOSDCManagerImpl();
     }
 
-    public ScaleIOGatewayClient getScaleIOClient(final Long storagePoolId) throws Exception {
-        return ScaleIOGatewayClientConnectionPool.getInstance().getClient(storagePoolId, storagePoolDetailsDao);
+    ScaleIOGatewayClient getScaleIOClient(final StoragePool storagePool) throws Exception {
+        return ScaleIOGatewayClientConnectionPool.getInstance().getClient(storagePool, storagePoolDetailsDao);
+    }
+
+    ScaleIOGatewayClient getScaleIOClient(final DataStore dataStore) throws Exception {
+        return ScaleIOGatewayClientConnectionPool.getInstance().getClient(dataStore, storagePoolDetailsDao);
     }
 
     private boolean setVolumeLimitsOnSDC(VolumeVO volume, Host host, DataStore dataStore, Long iopsLimit, Long bandwidthLimitInKbps) throws Exception {
@@ -160,10 +164,10 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         final String sdcId = sdcManager.prepareSDC(host, dataStore);
         if (StringUtils.isBlank(sdcId)) {
             alertHostSdcDisconnection(host);
-            throw new CloudRuntimeException("Unable to grant access to volume: " + volume.getId() + ", no Sdc connected with host ip: " + host.getPrivateIpAddress());
+            throw new CloudRuntimeException("Unable to grant access to volume: " + volume + ", no Sdc connected with host ip: " + host.getPrivateIpAddress());
         }
 
-        final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
+        final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
         return client.mapVolumeToSdcWithLimits(ScaleIOUtil.getVolumePath(volume.getPath()), sdcId, iopsLimit, bandwidthLimitInKbps);
     }
 
@@ -197,22 +201,25 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             final String sdcId = sdcManager.prepareSDC(host, dataStore);
             if (StringUtils.isBlank(sdcId)) {
                 alertHostSdcDisconnection(host);
-                throw new CloudRuntimeException(String.format("Unable to grant access to %s: %s, no Sdc connected with host ip: %s", dataObject.getType(), dataObject.getId(), host.getPrivateIpAddress()));
+                throw new CloudRuntimeException(String.format(
+                        "Unable to grant access to %s: [id: %d, uuid: %s], no Sdc connected with host ip: %s",
+                        dataObject.getType(), dataObject.getId(),
+                        dataObject.getUuid(), host.getPrivateIpAddress()));
             }
 
             if (DataObjectType.VOLUME.equals(dataObject.getType())) {
                 final VolumeVO volume = volumeDao.findById(dataObject.getId());
-                logger.debug("Granting access for PowerFlex volume: " + volume.getPath());
+                logger.debug("Granting access for PowerFlex volume: {} at path {}", volume, volume.getPath());
                 return setVolumeLimitsFromDetails(volume, host, dataStore);
             } else if (DataObjectType.TEMPLATE.equals(dataObject.getType())) {
                 final VMTemplateStoragePoolVO templatePoolRef = vmTemplatePoolDao.findByPoolTemplate(dataStore.getId(), dataObject.getId(), null);
-                logger.debug("Granting access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
-                final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
+                logger.debug("Granting access for PowerFlex template volume: {}", templatePoolRef.getInstallPath());
+                final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
                 return client.mapVolumeToSdc(ScaleIOUtil.getVolumePath(templatePoolRef.getInstallPath()), sdcId);
             } else if (DataObjectType.SNAPSHOT.equals(dataObject.getType())) {
                 SnapshotInfo snapshot = (SnapshotInfo) dataObject;
-                logger.debug("Granting access for PowerFlex volume snapshot: " + snapshot.getPath());
-                final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
+                logger.debug("Granting access for PowerFlex volume snapshot: {} at path {}", snapshot, snapshot.getPath());
+                final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
                 return client.mapVolumeToSdc(ScaleIOUtil.getVolumePath(snapshot.getPath()), sdcId);
             }
 
@@ -235,23 +242,26 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         }
 
         try {
-            final String sdcId = getConnectedSdc(dataStore.getId(), host.getId());
+            final String sdcId = getConnectedSdc(dataStore, host);
             if (StringUtils.isBlank(sdcId)) {
-                logger.warn(String.format("Unable to revoke access for %s: %s, no Sdc connected with host ip: %s", dataObject.getType(), dataObject.getId(), host.getPrivateIpAddress()));
+                logger.warn("Unable to revoke access for {}: [id: {}, uuid: {}], " +
+                        "no Sdc connected with host [id: {}, uuid: {}, ip: {}]",
+                        dataObject.getType(), dataObject.getId(), dataObject.getUuid(),
+                        host.getId(), host.getUuid(), host.getPrivateIpAddress());
                 return;
             }
-            final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
             if (DataObjectType.VOLUME.equals(dataObject.getType())) {
                 final VolumeVO volume = volumeDao.findById(dataObject.getId());
-                logger.debug("Revoking access for PowerFlex volume: " + volume.getPath());
+                logger.debug("Revoking access for PowerFlex volume: {} at path {}", volume, volume.getPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(volume.getPath()), sdcId);
             } else if (DataObjectType.TEMPLATE.equals(dataObject.getType())) {
                 final VMTemplateStoragePoolVO templatePoolRef = vmTemplatePoolDao.findByPoolTemplate(dataStore.getId(), dataObject.getId(), null);
-                logger.debug("Revoking access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
+                logger.debug("Revoking access for PowerFlex template volume: {}", templatePoolRef.getInstallPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(templatePoolRef.getInstallPath()), sdcId);
             } else if (DataObjectType.SNAPSHOT.equals(dataObject.getType())) {
                 SnapshotInfo snapshot = (SnapshotInfo) dataObject;
-                logger.debug("Revoking access for PowerFlex volume snapshot: " + snapshot.getPath());
+                logger.debug("Revoking access for PowerFlex volume snapshot: {} at path {}", snapshot, snapshot.getPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(snapshot.getPath()), sdcId);
             }
             if (client.listVolumesMappedToSdc(sdcId).isEmpty()) {
@@ -272,13 +282,15 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         try {
             logger.debug("Revoking access for PowerFlex volume: " + volumePath);
 
-            final String sdcId = getConnectedSdc(dataStore.getId(), host.getId());
+            final String sdcId = getConnectedSdc(dataStore, host);
             if (StringUtils.isBlank(sdcId)) {
-                logger.warn(String.format("Unable to revoke access for volume: %s, no Sdc connected with host ip: %s", volumePath, host.getPrivateIpAddress()));
+                logger.warn("Unable to revoke access for volume: {}, " +
+                        "no Sdc connected with host [id: {}, uuid: {}, ip: {}]",
+                        volumePath, host.getId(), host.getUuid(), host.getPrivateIpAddress());
                 return;
             }
 
-            final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
             client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(volumePath), sdcId);
             if (client.listVolumesMappedToSdc(sdcId).isEmpty()) {
                 sdcManager = ComponentContext.inject(sdcManager);
@@ -294,19 +306,20 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         revokeAccess(dataObject, host, dataStore);
     }
 
-    public String getConnectedSdc(long poolId, long hostId) {
+    public String getConnectedSdc(DataStore dataStore, Host host) {
         try {
-            StoragePoolHostVO poolHostVO = storagePoolHostDao.findByPoolHost(poolId, hostId);
+            StoragePoolHostVO poolHostVO = storagePoolHostDao.findByPoolHost(dataStore.getId(), host.getId());
             if (poolHostVO == null) {
                 return null;
             }
 
-            final ScaleIOGatewayClient client = getScaleIOClient(poolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(dataStore);
             if (client.isSdcConnected(poolHostVO.getLocalPath())) {
                 return poolHostVO.getLocalPath();
             }
         } catch (Exception e) {
-            logger.warn("Couldn't check SDC connection for the host: " + hostId + " and storage pool: " + poolId + " due to " + e.getMessage(), e);
+            logger.warn(String.format("Couldn't check SDC connection for the host: %s and " +
+                    "storage pool: %s due to %s", host, dataStore, e.getMessage()), e);
         }
 
         return null;
@@ -424,7 +437,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         try {
             SnapshotObjectTO snapshotObjectTo = (SnapshotObjectTO)snapshotInfo.getTO();
 
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             final String scaleIOVolumeId = ScaleIOUtil.getVolumePath(volumeVO.getPath());
             String snapshotName = String.format("%s-%s-%s-%s", ScaleIOUtil.SNAPSHOT_PREFIX, snapshotInfo.getId(),
                     storagePool.getUuid().split("-")[0].substring(4), ManagementServerImpl.customCsIdentifier.value());
@@ -441,8 +454,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             result = new CreateCmdResult(null, createObjectAnswer);
             result.setResult(null);
         } catch (Exception e) {
-            String errMsg = "Unable to take PowerFlex volume snapshot for volume: " + volumeInfo.getId() + " due to " + e.getMessage();
-            logger.warn(errMsg);
+            logger.warn("Unable to take PowerFlex volume snapshot for volume: {} due to {}", volumeInfo, e.getMessage());
             result = new CreateCmdResult(null, new CreateObjectAnswer(e.toString()));
             result.setResult(e.toString());
         }
@@ -470,8 +482,8 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 return;
             }
 
-            long storagePoolId = volumeVO.getPoolId();
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            StoragePoolVO storagePool = storagePoolDao.findById(volumeVO.getPoolId());
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             String snapshotVolumeId = ScaleIOUtil.getVolumePath(snapshot.getPath());
             final String destVolumeId = ScaleIOUtil.getVolumePath(volumeVO.getPath());
             client.revertSnapshot(snapshotVolumeId, destVolumeId);
@@ -479,7 +491,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             CommandResult commandResult = new CommandResult();
             callback.complete(commandResult);
         } catch (Exception ex) {
-            logger.debug("Unable to revert to PowerFlex snapshot: " + snapshot.getId(), ex);
+            logger.debug(String.format("Unable to revert to PowerFlex snapshot: %s", snapshot), ex);
             throw new CloudRuntimeException(ex.getMessage());
         }
     }
@@ -498,7 +510,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Preconditions.checkArgument(storagePool != null && storagePool.getHostAddress() != null, "storagePool and host address should not be null");
 
         try {
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             final String scaleIOStoragePoolId = storagePool.getPath();
             final Long sizeInBytes = volumeInfo.getSize();
             final long sizeInGb = (long) Math.ceil(sizeInBytes / (1024.0 * 1024.0 * 1024.0));
@@ -534,7 +546,8 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
             // if volume needs to be set up with encryption, do it now if it's not a root disk (which gets done during template copy)
             if (anyVolumeRequiresEncryption(volumeInfo) && (!volumeInfo.getVolumeType().equals(Volume.Type.ROOT) || migrationInvolved)) {
-                logger.debug(String.format("Setting up encryption for volume %s", volumeInfo.getId()));
+                logger.debug("Setting up encryption for volume [id: {}, uuid: {}, name: {}]",
+                        volumeInfo.getId(), volumeInfo.getUuid(), volumeInfo.getName());
                 VolumeObjectTO prepVolume = (VolumeObjectTO) createdObject.getTO();
                 prepVolume.setPath(volumePath);
                 prepVolume.setUuid(volumePath);
@@ -558,7 +571,8 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                     }
                 }
             } else {
-                 logger.debug(String.format("No encryption configured for data volume %s", volumeInfo));
+                 logger.debug("No encryption configured for data volume [id: {}, uuid: {}, name: {}]",
+                         volumeInfo.getId(), volumeInfo.getUuid(), volumeInfo.getName());
             }
 
             return answer;
@@ -578,7 +592,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Preconditions.checkArgument(storagePool != null && storagePool.getHostAddress() != null, "storagePool and host address should not be null");
 
         try {
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             final String scaleIOStoragePoolId = storagePool.getPath();
             final Long sizeInBytes = templateInfo.getSize();
             final long sizeInGb = (long) Math.ceil(sizeInBytes / (1024.0 * 1024.0 * 1024.0));
@@ -679,7 +693,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
             try {
                 String scaleIOVolumeId = ScaleIOUtil.getVolumePath(scaleIOVolumePath);
-                final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+                final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
                 deleteResult =  client.deleteVolume(scaleIOVolumeId);
                 if (!deleteResult) {
                     errMsg = "Failed to delete PowerFlex volume with id: " + scaleIOVolumeId;
@@ -773,26 +787,26 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
          * Data stores of file type happen automatically, but block device types have to handle it. Unfortunately for ScaleIO this means we add a whole 8GB to
          * the original size, but only if we are close to an 8GB boundary.
          */
-        logger.debug(String.format("Copying template %s to volume %s", srcData.getId(), destData.getId()));
+        logger.debug("Copying template {} to volume {}", srcData, destData);
         VolumeInfo destInfo = (VolumeInfo) destData;
         boolean encryptionRequired = anyVolumeRequiresEncryption(destData);
         if (encryptionRequired) {
             if (needsExpansionForEncryptionHeader(srcData.getSize(), destData.getSize())) {
                 long newSize = destData.getSize() + (1<<30);
-                logger.debug(String.format("Destination volume %s(%s) is configured for encryption. Resizing to fit headers, new size %s will be rounded up to nearest 8Gi", destInfo.getId(), destData.getSize(), newSize));
+                logger.debug("Destination volume {} ({}) is configured for encryption. Resizing to fit headers, new size {} will be rounded up to nearest 8Gi", destInfo, destData.getSize(), newSize);
                 ResizeVolumePayload p = new ResizeVolumePayload(newSize, destInfo.getMinIops(), destInfo.getMaxIops(),
                     destInfo.getHypervisorSnapshotReserve(), false, destInfo.getAttachedVmName(), null, true);
                 destInfo.addPayload(p);
                 resizeVolume(destInfo);
             } else {
-                logger.debug(String.format("Template %s has size %s, ok for volume %s with size %s", srcData.getId(), srcData.getSize(), destData.getId(), destData.getSize()));
+                logger.debug("Template {} has size {}, ok for volume {} with size {}", srcData, srcData.getSize(), destData, destData.getSize());
             }
         } else {
-            logger.debug(String.format("Destination volume is not configured for encryption, skipping encryption prep. Volume: %s", destData.getId()));
+            logger.debug("Destination volume is not configured for encryption, skipping encryption prep. Volume: {}", destData);
         }
 
         // Copy PowerFlex/ScaleIO template to volume
-        logger.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
+        logger.debug("Initiating copy from PowerFlex template volume on host {}", destHost != null ? destHost : "<not specified>");
         int primaryStorageDownloadWait = StorageManager.PRIMARY_STORAGE_DOWNLOAD_WAIT.value();
         CopyCommand cmd = new CopyCommand(srcData.getTO(), destData.getTO(), primaryStorageDownloadWait, VirtualMachineManager.ExecuteInSequence.value());
 
@@ -819,7 +833,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
     protected Answer copyOfflineVolume(DataObject srcData, DataObject destData, Host destHost) {
         // Copy PowerFlex/ScaleIO volume
-        logger.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
+        logger.debug("Initiating copy from PowerFlex template volume on host {}", destHost != null ? destHost : "<not specified>");
         String value = configDao.getValue(Config.CopyVolumeWait.key());
         int copyVolumeWait = NumbersUtil.parseInt(value, Integer.parseInt(Config.CopyVolumeWait.getDefaultValue()));
 
@@ -861,7 +875,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             GetVolumeStatCommand statCmd = new GetVolumeStatCommand(srcVolumeInfo.getPath(), srcVolumeInfo.getStoragePoolType(), srcStore.getUuid());
             GetVolumeStatAnswer statAnswer = (GetVolumeStatAnswer) ep.sendMessage(statCmd);
             if (!statAnswer.getResult() ) {
-                logger.warn(String.format("Unable to get volume %s stats", srcVolumeInfo.getId()));
+                logger.warn(String.format("Unable to get volume %s stats", srcVolumeInfo));
             } else if (statAnswer.getVirtualSize() > 0) {
                 srcVolumeUsableSize = statAnswer.getVirtualSize();
             }
@@ -882,15 +896,15 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 updateVolumeAfterCopyVolume(srcData, destData);
                 updateSnapshotsAfterCopyVolume(srcData, destData);
                 deleteSourceVolumeAfterSuccessfulBlockCopy(srcData, host);
-                logger.debug(String.format("Successfully migrated migrate PowerFlex volume %d to storage pool %d", srcVolumeId,  destPoolId));
+                logger.debug("Successfully migrated migrate PowerFlex volume {} to storage pool {}", srcData,  destStore);
                 answer = new Answer(null, true, null);
             } else {
-                String errorMsg = "Failed to migrate PowerFlex volume: " + srcVolumeId + " to storage pool " + destPoolId;
+                String errorMsg = String.format("Failed to migrate PowerFlex volume: %s to storage pool %s", srcData, destStore);
                 logger.debug(errorMsg);
                 answer = new Answer(null, false, errorMsg);
             }
         } catch (Exception e) {
-            logger.error("Failed to migrate PowerFlex volume: " + srcVolumeId + " due to: " + e.getMessage());
+            logger.error("Failed to migrate PowerFlex volume: {} due to: {}", srcData, e.getMessage());
             answer = new Answer(null, false, e.getMessage());
         }
 
@@ -941,8 +955,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
     public void updateSnapshotsAfterCopyVolume(DataObject srcData, DataObject destData) throws Exception {
         final long srcVolumeId = srcData.getId();
         DataStore srcStore = srcData.getDataStore();
-        final long srcPoolId = srcStore.getId();
-        final ScaleIOGatewayClient client = getScaleIOClient(srcPoolId);
+        final ScaleIOGatewayClient client = getScaleIOClient(srcStore);
 
         DataStore destStore = destData.getDataStore();
         final long destPoolId = destStore.getId();
@@ -951,7 +964,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         List<SnapshotVO> snapshots = snapshotDao.listByVolumeId(srcVolumeId);
         if (CollectionUtils.isNotEmpty(snapshots)) {
             for (SnapshotVO snapshot : snapshots) {
-                SnapshotDataStoreVO snapshotStore = snapshotDataStoreDao.findByStoreSnapshot(DataStoreRole.Primary, srcPoolId, snapshot.getId());
+                SnapshotDataStoreVO snapshotStore = snapshotDataStoreDao.findByStoreSnapshot(DataStoreRole.Primary, srcStore.getId(), snapshot.getId());
                 if (snapshotStore == null) {
                     continue;
                 }
@@ -979,7 +992,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         String errMsg;
         try {
             String scaleIOVolumeId = ScaleIOUtil.getVolumePath(srcVolumePath);
-            final ScaleIOGatewayClient client = getScaleIOClient(srcStore.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(srcStore);
             Boolean deleteResult =  client.deleteVolume(scaleIOVolumeId);
             if (!deleteResult) {
                 errMsg = "Failed to delete source PowerFlex volume with id: " + scaleIOVolumeId;
@@ -1000,7 +1013,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         String errMsg;
         try {
             String scaleIOVolumeId = ScaleIOUtil.getVolumePath(destVolumePath);
-            final ScaleIOGatewayClient client = getScaleIOClient(destStore.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(destStore);
             Boolean deleteResult =  client.deleteVolume(scaleIOVolumeId);
             if (!deleteResult) {
                 errMsg = "Failed to delete PowerFlex volume with id: " + scaleIOVolumeId;
@@ -1079,7 +1092,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             long srcPoolId = srcStore.getId();
             long destPoolId = destStore.getId();
 
-            final ScaleIOGatewayClient client = getScaleIOClient(srcPoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(srcStore);
             final String srcVolumePath = ((VolumeInfo) srcData).getPath();
             final String srcVolumeId = ScaleIOUtil.getVolumePath(srcVolumePath);
             final StoragePoolVO destStoragePool = storagePoolDao.findById(destPoolId);
@@ -1144,12 +1157,12 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
                 answer = new Answer(null, true, null);
             } else {
-                String errorMsg = "Failed to migrate PowerFlex volume: " + srcData.getId() + " to storage pool " + destPoolId;
+                String errorMsg = String.format("Failed to migrate PowerFlex volume: %s to storage pool %d", srcData, destPoolId);
                 logger.debug(errorMsg);
                 answer = new Answer(null, false, errorMsg);
             }
         } catch (Exception e) {
-            logger.error("Failed to migrate PowerFlex volume: " + srcData.getId() + " due to: " + e.getMessage());
+            logger.error("Failed to migrate PowerFlex volume: {} due to: {}", srcData, e.getMessage());
             answer = new Answer(null, false, e.getMessage());
         }
 
@@ -1206,7 +1219,8 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         try {
             String scaleIOVolumeId = ScaleIOUtil.getVolumePath(volumeInfo.getPath());
             Long storagePoolId = volumeInfo.getPoolId();
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePoolId);
+            StoragePoolVO storagePool = storagePoolDao.findById(storagePoolId);
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
 
             ResizeVolumePayload payload = (ResizeVolumePayload)volumeInfo.getpayload();
             long newSizeInBytes = payload.newSize != null ? payload.newSize : volumeInfo.getSize();
@@ -1228,7 +1242,6 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 }
             }
 
-            StoragePoolVO storagePool = storagePoolDao.findById(storagePoolId);
             boolean attachedRunning = false;
             long hostId = 0;
 
@@ -1315,7 +1328,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             storagePool.setUsedBytes(Math.min(usedBytes, capacityBytes));
             storagePoolDao.update(storagePoolId, storagePool);
         } catch (Exception e) {
-            String errMsg = "Unable to resize PowerFlex volume: " + volumeInfo.getId() + " due to " + e.getMessage();
+            String errMsg = "Unable to resize PowerFlex volume: " + volumeInfo + " due to " + e.getMessage();
             logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
@@ -1377,12 +1390,11 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Map<String, String> customStats = new HashMap<>();
 
         try {
-            final ScaleIOGatewayClient client = getScaleIOClient(pool.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(pool);
             int connectedSdcsCount = client.getConnectedSdcsCount();
             customStats.put(ScaleIOUtil.CONNECTED_SDC_COUNT_STAT, String.valueOf(connectedSdcsCount));
         } catch (Exception e) {
-            String errMsg = "Unable to get custom storage stats for the pool: " + pool.getId() + " due to " + e.getMessage();
-            logger.error(errMsg);
+            logger.error("Unable to get custom storage stats for the pool: {} due to {}", pool, e.getMessage());
         }
 
         return customStats;
@@ -1393,7 +1405,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Preconditions.checkArgument(storagePool != null, "storagePool cannot be null");
 
         try {
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePool.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             StoragePoolStatistics poolStatistics = client.getStoragePoolStatistics(storagePool.getPath());
             if (poolStatistics != null && poolStatistics.getNetMaxCapacityInBytes() != null && poolStatistics.getNetUsedCapacityInBytes() != null) {
                 Long capacityBytes = poolStatistics.getNetMaxCapacityInBytes();
@@ -1401,7 +1413,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 return new Pair<Long, Long>(capacityBytes, usedBytes);
             }
         } catch (Exception e) {
-            String errMsg = "Unable to get storage stats for the pool: " + storagePool.getId() + " due to " + e.getMessage();
+            String errMsg = "Unable to get storage stats for the pool: " + storagePool + " due to " + e.getMessage();
             logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
@@ -1420,7 +1432,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Preconditions.checkArgument(StringUtils.isNotEmpty(volumePath), "volumePath cannot be null");
 
         try {
-            final ScaleIOGatewayClient client = getScaleIOClient(storagePool.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(storagePool);
             VolumeStatistics volumeStatistics = client.getVolumeStatistics(ScaleIOUtil.getVolumePath(volumePath));
             if (volumeStatistics != null) {
                 Long provisionedSizeInBytes = volumeStatistics.getNetProvisionedAddressesInBytes();
@@ -1428,7 +1440,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 return new Pair<Long, Long>(provisionedSizeInBytes, allocatedSizeInBytes);
             }
         }  catch (Exception e) {
-            String errMsg = "Unable to get stats for the volume: " + volumePath + " in the pool: " + storagePool.getId() + " due to " + e.getMessage();
+            String errMsg = "Unable to get stats for the volume: " + volumePath + " in the pool: " + storagePool + " due to " + e.getMessage();
             logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
@@ -1447,10 +1459,10 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             if (poolHostVO == null) {
                 return false;
             }
-            final ScaleIOGatewayClient client = getScaleIOClient(pool.getId());
+            final ScaleIOGatewayClient client = getScaleIOClient(pool);
             return client.isSdcConnected(poolHostVO.getLocalPath());
         } catch (Exception e) {
-            logger.warn("Unable to check the host: " + host.getId() + " access to storage pool: " + pool.getId() + " due to " + e.getMessage(), e);
+            logger.warn("Unable to check the host: {} access to storage pool: {} due to {}", host, pool, e.getMessage(), e);
             return false;
         }
     }
@@ -1470,8 +1482,8 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             return;
         }
 
-        logger.warn("SDC not connected on the host: " + host.getId());
-        String msg = "SDC not connected on the host: " + host.getId() + ", reconnect the SDC to MDM";
+        logger.warn("SDC not connected on the host: {}", host);
+        String msg = String.format("SDC not connected on the host: %s, reconnect the SDC to MDM", host);
         alertMgr.sendAlert(AlertManager.AlertType.ALERT_TYPE_HOST, host.getDataCenterId(), host.getPodId(), "SDC disconnected on host: " + host.getUuid(), msg);
     }
 
