@@ -38,7 +38,6 @@ import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
 import org.apache.cloudstack.storage.datastore.util.StorPoolUtil;
 import org.apache.cloudstack.storage.snapshot.StorPoolConfigurationManager;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
 import org.apache.commons.lang3.StringUtils;
 
 import com.cloud.storage.DataStoreRole;
@@ -57,8 +56,6 @@ import com.google.gson.JsonObject;
 
 public class StorPoolStatsCollector extends ManagerBase {
 
-    private static Logger log = Logger.getLogger(StorPoolStatsCollector.class);
-
     @Inject
     private PrimaryDataStoreDao storagePoolDao;
     @Inject
@@ -116,19 +113,19 @@ public class StorPoolStatsCollector extends ManagerBase {
             if (CollectionUtils.isNotEmpty(spPools)) {
                 volumesStats.clear();
 
-                log.debug("Collecting StorPool volumes used space");
+                logger.debug("Collecting StorPool volumes used space");
                 Map<Long, StoragePoolVO> onePoolforZone = new HashMap<>();
                 for (StoragePoolVO storagePoolVO : spPools) {
                     onePoolforZone.put(storagePoolVO.getDataCenterId(), storagePoolVO);
                 }
                 for (StoragePoolVO storagePool : onePoolforZone.values()) {
                     try {
-                        log.debug(String.format("Collecting volumes statistics for zone [%s]", storagePool.getDataCenterId()));
+                        logger.debug(String.format("Collecting volumes statistics for zone [%s]", storagePool.getDataCenterId()));
                         JsonArray arr = StorPoolUtil.volumesSpace(StorPoolUtil.getSpConnection(storagePool.getUuid(),
                                 storagePool.getId(), storagePoolDetailsDao, storagePoolDao));
                         volumesStats.putAll(getClusterVolumeOrTemplateSpace(arr, StorPoolObject.VOLUME));
                     } catch (Exception e) {
-                        log.debug(String.format("Could not collect StorPool volumes statistics due to %s", e.getMessage()));
+                        logger.debug(String.format("Could not collect StorPool volumes statistics due to %s", e.getMessage()));
                     }
                 }
             }
@@ -149,12 +146,12 @@ public class StorPoolStatsCollector extends ManagerBase {
                 }
                 for (StoragePoolVO storagePool : onePoolforZone.values()) {
                     try {
-                        log.debug(String.format("Collecting templates statistics for zone [%s]", storagePool.getDataCenterId()));
+                        logger.debug(String.format("Collecting templates statistics for zone [%s]", storagePool.getDataCenterId()));
                         JsonArray arr = StorPoolUtil.templatesStats(StorPoolUtil.getSpConnection(storagePool.getUuid(),
                                 storagePool.getId(), storagePoolDetailsDao, storagePoolDao));
                         templatesStats.put(storagePool.getDataCenterId(), getClusterVolumeOrTemplateSpace(arr, StorPoolObject.TEMPLATE));
                     } catch (Exception e) {
-                        log.debug(String.format("Could not collect StorPool templates statistics %s", e.getMessage()));
+                        logger.debug(String.format("Could not collect StorPool templates statistics %s", e.getMessage()));
                     }
                 }
             }
@@ -227,14 +224,14 @@ public class StorPoolStatsCollector extends ManagerBase {
                     Map<String, String> snapshotsWithDelayDelete = new HashMap<>();
 
                     try {
-                        log.debug(String.format("Collecting snapshots marked to be deleted for zone [%s]", storagePool.getDataCenterId()));
+                        logger.debug(String.format("Collecting snapshots marked to be deleted for zone [%s]", storagePool.getDataCenterId()));
                         JsonArray arr = StorPoolUtil.snapshotsListAllClusters(StorPoolUtil.getSpConnection(storagePool.getUuid(),
                                 storagePool.getId(), storagePoolDetailsDao, storagePoolDao));
                          snapshotsWithDelayDelete.putAll(getSnapshotsMarkedForDeletion(arr));
-                         log.debug(String.format("Found snapshot details [%s] and snapshots on StorPool with delay delete flag [%s]", snapshotsDetails, snapshotsWithDelayDelete));
+                         logger.debug(String.format("Found snapshot details [%s] and snapshots on StorPool with delay delete flag [%s]", snapshotsDetails, snapshotsWithDelayDelete));
                          syncSnapshots(snapshotsDetails, snapshotsWithDelayDelete);
                     } catch (Exception e) {
-                        log.debug("Could not fetch the snapshots with delay delete flag " + e.getMessage());
+                        logger.debug("Could not fetch the snapshots with delay delete flag " + e.getMessage());
                     }
                 }
             }
@@ -276,7 +273,7 @@ public class StorPoolStatsCollector extends ManagerBase {
                 }
                 collectSnapshots(snapshotsWithDelayDelete, response);
             }
-            log.debug("Found snapshots on StorPool" + snapshotsWithDelayDelete);
+            logger.debug("Found snapshots on StorPool" + snapshotsWithDelayDelete);
             return snapshotsWithDelayDelete;
         }
 
