@@ -26,7 +26,6 @@ import org.apache.cloudstack.api.response.LDAPConfigResponse;
 import org.apache.cloudstack.api.response.LDAPRemoveResponse;
 import org.apache.cloudstack.ldap.LdapConfigurationVO;
 import org.apache.cloudstack.ldap.LdapManager;
-import org.apache.log4j.Logger;
 
 import com.cloud.user.Account;
 import com.cloud.utils.Pair;
@@ -38,7 +37,6 @@ import com.cloud.utils.Pair;
 @APICommand(name = "ldapRemove", description = "(Deprecated , use deleteLdapConfiguration) Remove the LDAP context for this site.", responseObject = LDAPConfigResponse.class, since = "3.0.1",
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class LDAPRemoveCmd extends BaseCmd {
-    public static final Logger s_logger = Logger.getLogger(LDAPRemoveCmd.class.getName());
 
     @Inject
     private LdapManager _ldapManager;
