@@ -25,7 +25,8 @@ import java.util.Map;
 import org.apache.cloudstack.api.ApiConstants;
 import org.apache.cloudstack.api.BaseCmd;
 import org.apache.cloudstack.api.Parameter;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 /**
  * This worker validates parameters in a generic way, by using annotated
@@ -37,7 +38,7 @@ import org.apache.log4j.Logger;
  */
 public class ParamGenericValidationWorker implements DispatchWorker {
 
-    static Logger s_logger = Logger.getLogger(ParamGenericValidationWorker.class.getName());
+    protected Logger logger = LogManager.getLogger(getClass());
 
     protected static final List<String> defaultParamNames = new ArrayList<String>();
 
@@ -101,7 +102,7 @@ public class ParamGenericValidationWorker implements DispatchWorker {
         }
 
         if (foundUnknownParam) {
-            s_logger.warn(String.format("Received unknown parameters for command %s. %s", cmd.getActualCommandName(), errorMsg));
+            logger.warn(String.format("Received unknown parameters for command %s. %s", cmd.getActualCommandName(), errorMsg));
         }
     }
 
