@@ -48,7 +48,6 @@ import org.apache.cloudstack.framework.security.keystore.KeystoreVO;
 import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
 import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreDao;
-import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreVO;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.BooleanUtils;
 
@@ -82,9 +81,9 @@ import com.cloud.exception.InsufficientAddressCapacityException;
 import com.cloud.exception.InsufficientCapacityException;
 import com.cloud.exception.OperationTimedoutException;
 import com.cloud.exception.ResourceUnavailableException;
-import com.cloud.host.Host;
 import com.cloud.host.Host.Type;
 import com.cloud.host.HostVO;
+import com.cloud.host.Status;
 import com.cloud.host.dao.HostDao;
 import com.cloud.hypervisor.Hypervisor.HypervisorType;
 import com.cloud.info.ConsoleProxyConnectionInfo;
@@ -111,10 +110,8 @@ import com.cloud.resource.ServerResource;
 import com.cloud.resource.UnableDeleteHostException;
 import com.cloud.service.ServiceOfferingVO;
 import com.cloud.service.dao.ServiceOfferingDao;
-import com.cloud.storage.DataStoreRole;
 import com.cloud.storage.Storage;
 import com.cloud.storage.StoragePoolStatus;
-import com.cloud.storage.VMTemplateStorageResourceAssoc.Status;
 import com.cloud.storage.VMTemplateVO;
 import com.cloud.storage.dao.VMTemplateDao;
 import com.cloud.user.Account;
@@ -281,9 +278,9 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         }
 
         @Override
-        public void onAgentDisconnect(long agentId, com.cloud.host.Status state) {
+        public void onAgentDisconnect(long agentId, Status state) {
 
-            if (state == com.cloud.host.Status.Alert || state == com.cloud.host.Status.Disconnected) {
+            if (state == Status.Alert || state == Status.Disconnected) {
                 HostVO host = _hostDao.findById(agentId);
                 if (host.getType() == Type.ConsoleProxy) {
                     String name = host.getName();
@@ -329,8 +326,8 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
     }
 
     @Override
-    public ConsoleProxyInfo assignProxy(final long dataCenterId, final long vmId) {
-        ConsoleProxyVO proxy = doAssignProxy(dataCenterId, vmId);
+    public ConsoleProxyInfo assignProxy(final long dataCenterId, final VMInstanceVO userVm) {
+        ConsoleProxyVO proxy = doAssignProxy(dataCenterId, userVm);
         if (proxy == null) {
             return null;
         }
@@ -355,14 +352,8 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         return  info;
     }
 
-    public ConsoleProxyVO doAssignProxy(long dataCenterId, long vmId) {
+    public ConsoleProxyVO doAssignProxy(long dataCenterId, VMInstanceVO vm) {
         ConsoleProxyVO proxy = null;
-        VMInstanceVO vm = vmInstanceDao.findById(vmId);
-
-        if (vm == null) {
-            logger.warn("VM " + vmId + " no longer exists, return a null proxy for vm:" + vmId);
-            return null;
-        }
 
         if (!availableVmStateOnAssignProxy.contains(vm.getState())) {
             if (logger.isInfoEnabled()) {
@@ -379,17 +370,17 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
                     if (proxy != null) {
                         if (!isInAssignableState(proxy)) {
                             if (logger.isInfoEnabled()) {
-                                logger.info("A previous assigned proxy is not assignable now, reassign console proxy for user vm : " + vmId);
+                                logger.info("A previous assigned proxy is not assignable now, reassign console proxy for user vm : {}", vm);
                             }
                             proxy = null;
                         } else {
                             if (consoleProxyDao.getProxyActiveLoad(proxy.getId()) < capacityPerProxy || hasPreviousSession(proxy, vm)) {
                                 if (logger.isDebugEnabled()) {
-                                    logger.debug("Assign previous allocated console proxy for user vm : " + vmId);
+                                    logger.debug("Assign previous allocated console proxy for user vm: {}", vm);
                                 }
 
                                 if (proxy.getActiveSession() >= capacityPerProxy) {
-                                    logger.warn("Assign overloaded proxy to user VM as previous session exists, user vm : " + vmId);
+                                    logger.warn("Assign overloaded proxy to user VM as previous session exists, user vm: {}", vm);
                                 }
                             } else {
                                 proxy = null;
@@ -405,8 +396,8 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
                 allocProxyLock.unlock();
             }
         } else {
-            logger.error("Unable to acquire synchronization lock to get/allocate proxy resource for vm :" + vmId +
-                ". Previous console proxy allocation is taking too long");
+            logger.error("Unable to acquire synchronization lock to get/allocate proxy " +
+                    "resource for vm: {}. Previous console proxy allocation is taking too long", vm);
         }
 
         if (proxy == null) {
@@ -415,7 +406,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         }
 
         if (vm.getProxyId() == null || vm.getProxyId() != proxy.getId()) {
-            vmInstanceDao.updateProxyId(vmId, proxy.getId(), DateUtil.currentGMTTime());
+            vmInstanceDao.updateProxyId(vm.getId(), proxy.getId(), DateUtil.currentGMTTime());
         }
 
         proxy.setSslEnabled(sslEnabled);
@@ -471,7 +462,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
     public ConsoleProxyVO startProxy(long proxyVmId, boolean ignoreRestartSetting) {
         try {
             ConsoleProxyVO proxy = consoleProxyDao.findById(proxyVmId);
-            if (proxy.getState() == VirtualMachine.State.Running) {
+            if (proxy.getState() == State.Running) {
                 return proxy;
             }
 
@@ -480,7 +471,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
                 return null;
             }
 
-            if (proxy.getState() == VirtualMachine.State.Stopped) {
+            if (proxy.getState() == State.Stopped) {
                 virtualMachineManager.advanceStart(proxy.getUuid(), null, null);
                 proxy = consoleProxyDao.findById(proxy.getId());
                 return proxy;
@@ -504,8 +495,9 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
 
     public ConsoleProxyVO assignProxyFromRunningPool(long dataCenterId) {
 
+        DataCenterVO zone = dataCenterDao.findById(dataCenterId);
         if (logger.isDebugEnabled()) {
-            logger.debug("Assign console proxy from running pool for request from data center : " + dataCenterId);
+            logger.debug("Assign console proxy from running pool for request from data center: {}", zone);
         }
 
         ConsoleProxyAllocator allocator = getCurrentAllocator();
@@ -542,14 +534,14 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
             Long allocated = allocator.allocProxy(runningList, loadInfo, dataCenterId);
 
             if (allocated == null) {
-                logger.debug(String.format("Console proxy not found, unable to assign console proxy from running pool for request from zone [%s].", dataCenterId));
+                logger.debug("Console proxy not found, unable to assign console proxy from running pool for request from zone [{}].", zone);
                 return null;
             }
 
             return consoleProxyDao.findById(allocated);
         } else {
             if (logger.isDebugEnabled()) {
-                logger.debug("Empty running proxy pool for now in data center : " + dataCenterId);
+                logger.debug("Empty running proxy pool for now in data center: {}", zone);
             }
 
         }
@@ -580,12 +572,13 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         }
 
         HypervisorType availableHypervisor = resourceManager.getAvailableHypervisor(dataCenterId);
-        VMTemplateVO template = vmTemplateDao.findSystemVMReadyTemplate(dataCenterId, availableHypervisor);
-        if (template == null) {
+        List<VMTemplateVO> templates = vmTemplateDao.findSystemVMReadyTemplates(dataCenterId, availableHypervisor,
+                ResourceManager.SystemVmPreferredArchitecture.valueIn(dataCenterId));
+        if (CollectionUtils.isEmpty(templates)) {
             throw new CloudRuntimeException("Not able to find the System templates or not downloaded in zone " + dataCenterId);
         }
 
-        Map<String, Object> context = createProxyInstance(dataCenterId, template);
+        Map<String, Object> context = createProxyInstance(dataCenterId, templates);
 
         long proxyVmId = (Long)context.get("proxyVmId");
         if (proxyVmId == 0) {
@@ -678,7 +671,26 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         return defaultNetworks.get(0);
     }
 
-    protected Map<String, Object> createProxyInstance(long dataCenterId, VMTemplateVO template) throws ConcurrentOperationException {
+    protected ConsoleProxyVO createOrUpdateConsoleProxy(ConsoleProxyVO proxy, long dataCenterId, long id, String name,
+            ServiceOffering serviceOffering, VMTemplateVO template, Account systemAccount) {
+        if (proxy == null) {
+            proxy = new ConsoleProxyVO(id, serviceOffering.getId(), name, template.getId(),
+                    template.getHypervisorType(), template.getGuestOSId(), dataCenterId, systemAccount.getDomainId(),
+                    systemAccount.getId(), accountManager.getSystemUser().getId(), 0,
+                    serviceOffering.isOfferHA());
+            proxy.setDynamicallyScalable(template.isDynamicallyScalable());
+            proxy.setLimitCpuUse(serviceOffering.getLimitCpuUse());
+            return consoleProxyDao.persist(proxy);
+        }
+        proxy.setTemplateId(template.getId());
+        proxy.setHypervisorType(template.getHypervisorType());
+        proxy.setGuestOSId(template.getGuestOSId());
+        proxy.setDynamicallyScalable(template.isDynamicallyScalable());
+        consoleProxyDao.update(proxy.getId(), proxy);
+        return proxy;
+    }
+
+    protected Map<String, Object> createProxyInstance(long dataCenterId, List<VMTemplateVO> templates) throws ConcurrentOperationException {
 
         long id = consoleProxyDao.getNextInSequence(Long.class, "id");
         String name = VirtualMachineName.getConsoleProxyName(id, instance);
@@ -707,18 +719,23 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         if (serviceOffering == null) {
             serviceOffering = serviceOfferingDao.findDefaultSystemOffering(ServiceOffering.consoleProxyDefaultOffUniqueName, ConfigurationManagerImpl.SystemVMUseLocalStorage.valueIn(dataCenterId));
         }
-        ConsoleProxyVO proxy =
-            new ConsoleProxyVO(id, serviceOffering.getId(), name, template.getId(), template.getHypervisorType(), template.getGuestOSId(), dataCenterId,
-                systemAcct.getDomainId(), systemAcct.getId(), accountManager.getSystemUser().getId(), 0, serviceOffering.isOfferHA());
-        proxy.setDynamicallyScalable(template.isDynamicallyScalable());
-        proxy.setLimitCpuUse(serviceOffering.getLimitCpuUse());
-        proxy = consoleProxyDao.persist(proxy);
-        try {
-            virtualMachineManager.allocate(name, template, serviceOffering, networks, plan, null);
-        } catch (InsufficientCapacityException e) {
-            String message = String.format("Unable to allocate proxy [%s] on zone [%s] due to [%s].", proxy.toString(), dataCenterId, e.getMessage());
-            logger.warn(message, e);
-            throw new CloudRuntimeException(message, e);
+        ConsoleProxyVO proxy = null;
+        for (final Iterator<VMTemplateVO> templateIterator = templates.iterator(); templateIterator.hasNext();) {
+            VMTemplateVO template = templateIterator.next();
+            proxy = createOrUpdateConsoleProxy(proxy, dataCenterId, id, name, serviceOffering, template, systemAcct);
+            try {
+                virtualMachineManager.allocate(name, template, serviceOffering, networks, plan,
+                        template.getHypervisorType());
+                proxy = consoleProxyDao.findById(proxy.getId());
+                virtualMachineManager.checkDeploymentPlan(proxy, template, serviceOffering, systemAcct, plan);
+                break;
+            } catch (InsufficientCapacityException e) {
+                if (templateIterator.hasNext()) {
+                    logger.debug("Unable to allocate proxy {} with {} in {} due to [{}]. Retrying with another template", proxy, template, dc, e.getMessage(), e);
+                    continue;
+                }
+                throw new CloudRuntimeException("Failed to allocate proxy [%s] in zone [%s] with available templates", e);
+            }
         }
 
         Map<String, Object> context = new HashMap<>();
@@ -742,8 +759,8 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         updateConsoleProxyStatus(answer.getDetails(), answer.getProxyVmId());
     }
 
-    public void handleAgentDisconnect(long agentId, com.cloud.host.Status state) {
-        if (state == com.cloud.host.Status.Alert || state == com.cloud.host.Status.Disconnected) {
+    public void handleAgentDisconnect(long agentId, Status state) {
+        if (state == Status.Alert || state == Status.Disconnected) {
             HostVO host = hostDao.findById(agentId);
             if (host.getType() == Type.ConsoleProxy) {
                 String name = host.getName();
@@ -794,8 +811,8 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
             return false;
         }
         List<ConsoleProxyVO> l =
-            consoleProxyDao.getProxyListInStates(dcId, VirtualMachine.State.Starting, VirtualMachine.State.Running, VirtualMachine.State.Stopping,
-                VirtualMachine.State.Stopped, VirtualMachine.State.Migrating, VirtualMachine.State.Shutdown, VirtualMachine.State.Unknown);
+            consoleProxyDao.getProxyListInStates(dcId, State.Starting, State.Running, State.Stopping,
+                State.Stopped, State.Migrating, State.Shutdown, State.Unknown);
 
         String value = configurationDao.getValue(Config.ConsoleProxyLaunchMax.key());
         int launchLimit = NumbersUtil.parseInt(value, 10);
@@ -807,8 +824,9 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
     }
 
     private void allocCapacity(long dataCenterId) {
+        DataCenterVO zone = dataCenterDao.findById(dataCenterId);
         if (logger.isDebugEnabled()) {
-            logger.debug(String.format("Allocating console proxy standby capacity for zone [%s].", dataCenterId));
+            logger.debug("Allocating console proxy standby capacity for zone [{}].", zone);
         }
 
         ConsoleProxyVO proxy = null;
@@ -825,7 +843,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
                     try {
                         proxy = startNew(dataCenterId);
                     } catch (ConcurrentOperationException e) {
-                        logger.warn(String.format("Unable to start new console proxy on zone [%s] due to [%s].", dataCenterId, e.getMessage()), e);
+                        logger.warn("Unable to start new console proxy on zone [{}] due to [{}].", zone, e.getMessage(), e);
                     } finally {
                         allocProxyLock.unlock();
                     }
@@ -836,7 +854,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
                 }
             } else {
                 if (logger.isInfoEnabled()) {
-                    logger.info("Found a stopped console proxy, starting it. Vm id : " + proxy.getId());
+                    logger.info("Found a stopped console proxy, starting it. VM: {}", proxy);
                 }
                 consoleProxyVmFromStoppedPool = true;
             }
@@ -847,13 +865,13 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
 
                 if (proxy != null) {
                     if (logger.isInfoEnabled()) {
-                        logger.info("Console proxy " + proxy.getHostName() + " is started");
+                        logger.info("Console proxy {} is started", proxy);
                     }
                     SubscriptionMgr.getInstance().notifySubscribers(ConsoleProxyManager.ALERT_SUBJECT, this,
                         new ConsoleProxyAlertEventArgs(ConsoleProxyAlertEventArgs.PROXY_UP, dataCenterId, proxy.getId(), proxy, null));
                 } else {
                     if (logger.isInfoEnabled()) {
-                        logger.info("Unable to start console proxy vm for standby capacity, vm id : " + proxyVmId + ", will recycle it and start a new one");
+                        logger.info("Unable to start console proxy vm for standby capacity, vm: {}, will recycle it and start a new one", proxy);
                     }
 
                     if (consoleProxyVmFromStoppedPool) {
@@ -863,7 +881,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
             }
         } catch (Exception e) {
            errorString = e.getMessage();
-           logger.warn(String.format("Unable to allocate console proxy standby capacity for zone [%s] due to [%s].", dataCenterId, e.getMessage()), e);
+           logger.warn("Unable to allocate console proxy standby capacity for zone [{}] due to [{}].", zone, e.getMessage(), e);
            throw e;
         } finally {
             if (proxy == null || proxy.getState() != State.Running)
@@ -872,43 +890,29 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
         }
     }
 
-    public boolean isZoneReady(Map<Long, ZoneHostInfo> zoneHostInfoMap, long dataCenterId) {
-        List <HostVO> hosts = hostDao.listByDataCenterId(dataCenterId);
-        if (CollectionUtils.isEmpty(hosts)) {
-            if (logger.isDebugEnabled()) {
-                logger.debug("Zone " + dataCenterId + " has no host available which is enabled and in Up state");
-            }
+    public boolean isZoneReady(Map<Long, ZoneHostInfo> zoneHostInfoMap, DataCenter dataCenter) {
+        Integer totalUpAndEnabledHosts = hostDao.countUpAndEnabledHostsInZone(dataCenter.getId());
+        if (totalUpAndEnabledHosts != null && totalUpAndEnabledHosts < 1) {
+            logger.debug("{} has no host available which is enabled and in Up state", dataCenter);
             return false;
         }
-        ZoneHostInfo zoneHostInfo = zoneHostInfoMap.get(dataCenterId);
+        ZoneHostInfo zoneHostInfo = zoneHostInfoMap.get(dataCenter.getId());
         if (zoneHostInfo != null && isZoneHostReady(zoneHostInfo)) {
-            VMTemplateVO template = vmTemplateDao.findSystemVMReadyTemplate(dataCenterId, HypervisorType.Any);
-            if (template == null) {
+            List<VMTemplateVO> templates = vmTemplateDao.findSystemVMReadyTemplates(dataCenter.getId(),
+                    HypervisorType.Any, null);
+            if (CollectionUtils.isEmpty(templates)) {
                 if (logger.isDebugEnabled()) {
-                    logger.debug("System vm template is not ready at data center " + dataCenterId + ", wait until it is ready to launch console proxy vm");
+                    logger.debug("System vm template is not ready at data center {}, wait until it is ready to launch console proxy vm", dataCenter);
                 }
                 return false;
             }
-            TemplateDataStoreVO templateHostRef;
-            if (template.isDirectDownload()) {
-                templateHostRef = templateDataStoreDao.findByTemplate(template.getId(), DataStoreRole.Image);
-            } else {
-                templateHostRef = templateDataStoreDao.findByTemplateZoneDownloadStatus(template.getId(), dataCenterId, Status.DOWNLOADED);
-            }
-
-            if (templateHostRef != null) {
-                Boolean useLocalStorage = BooleanUtils.toBoolean(ConfigurationManagerImpl.SystemVMUseLocalStorage.valueIn(dataCenterId));
-                List<Pair<Long, Integer>> l = consoleProxyDao.getDatacenterStoragePoolHostInfo(dataCenterId, useLocalStorage);
-                if (CollectionUtils.isNotEmpty(l) && l.get(0).second() > 0) {
-                    return true;
-                } else {
-                    if (logger.isDebugEnabled()) {
-                        logger.debug("Primary storage is not ready, wait until it is ready to launch console proxy");
-                    }
-                }
+            boolean useLocalStorage = BooleanUtils.toBoolean(ConfigurationManagerImpl.SystemVMUseLocalStorage.valueIn(dataCenter.getId()));
+            boolean hasDatacenterStoragePoolHostInfo = consoleProxyDao.hasDatacenterStoragePoolHostInfo(dataCenter.getId(), !useLocalStorage);
+            if (hasDatacenterStoragePoolHostInfo) {
+                return true;
             } else {
                 if (logger.isDebugEnabled()) {
-                    logger.debug(String.format("Zone [%s] is ready, but console proxy template [%s] is not ready on secondary storage.", dataCenterId, template.getId()));
+                    logger.debug("Primary storage is not ready, wait until it is ready to launch console proxy");
                 }
             }
         }
@@ -918,9 +922,9 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
     private boolean isZoneHostReady(ZoneHostInfo zoneHostInfo) {
         int expectedFlags;
         if (useStorageVm) {
-            expectedFlags = RunningHostInfoAgregator.ZoneHostInfo.ROUTING_HOST_MASK;
+            expectedFlags = ZoneHostInfo.ROUTING_HOST_MASK;
         } else {
-            expectedFlags = RunningHostInfoAgregator.ZoneHostInfo.ALL_HOST_MASK;
+            expectedFlags = ZoneHostInfo.ALL_HOST_MASK;
         }
 
         return (zoneHostInfo.getFlags() & expectedFlags) == expectedFlags;
@@ -1099,9 +1103,9 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
             proxy.setPrivateIpAddress(null);
             consoleProxyDao.update(proxy.getId(), proxy);
             consoleProxyDao.remove(vmId);
-            HostVO host = hostDao.findByTypeNameAndZoneId(proxy.getDataCenterId(), proxy.getHostName(), Host.Type.ConsoleProxy);
+            HostVO host = hostDao.findByTypeNameAndZoneId(proxy.getDataCenterId(), proxy.getHostName(), Type.ConsoleProxy);
             if (host != null) {
-                logger.debug(String.format("Removing host [%s] entry for proxy [%s].", host.toString(), vmId));
+                logger.debug("Removing host [{}] entry for proxy [{}].", host, proxy);
                 return hostDao.remove(host.getId());
             }
 
@@ -1467,7 +1471,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
     private void handleResetSuspending() {
         List<ConsoleProxyVO> runningProxies = consoleProxyDao.getProxyListInStates(State.Running);
         for (ConsoleProxyVO proxy : runningProxies) {
-            logger.info("Stop console proxy " + proxy.getId() + " because of we are currently in ResetSuspending management mode");
+            logger.info("Stop console proxy {} because of we are currently in ResetSuspending management mode", proxy);
             stopProxy(proxy.getId());
         }
 
@@ -1509,24 +1513,25 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
 
     @Override
     public boolean isPoolReadyForScan(Long dataCenterId) {
-        if (!isZoneReady(zoneHostInfoMap, dataCenterId)) {
+        DataCenterVO zone = dataCenterDao.findById(dataCenterId);
+        if (!isZoneReady(zoneHostInfoMap, zone)) {
             if (logger.isDebugEnabled()) {
-                logger.debug("Zone " + dataCenterId + " is not ready to launch console proxy yet");
+                logger.debug("Zone {} is not ready to launch console proxy yet", zone);
             }
             return false;
         }
 
-        List<ConsoleProxyVO> l = consoleProxyDao.getProxyListInStates(VirtualMachine.State.Starting, VirtualMachine.State.Stopping);
+        List<ConsoleProxyVO> l = consoleProxyDao.getProxyListInStates(State.Starting, State.Stopping);
         if (l.size() > 0) {
             if (logger.isDebugEnabled()) {
-                logger.debug("Zone " + dataCenterId + " has " + l.size() + " console proxy VM(s) in transition state");
+                logger.debug("Zone {} has {} console proxy VM(s) in transition state", zone, l.size());
             }
 
             return false;
         }
 
         if (logger.isDebugEnabled()) {
-            logger.debug("Zone " + dataCenterId + " is ready to launch console proxy");
+            logger.debug("Zone {} is ready to launch console proxy", zone);
         }
         return true;
     }
@@ -1573,7 +1578,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
             return null;
         }
 
-        host.setType(com.cloud.host.Host.Type.ConsoleProxy);
+        host.setType(Type.ConsoleProxy);
         return host;
     }
 
@@ -1589,7 +1594,7 @@ public class ConsoleProxyManagerImpl extends ManagerBase implements ConsoleProxy
 
     protected HostVO findConsoleProxyHostByName(String name) {
         QueryBuilder<HostVO> sc = QueryBuilder.create(HostVO.class);
-        sc.and(sc.entity().getType(), Op.EQ, Host.Type.ConsoleProxy);
+        sc.and(sc.entity().getType(), Op.EQ, Type.ConsoleProxy);
         sc.and(sc.entity().getName(), Op.EQ, name);
         return sc.find();
     }
