@@ -17,6 +17,7 @@
 package com.cloud.dc.dao;
 
 import java.util.List;
+import java.util.Map;
 
 import com.cloud.dc.DedicatedResourceVO;
 import com.cloud.utils.Pair;
@@ -58,4 +59,6 @@ public interface DedicatedResourceDao extends GenericDao<DedicatedResourceVO, Lo
     List<Long> findHostsByCluster(Long clusterId);
 
     List<Long> findHostsByZone(Long zoneId);
+
+    Map<Long, List<String>> listDomainsOfDedicatedResourcesUsedByDomainPath(String domainPath);
 }
