@@ -23,7 +23,6 @@ import java.util.Random;
 import javax.inject.Inject;
 
 import com.cloud.network.NetworkModel;
-import org.apache.log4j.Logger;
 
 import com.cloud.dc.Pod;
 import com.cloud.dc.dao.DataCenterDao;
@@ -50,7 +49,6 @@ import com.cloud.vm.ReservationContext;
 import com.cloud.vm.VirtualMachineProfile;
 
 public class PodBasedNetworkGuru extends AdapterBase implements NetworkGuru {
-    private static final Logger s_logger = Logger.getLogger(PodBasedNetworkGuru.class);
     @Inject
     DataCenterDao _dcDao;
     @Inject
@@ -76,7 +74,7 @@ public class PodBasedNetworkGuru extends AdapterBase implements NetworkGuru {
     }
 
     @Override
-    public Network design(NetworkOffering offering, DeploymentPlan plan, Network userSpecified, Account owner) {
+    public Network design(NetworkOffering offering, DeploymentPlan plan, Network userSpecified, String name, Long vpcId, Account owner) {
         TrafficType type = offering.getTrafficType();
 
         if (!isMyTrafficType(type)) {
@@ -89,6 +87,11 @@ public class PodBasedNetworkGuru extends AdapterBase implements NetworkGuru {
         return config;
     }
 
+    @Override
+    public void setup(Network network, long networkId) {
+        // do nothing
+    }
+
     protected PodBasedNetworkGuru() {
         super();
     }
@@ -141,7 +144,7 @@ public class PodBasedNetworkGuru extends AdapterBase implements NetworkGuru {
         }
         nic.setIsolationUri(null);
 
-        s_logger.debug("Allocated a nic " + nic + " for " + vm);
+        logger.debug("Allocated a nic " + nic + " for " + vm);
     }
 
     @Override
@@ -158,8 +161,8 @@ public class PodBasedNetworkGuru extends AdapterBase implements NetworkGuru {
 
         nic.deallocate();
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug(String.format("Released nic: %s for vm %s", nic, vm));
+        if (logger.isDebugEnabled()) {
+            logger.debug(String.format("Released nic: %s for vm %s", nic, vm));
         }
 
         return true;
