@@ -182,10 +182,10 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
         Integer connectRequestTimeout = DirectDownloadManager.DirectDownloadConnectionRequestTimeout.value();
         Integer connectTimeout = DirectDownloadManager.DirectDownloadConnectTimeout.value();
         CheckUrlCommand cmd = new CheckUrlCommand(format, url, connectTimeout, connectRequestTimeout, socketTimeout, followRedirects);
-        logger.debug("Performing URL " + url + " validation on host " + host.getId());
+        logger.debug("Performing URL {} validation on host {}", url, host);
         Answer answer = _agentMgr.easySend(host.getId(), cmd);
         if (answer == null || !answer.getResult()) {
-            throw new CloudRuntimeException("URL: " + url + " validation failed on host id " + host.getId());
+            throw new CloudRuntimeException(String.format("URL: %s validation failed on host %s", url, host));
         }
         CheckUrlAnswer ans = (CheckUrlAnswer) answer;
         return ans.getTemplateSize();
@@ -293,7 +293,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
     }
 
     /**
-     * For each zone ID in {@link TemplateProfile#zoneIdList}, verifies if there is active heuristic rules for allocating template and returns the
+     * For each zone ID in {@link TemplateProfile#getZoneIdList()}, verifies if there is active heuristic rules for allocating template and returns the
      * {@link DataStore} returned by the heuristic rule. If there is not an active heuristic rule, then allocate it to a random {@link DataStore}, if the ISO/template is private
      * or allocate it to all {@link DataStore} in the zone, if it is public.
      * @param profile
@@ -368,17 +368,17 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
 
         DataCenterVO zone = _dcDao.findById(zoneId);
         if (zone == null) {
-            logger.warn(String.format("Unable to find zone by id [%s], so skip downloading template to its image store [%s].", zoneId, imageStore.getId()));
+            logger.warn("Unable to find zone by id [{}], so skip downloading template to its image store [{}].", zoneId, imageStore);
             return false;
         }
 
         if (Grouping.AllocationState.Disabled == zone.getAllocationState()) {
-            logger.info(String.format("Zone [%s] is disabled. Skip downloading template to its image store [%s].", zoneId, imageStore.getId()));
+            logger.info("Zone [{}] is disabled. Skip downloading template to its image store [{}].", zone, imageStore);
             return false;
         }
 
         if (!_statsCollector.imageStoreHasEnoughCapacity(imageStore)) {
-            logger.info(String.format("Image store doesn't have enough capacity. Skip downloading template to this image store [%s].", imageStore.getId()));
+            logger.info("Image store doesn't have enough capacity. Skip downloading template to this image store [{}].", imageStore);
             return false;
         }
 
@@ -453,10 +453,10 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
 
     /**
      * If the template/ISO is marked as private, then it is allocated to a random secondary storage; otherwise, allocates to every storage pool in every zone given by the
-     * {@link TemplateProfile#zoneIdList}.
+     * {@link TemplateProfile#getZoneIdList()}.
      */
     private void postUploadAllocation(List<DataStore> imageStores, VMTemplateVO template, List<TemplateOrVolumePostUploadCommand> payloads) {
-        Set<Long> zoneSet = new HashSet<Long>();
+        Set<Long> zoneSet = new HashSet<>();
         Collections.shuffle(imageStores);
         for (DataStore imageStore : imageStores) {
             Long zoneId_is = imageStore.getScope().getScopeId();
@@ -473,7 +473,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
             // update template_store_ref and template state
             EndPoint ep = _epSelector.select(templateOnStore);
             if (ep == null) {
-                String errMsg = "There is no secondary storage VM for downloading template to image store " + imageStore.getName();
+                String errMsg = String.format("There is no secondary storage VM for downloading template to image store %s", imageStore);
                 logger.warn(errMsg);
                 throw new CloudRuntimeException(errMsg);
             }
@@ -539,8 +539,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                 if (tmpltStore != null) {
                     physicalSize = tmpltStore.getPhysicalSize();
                 } else {
-                    logger.warn("No entry found in template_store_ref for template id: " + template.getId() + " and image store id: " + ds.getId() +
-                        " at the end of registering template!");
+                    logger.warn("No entry found in template_store_ref for template: {} and image store: {} at the end of registering template!", template, ds);
                 }
                 Scope dsScope = ds.getScope();
                 if (dsScope.getScopeType() == ScopeType.ZONE) {
@@ -548,7 +547,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                         UsageEventUtils.publishUsageEvent(etype, template.getAccountId(), dsScope.getScopeId(), template.getId(), template.getName(), null, null,
                             physicalSize, template.getSize(), VirtualMachineTemplate.class.getName(), template.getUuid());
                     } else {
-                        logger.warn("Zone scope image store " + ds.getId() + " has a null scope id");
+                        logger.warn("Zone scope image store {} has a null scope id", ds);
                     }
                 } else if (dsScope.getScopeType() == ScopeType.REGION) {
                     // publish usage event for region-wide image store using a -1 zoneId for 4.2, need to revisit post-4.2
@@ -596,7 +595,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
         if (imageStores == null || imageStores.size() == 0) {
             // already destroyed on image stores
             success = true;
-            logger.info("Unable to find image store still having template: " + template.getName() + ", so just mark the template removed");
+            logger.info("Unable to find image store still having template: {}, so just mark the template removed", template);
         } else {
             // Make sure the template is downloaded to all found image stores
             for (DataStore store : imageStores) {
@@ -605,7 +604,7 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                 for (TemplateDataStoreVO templateStore : templateStores) {
                     if (templateStore.getDownloadState() == Status.DOWNLOAD_IN_PROGRESS) {
                         String errorMsg = "Please specify a template that is not currently being downloaded.";
-                        logger.debug("Template: " + template.getName() + " is currently being downloaded to secondary storage host: " + store.getName() + "; can't delete it.");
+                        logger.debug("Template: {} is currently being downloaded to secondary storage host: {}; can't delete it.", template, store);
                         throw new CloudRuntimeException(errorMsg);
                     }
                 }
@@ -629,16 +628,15 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                 boolean dataDiskDeletetionResult = true;
                 List<VMTemplateVO> dataDiskTemplates = templateDao.listByParentTemplatetId(template.getId());
                 if (dataDiskTemplates != null && dataDiskTemplates.size() > 0) {
-                    logger.info("Template: " + template.getId() + " has Datadisk template(s) associated with it. Delete Datadisk templates before deleting the template");
+                    logger.info("Template: {} has Datadisk template(s) associated with it. Delete Datadisk templates before deleting the template", template);
                     for (VMTemplateVO dataDiskTemplate : dataDiskTemplates) {
-                        logger.info("Delete Datadisk template: " + dataDiskTemplate.getId() + " from image store: " + imageStore.getName());
+                        logger.info("Delete Datadisk template: {} from image store: {}", dataDiskTemplate, imageStore);
                         AsyncCallFuture<TemplateApiResult> future = imageService.deleteTemplateAsync(imageFactory.getTemplate(dataDiskTemplate.getId(), imageStore));
                         try {
                             TemplateApiResult result = future.get();
                             dataDiskDeletetionResult = result.isSuccess();
                             if (!dataDiskDeletetionResult) {
-                                logger.warn("Failed to delete datadisk template: " + dataDiskTemplate + " from image store: " + imageStore.getName() + " due to: "
-                                        + result.getResult());
+                                logger.warn("Failed to delete datadisk template: {} from image store: {} due to: {}", dataDiskTemplate, imageStore, result.getResult());
                                 break;
                             }
                             // Remove from template_zone_ref
@@ -664,13 +662,13 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                 }
                 // remove from template_zone_ref
                 if (dataDiskDeletetionResult) {
-                    logger.info("Delete template: " + template.getId() + " from image store: " + imageStore.getName());
+                    logger.info("Delete template: {} from image store: {}", template, imageStore);
                     AsyncCallFuture<TemplateApiResult> future = imageService.deleteTemplateAsync(imageFactory.getTemplate(template.getId(), imageStore));
                     try {
                         TemplateApiResult result = future.get();
                         success = result.isSuccess();
                         if (!success) {
-                            logger.warn("Failed to delete the template: " + template + " from the image store: " + imageStore.getName() + " due to: " + result.getResult());
+                            logger.warn("Failed to delete the template: {} from the image store: {} due to: {}", template, imageStore, result.getResult());
                             break;
                         }
 
@@ -686,8 +684,8 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
                         throw new CloudRuntimeException("Delete template Failed", e);
                     }
                 } else {
-                    logger.warn("Template: " + template.getId() + " won't be deleted from image store: " + imageStore.getName() + " because deletion of one of the Datadisk"
-                            + " templates that belonged to the template failed");
+                    logger.warn("Template: {} won't be deleted from image store: {} " +
+                            "because deletion of one of the Datadisk templates that belonged to the template failed", template, imageStore);
                 }
             }
 
@@ -699,9 +697,9 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
             }
 
             // delete all cache entries for this template
-            List<TemplateInfo> cacheTmpls = imageFactory.listTemplateOnCache(template.getId());
-            for (TemplateInfo tmplOnCache : cacheTmpls) {
-                logger.info("Delete template: " + tmplOnCache.getId() + " from image cache store: " + tmplOnCache.getDataStore().getName());
+            List<TemplateInfo> cachedTemplates = imageFactory.listTemplateOnCache(template.getId());
+            for (TemplateInfo tmplOnCache : cachedTemplates) {
+                logger.info("Delete template: {} from image cache store: {}", tmplOnCache, tmplOnCache.getDataStore());
                 tmplOnCache.delete();
             }
 
@@ -729,27 +727,32 @@ public class HypervisorTemplateAdapter extends TemplateAdapterBase {
             }
 
             // remove its related ACL permission
-            Pair<Class<?>, Long> tmplt = new Pair<Class<?>, Long>(VirtualMachineTemplate.class, template.getId());
-            _messageBus.publish(_name, EntityManager.MESSAGE_REMOVE_ENTITY_EVENT, PublishScope.LOCAL, tmplt);
-
-            checkAndRemoveTemplateDetails(template);
-
-            // Remove comments (if any)
-            AnnotationService.EntityType entityType = template.getFormat().equals(ImageFormat.ISO) ?
-                    AnnotationService.EntityType.ISO : AnnotationService.EntityType.TEMPLATE;
-            annotationDao.removeByEntityType(entityType.name(), template.getUuid());
+            Pair<Class<?>, Long> templateClassForId = new Pair<>(VirtualMachineTemplate.class, template.getId());
+            _messageBus.publish(_name, EntityManager.MESSAGE_REMOVE_ENTITY_EVENT, PublishScope.LOCAL, templateClassForId);
 
+            List<VMTemplateZoneVO> zoneRegistrations = templateZoneDao.listByTemplateId(template.getId());
+            if (zoneRegistrations.isEmpty()) {
+                removeTemplateDetails(template);
+                removeTemplateAnnotations(template);
+            }
         }
         return success;
     }
 
+    private void removeTemplateAnnotations(VMTemplateVO template) {
+        // Remove comments (if any)
+        AnnotationService.EntityType entityType = template.getFormat().equals(ImageFormat.ISO) ?
+                AnnotationService.EntityType.ISO : AnnotationService.EntityType.TEMPLATE;
+        annotationDao.removeByEntityType(entityType.name(), template.getUuid());
+    }
+
     /**
      * removes details of the template and
      * if the template is registered as deploy as is,
      * then it also deletes the details related to deploy as is only if there are no VMs using the template
      * @param template
      */
-    void checkAndRemoveTemplateDetails(VMTemplateVO template) {
+    private void removeTemplateDetails(VMTemplateVO template) {
         templateDetailsDao.removeDetails(template.getId());
 
         if (template.isDeployAsIs()) {
