@@ -362,7 +362,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
 
         try {
             // mark domain as inactive
-            logger.debug("Marking domain id=" + domain.getId() + " as " + Domain.State.Inactive + " before actually deleting it");
+            logger.debug("Marking domain {} as {} before actually deleting it", domain, Domain.State.Inactive);
             domain.setState(Domain.State.Inactive);
             _domainDao.update(domain.getId(), domain);
 
@@ -402,12 +402,12 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             // remove dedicated BGP peers
             routedIpv4Manager.removeBgpPeersByDomainId(domain.getId());
 
-            if (!_configMgr.releaseDomainSpecificVirtualRanges(domain.getId())) {
+            if (!_configMgr.releaseDomainSpecificVirtualRanges(domain)) {
                 CloudRuntimeException e = new CloudRuntimeException("Can't delete the domain yet because failed to release domain specific virtual ip ranges");
                 e.addProxyObject(domain.getUuid(), "domainId");
                 throw e;
             } else {
-                logger.debug("Domain specific Virtual IP ranges " + " are successfully released as a part of domain id=" + domain.getId() + " cleanup.");
+                logger.debug("Domain specific Virtual IP ranges  are successfully released as a part of domain {} cleanup.", domain);
             }
 
             cleanupDomainDetails(domain.getId());
@@ -416,7 +416,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             CallContext.current().putContextParameter(Domain.class, domain.getUuid());
             return true;
         } catch (Exception ex) {
-            logger.error("Exception deleting domain with id " + domain.getId(), ex);
+            logger.error("Exception deleting domain {}", domain, ex);
             if (ex instanceof CloudRuntimeException) {
                 rollbackDomainState(domain);
                 throw (CloudRuntimeException)ex;
@@ -431,8 +431,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
      * @param domain domain
      */
     protected void rollbackDomainState(DomainVO domain) {
-        logger.debug("Changing domain id=" + domain.getId() + " state back to " + Domain.State.Active +
-                " because it can't be removed due to resources referencing to it");
+        logger.debug("Changing domain {} state back to {} because it can't be removed due to resources referencing to it", domain, Domain.State.Active);
         domain.setState(Domain.State.Active);
         _domainDao.update(domain.getId(), domain);
     }
@@ -448,8 +447,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     protected void tryCleanupDomain(DomainVO domain, long ownerId) throws ConcurrentOperationException, ResourceUnavailableException, CloudRuntimeException {
         if (!cleanupDomain(domain.getId(), ownerId)) {
             CloudRuntimeException e =
-                new CloudRuntimeException("Failed to clean up domain resources and sub domains, delete failed on domain " + domain.getName() + " (id: " +
-                    domain.getId() + ").");
+                new CloudRuntimeException(String.format("Failed to clean up domain resources and sub domains, delete failed on domain %s", domain));
             e.addProxyObject(domain.getUuid(), "domainId");
             throw e;
         }
@@ -472,7 +470,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         List<AccountVO> accountsForCleanup = _accountDao.findCleanupsForRemovedAccounts(domain.getId());
         List<DedicatedResourceVO> dedicatedResources = _dedicatedDao.listByDomainId(domain.getId());
         if (CollectionUtils.isNotEmpty(dedicatedResources)) {
-            logger.error("There are dedicated resources for the domain " + domain.getId());
+            logger.error("There are dedicated resources for the domain {}", domain);
             hasDedicatedResources = true;
         }
         if (accountsForCleanup.isEmpty() && networkIds.isEmpty() && !hasDedicatedResources) {
@@ -514,8 +512,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         _messageBus.publish(_name, MESSAGE_PRE_REMOVE_DOMAIN_EVENT, PublishScope.LOCAL, domain);
         if (!_domainDao.remove(domain.getId())) {
             CloudRuntimeException e =
-                new CloudRuntimeException("Delete failed on domain " + domain.getName() + " (id: " + domain.getId() +
-                    "); Please make sure all users and sub domains have been removed from the domain before deleting");
+                new CloudRuntimeException(String.format("Delete failed on domain %s; Please make sure all users and sub domains have been removed from the domain before deleting", domain));
             e.addProxyObject(domain.getUuid(), "domainId");
             throw e;
         }
@@ -604,9 +601,9 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     }
 
     protected boolean cleanupDomain(Long domainId, Long ownerId) throws ConcurrentOperationException, ResourceUnavailableException {
-        logger.debug("Cleaning up domain id=" + domainId);
         boolean success = true;
         DomainVO domainHandle = _domainDao.findById(domainId);
+        logger.debug("Cleaning up domain {}", domainHandle);
         {
             domainHandle.setState(Domain.State.Inactive);
             _domainDao.update(domainId, domainHandle);
@@ -629,7 +626,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             for (DomainVO domain : domains) {
                 success = (success && cleanupDomain(domain.getId(), domain.getAccountId()));
                 if (!success) {
-                    logger.warn("Failed to cleanup domain id=" + domain.getId());
+                    logger.warn("Failed to cleanup domain {}", domain);
                 }
             }
         }
@@ -640,15 +637,15 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         List<AccountVO> accounts = _accountDao.search(sc, null);
         for (AccountVO account : accounts) {
             if (account.getType() != Account.Type.PROJECT) {
-                logger.debug("Deleting account " + account + " as a part of domain id=" + domainId + " cleanup");
+                logger.debug("Deleting account {} as a part of domain {} cleanup", account, domainHandle);
                 boolean deleteAccount = _accountMgr.deleteAccount(account, CallContext.current().getCallingUserId(), getCaller());
                 if (!deleteAccount) {
-                    logger.warn("Failed to cleanup account id=" + account.getId() + " as a part of domain cleanup");
+                    logger.warn("Failed to cleanup account {} as a part of domain cleanup", account);
                 }
                 success = (success && deleteAccount);
             } else {
                 ProjectVO project = _projectDao.findByProjectAccountId(account.getId());
-                logger.debug("Deleting project " + project + " as a part of domain id=" + domainId + " cleanup");
+                logger.debug("Deleting project {} as a part of domain {} cleanup", project, domainHandle);
                 boolean deleteProject = _projectMgr.deleteProject(getCaller(), CallContext.current().getCallingUserId(), project);
                 if (!deleteProject) {
                     logger.warn("Failed to cleanup project " + project + " as a part of domain cleanup");
@@ -659,23 +656,23 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
 
         //delete the domain shared networks
         boolean networksDeleted = true;
-        logger.debug("Deleting networks for domain id=" + domainId);
+        logger.debug("Deleting networks for domain {}", domainHandle);
         List<Long> networkIds = _networkDomainDao.listNetworkIdsByDomain(domainId);
         CallContext ctx = CallContext.current();
         ReservationContext context = new ReservationContextImpl(null, null, _accountMgr.getActiveUser(ctx.getCallingUserId()), ctx.getCallingAccount());
         for (Long networkId : networkIds) {
-            logger.debug("Deleting network id=" + networkId + " as a part of domain id=" + domainId + " cleanup");
+            logger.debug("Deleting network id={} as a part of domain {} cleanup", networkId, domainHandle);
             if (!_networkMgr.destroyNetwork(networkId, context, false)) {
-                logger.warn("Unable to destroy network id=" + networkId + " as a part of domain id=" + domainId + " cleanup.");
+                logger.warn("Unable to destroy network id={} as a part of domain {} cleanup.", networkId, domainHandle);
                 networksDeleted = false;
             } else {
-                logger.debug("Network " + networkId + " successfully deleted as a part of domain id=" + domainId + " cleanup.");
+                logger.debug("Network {} successfully deleted as a part of domain {} cleanup.", networkId, domainHandle);
             }
         }
 
         //don't proceed if networks failed to cleanup. The cleanup will be performed for inactive domain once again
         if (!networksDeleted) {
-            logger.debug("Failed to delete the shared networks as a part of domain id=" + domainId + " clenaup");
+            logger.debug("Failed to delete the shared networks as a part of domain {} cleanup", domainHandle);
             return false;
         }
 
@@ -686,10 +683,10 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             //release dedication if any, before deleting the domain
             List<DedicatedResourceVO> dedicatedResources = _dedicatedDao.listByDomainId(domainId);
             if (dedicatedResources != null && !dedicatedResources.isEmpty()) {
-                logger.debug("Releasing dedicated resources for domain" + domainId);
+                logger.debug("Releasing dedicated resources for domain {}", domainHandle);
                 for (DedicatedResourceVO dr : dedicatedResources) {
                     if (!_dedicatedDao.remove(dr.getId())) {
-                        logger.warn("Fail to release dedicated resources for domain " + domainId);
+                        logger.warn("Fail to release dedicated resources for domain {}", domainHandle);
                         return false;
                     }
                 }
@@ -1005,8 +1002,8 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
 
         if (currentDomainResourceCount + newParentDomainResourceCount > newParentDomainResourceLimit) {
             String message = String.format("Cannot move domain [%s] to parent domain [%s] as maximum domain resource limit of type [%s] would be exceeded. The current resource "
-                            + "count for domain [%s] is [%s], the resource count for the new parent domain [%s] is [%s], and the limit is [%s].", domainToBeMoved.getUuid(),
-                    newParentDomain.getUuid(), resourceType, domainToBeMoved.getUuid(), currentDomainResourceCount, newParentDomain.getUuid(), newParentDomainResourceCount,
+                            + "count for domain [%s] is [%s], the resource count for the new parent domain [%s] is [%s], and the limit is [%s].", domainToBeMoved,
+                    newParentDomain, resourceType, domainToBeMoved, currentDomainResourceCount, newParentDomain, newParentDomainResourceCount,
                     newParentDomainResourceLimit);
             logger.error(message);
             throw new ResourceAllocationException(message, resourceType);
