@@ -18,9 +18,7 @@ package org.apache.cloudstack.agent.lb;
 
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.Comparator;
-import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -34,17 +32,19 @@ import org.apache.cloudstack.agent.lb.algorithm.IndirectAgentLBStaticAlgorithm;
 import org.apache.cloudstack.config.ApiServiceConfiguration;
 import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.cloudstack.framework.config.Configurable;
+import org.apache.commons.lang3.StringUtils;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
+import com.cloud.dc.DataCenterVO;
+import com.cloud.dc.dao.ClusterDao;
+import com.cloud.dc.dao.DataCenterDao;
 import com.cloud.host.Host;
-import com.cloud.host.HostVO;
 import com.cloud.host.dao.HostDao;
 import com.cloud.hypervisor.Hypervisor;
 import com.cloud.resource.ResourceState;
 import com.cloud.utils.component.ComponentLifecycleBase;
 import com.cloud.utils.exception.CloudRuntimeException;
-import org.apache.commons.lang3.StringUtils;
 
 public class IndirectAgentLBServiceImpl extends ComponentLifecycleBase implements IndirectAgentLB, Configurable {
 
@@ -60,11 +60,25 @@ public class IndirectAgentLBServiceImpl extends ComponentLifecycleBase implement
 
     private static Map<String, org.apache.cloudstack.agent.lb.IndirectAgentLBAlgorithm> algorithmMap = new HashMap<>();
 
+    @Inject
+    private DataCenterDao dataCenterDao;
+    @Inject
+    private ClusterDao clusterDao;
     @Inject
     private HostDao hostDao;
     @Inject
     private AgentManager agentManager;
 
+    private static final List<ResourceState> agentValidResourceStates = List.of(
+            ResourceState.Enabled, ResourceState.Maintenance, ResourceState.Disabled,
+            ResourceState.ErrorInMaintenance, ResourceState.PrepareForMaintenance);
+    private static final List<Host.Type> agentValidHostTypes = List.of(Host.Type.Routing, Host.Type.ConsoleProxy,
+            Host.Type.SecondaryStorage, Host.Type.SecondaryStorageVM);
+    private static final List<Host.Type> agentNonRoutingHostTypes = List.of(Host.Type.ConsoleProxy,
+            Host.Type.SecondaryStorage, Host.Type.SecondaryStorageVM);
+    private static final List<Hypervisor.HypervisorType> agentValidHypervisorTypes = List.of(
+            Hypervisor.HypervisorType.KVM, Hypervisor.HypervisorType.LXC);
+
     //////////////////////////////////////////////////////
     /////////////// Agent MSLB Methods ///////////////////
     //////////////////////////////////////////////////////
@@ -76,22 +90,22 @@ public class IndirectAgentLBServiceImpl extends ComponentLifecycleBase implement
             throw new CloudRuntimeException(String.format("No management server addresses are defined in '%s' setting",
                     ApiServiceConfiguration.ManagementServerAddresses.key()));
         }
+        final List<String> msList = Arrays.asList(msServerAddresses.replace(" ", "").split(","));
+        if (msList.size() == 1) {
+            return msList;
+        }
 
+        final org.apache.cloudstack.agent.lb.IndirectAgentLBAlgorithm algorithm = getAgentMSLBAlgorithm();
         List<Long> hostIdList = orderedHostIdList;
         if (hostIdList == null) {
-            hostIdList = getOrderedHostIdList(dcId);
+            hostIdList = algorithm.isHostListNeeded() ? getOrderedHostIdList(dcId) : new ArrayList<>();
         }
 
         // just in case we have a host in creating state make sure it is in the list:
         if (null != hostId && ! hostIdList.contains(hostId)) {
-            if (logger.isTraceEnabled()) {
-                logger.trace("adding requested host to host list as it does not seem to be there; " + hostId);
-            }
+            logger.trace("adding requested host to host list as it does not seem to be there; {}", hostId);
             hostIdList.add(hostId);
         }
-
-        final org.apache.cloudstack.agent.lb.IndirectAgentLBAlgorithm algorithm = getAgentMSLBAlgorithm();
-        final List<String> msList = Arrays.asList(msServerAddresses.replace(" ", "").split(","));
         return algorithm.sort(msList, hostIdList, hostId);
     }
 
@@ -119,76 +133,24 @@ public class IndirectAgentLBServiceImpl extends ComponentLifecycleBase implement
     }
 
     List<Long> getOrderedHostIdList(final Long dcId) {
-        final List<Long> hostIdList = new ArrayList<>();
-        for (final Host host : getAllAgentBasedHosts()) {
-            if (host.getDataCenterId() == dcId) {
-                hostIdList.add(host.getId());
-            }
-        }
-        Collections.sort(hostIdList, new Comparator<Long>() {
-            @Override
-            public int compare(Long x, Long y) {
-                return Long.compare(x,y);
-            }
-        });
+        final List<Long> hostIdList = getAllAgentBasedHostsFromDB(dcId, null);
+        hostIdList.sort(Comparator.comparingLong(x -> x));
         return hostIdList;
     }
 
-    private List<Host> getAllAgentBasedHosts() {
-        final List<HostVO> allHosts = hostDao.listAll();
-        if (allHosts == null) {
-            return new ArrayList<>();
-        }
-        final List <Host> agentBasedHosts = new ArrayList<>();
-        for (final Host host : allHosts) {
-            conditionallyAddHost(agentBasedHosts, host);
-        }
-        return agentBasedHosts;
+    private List<Long> getAllAgentBasedNonRoutingHostsFromDB(final Long zoneId) {
+        return hostDao.findHostIdsByZoneClusterResourceStateTypeAndHypervisorType(zoneId, null,
+                agentValidResourceStates, agentNonRoutingHostTypes, agentValidHypervisorTypes);
     }
 
-    private void conditionallyAddHost(List<Host> agentBasedHosts, Host host) {
-        if (host == null) {
-            if (logger.isTraceEnabled()) {
-                logger.trace("trying to add no host to a list");
-            }
-            return;
-        }
+    private List<Long> getAllAgentBasedRoutingHostsFromDB(final Long zoneId, final Long clusterId) {
+        return hostDao.findHostIdsByZoneClusterResourceStateTypeAndHypervisorType(zoneId, clusterId,
+                agentValidResourceStates, List.of(Host.Type.Routing), agentValidHypervisorTypes);
+    }
 
-        EnumSet<ResourceState> allowedStates = EnumSet.of(
-                ResourceState.Enabled,
-                ResourceState.Maintenance,
-                ResourceState.Disabled,
-                ResourceState.ErrorInMaintenance,
-                ResourceState.PrepareForMaintenance);
-        // so the remaining EnumSet<ResourceState> disallowedStates = EnumSet.complementOf(allowedStates)
-        // would be {ResourceState.Creating, ResourceState.Error};
-        if (!allowedStates.contains(host.getResourceState())) {
-            if (logger.isTraceEnabled()) {
-                logger.trace(String.format("host is in '%s' state, not adding to the host list, (id = %s)", host.getResourceState(), host.getUuid()));
-            }
-            return;
-        }
-
-        if (host.getType() != Host.Type.Routing
-                && host.getType() != Host.Type.ConsoleProxy
-                && host.getType() != Host.Type.SecondaryStorage
-                && host.getType() != Host.Type.SecondaryStorageVM) {
-            if (logger.isTraceEnabled()) {
-                logger.trace(String.format("host is of wrong type, not adding to the host list, (id = %s, type = %s)", host.getUuid(), host.getType()));
-            }
-            return;
-        }
-
-        if (host.getHypervisorType() != null
-                && ! (host.getHypervisorType() == Hypervisor.HypervisorType.KVM || host.getHypervisorType() == Hypervisor.HypervisorType.LXC)) {
-
-            if (logger.isTraceEnabled()) {
-                logger.trace(String.format("hypervisor is not the right type, not adding to the host list, (id = %s, hypervisortype = %s)", host.getUuid(), host.getHypervisorType()));
-            }
-            return;
-        }
-
-        agentBasedHosts.add(host);
+    private List<Long> getAllAgentBasedHostsFromDB(final Long zoneId, final Long clusterId) {
+        return hostDao.findHostIdsByZoneClusterResourceStateTypeAndHypervisorType(zoneId, clusterId,
+                agentValidResourceStates, agentValidHostTypes, agentValidHypervisorTypes);
     }
 
     private org.apache.cloudstack.agent.lb.IndirectAgentLBAlgorithm getAgentMSLBAlgorithm() {
@@ -208,19 +170,39 @@ public class IndirectAgentLBServiceImpl extends ComponentLifecycleBase implement
     public void propagateMSListToAgents() {
         logger.debug("Propagating management server list update to agents");
         final String lbAlgorithm = getLBAlgorithmName();
-        final Map<Long, List<Long>> dcOrderedHostsMap = new HashMap<>();
-        for (final Host host : getAllAgentBasedHosts()) {
-            final Long dcId = host.getDataCenterId();
-            if (!dcOrderedHostsMap.containsKey(dcId)) {
-                dcOrderedHostsMap.put(dcId, getOrderedHostIdList(dcId));
+        final Long globalLbCheckInterval = getLBPreferredHostCheckInterval(null);
+        List<DataCenterVO> zones = dataCenterDao.listAll();
+        for (DataCenterVO zone : zones) {
+            List<Long> zoneHostIds = new ArrayList<>();
+            List<Long> nonRoutingHostIds = getAllAgentBasedNonRoutingHostsFromDB(zone.getId());
+            zoneHostIds.addAll(nonRoutingHostIds);
+            Map<Long, List<Long>> clusterHostIdsMap = new HashMap<>();
+            List<Long> clusterIds = clusterDao.listAllClusterIds(zone.getId());
+            for (Long clusterId : clusterIds) {
+                List<Long> hostIds = getAllAgentBasedRoutingHostsFromDB(zone.getId(), clusterId);
+                clusterHostIdsMap.put(clusterId, hostIds);
+                zoneHostIds.addAll(hostIds);
             }
-            final List<String> msList = getManagementServerList(host.getId(), host.getDataCenterId(), dcOrderedHostsMap.get(dcId));
-            final Long lbCheckInterval = getLBPreferredHostCheckInterval(host.getClusterId());
-            final SetupMSListCommand cmd = new SetupMSListCommand(msList, lbAlgorithm, lbCheckInterval);
-            final Answer answer = agentManager.easySend(host.getId(), cmd);
-            if (answer == null || !answer.getResult()) {
-                logger.warn(String.format("Failed to setup management servers list to the agent of %s", host));
+            zoneHostIds.sort(Comparator.comparingLong(x -> x));
+            for (Long nonRoutingHostId : nonRoutingHostIds) {
+                setupMSList(nonRoutingHostId, zone.getId(), zoneHostIds, lbAlgorithm, globalLbCheckInterval);
             }
+            for (Long clusterId : clusterIds) {
+                final Long clusterLbCheckInterval = getLBPreferredHostCheckInterval(clusterId);
+                List<Long> hostIds = clusterHostIdsMap.get(clusterId);
+                for (Long hostId : hostIds) {
+                    setupMSList(hostId, zone.getId(), zoneHostIds, lbAlgorithm, clusterLbCheckInterval);
+                }
+            }
+        }
+    }
+
+    private void setupMSList(final Long hostId, final Long dcId, final List<Long> orderedHostIdList, final String lbAlgorithm, final Long lbCheckInterval) {
+        final List<String> msList = getManagementServerList(hostId, dcId, orderedHostIdList);
+        final SetupMSListCommand cmd = new SetupMSListCommand(msList, lbAlgorithm, lbCheckInterval);
+        final Answer answer = agentManager.easySend(hostId, cmd);
+        if (answer == null || !answer.getResult()) {
+            logger.warn(String.format("Failed to setup management servers list to the agent of ID: %d", hostId));
         }
     }
 
