@@ -149,7 +149,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
         final Map<String, String> accessDetails = networkManager.getSystemVMAccessDetails(vmInstance);
 
         if (StringUtils.isEmpty(accessDetails.get(NetworkElementCommand.ROUTER_IP))) {
-            throw new CloudRuntimeException("Unable to set system vm ControlIP for system vm with ID: " + vmId);
+            throw new CloudRuntimeException("Unable to set system vm ControlIP for system vm: " + vmInstance);
         }
 
         command.setAccessDetail(accessDetails);
@@ -227,7 +227,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
         final long zoneId = vmInstance.getDataCenterId();
         VMInstanceVO ssvm = getSecondaryStorageVmInZone(zoneId);
         if (ssvm == null) {
-            throw new CloudRuntimeException("No SSVM found in zone with ID: " + zoneId);
+            throw new CloudRuntimeException("No SSVM found in zone: " + dataCenterDao.findById(zoneId));
         }
 
         // Secondary Storage install path = "diagnostics_data/diagnostics_files_xxxx.tar
@@ -265,7 +265,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
     private void configureNetworkElementCommand(NetworkElementCommand cmd, VMInstanceVO vmInstance) {
         Map<String, String> accessDetails = networkManager.getSystemVMAccessDetails(vmInstance);
         if (StringUtils.isBlank(accessDetails.get(NetworkElementCommand.ROUTER_IP))) {
-            throw new CloudRuntimeException("Unable to set system vm ControlIP for system vm with ID: " + vmInstance.getId());
+            throw new CloudRuntimeException(String.format("Unable to set system vm ControlIP for system vm: %s", vmInstance));
         }
         cmd.setAccessDetail(accessDetails);
     }
@@ -282,10 +282,10 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
         configureNetworkElementCommand(cmd, vmInstance);
         final Answer fileCleanupAnswer = agentManager.easySend(vmInstance.getHostId(), cmd);
         if (fileCleanupAnswer == null) {
-            logger.error(String.format("Failed to cleanup diagnostics zip file on vm: %s", vmInstance.getUuid()));
+            logger.error("Failed to cleanup diagnostics zip file on vm: {}", vmInstance);
         } else {
             if (!fileCleanupAnswer.getResult()) {
-                logger.error(String.format("Zip file cleanup for vm %s has failed with: %s", vmInstance.getUuid(), fileCleanupAnswer.getDetails()));
+                logger.error("Zip file cleanup for vm {} has failed with: {}", vmInstance, fileCleanupAnswer.getDetails());
             }
         }
 
@@ -328,7 +328,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
         boolean success = false;
         String mountPoint = mountManager.getMountPoint(store.getUri(), imageStoreDetailsUtil.getNfsVersion(store.getId()));
         if (StringUtils.isBlank(mountPoint)) {
-            logger.error("Failed to generate mount point for copying to secondary storage for " + store.getName());
+            logger.error("Failed to generate mount point for copying to secondary storage for {}", store);
             return new Pair<>(false, "Failed to mount secondary storage:" + store.getName());
         }
 
@@ -371,7 +371,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
     private DataStore getImageStore(Long zoneId) {
         List<DataStore> stores = storeMgr.getImageStoresByScopeExcludingReadOnly(new ZoneScope(zoneId));
         if (CollectionUtils.isEmpty(stores)) {
-            throw new CloudRuntimeException("No Secondary storage found in Zone with Id: " + zoneId);
+            throw new CloudRuntimeException(String.format("No Secondary storage found in Zone: %s", dataCenterDao.findById(zoneId)));
         }
         DataStore imageStore = null;
         for (DataStore store : stores) {
@@ -382,7 +382,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
             }
         }
         if (imageStore == null) {
-            throw new CloudRuntimeException("No suitable secondary storage found to retrieve diagnostics in Zone: " + zoneId);
+            throw new CloudRuntimeException(String.format("No suitable secondary storage found to retrieve diagnostics in Zone: %s", dataCenterDao.findById(zoneId)));
         }
         return imageStore;
     }
@@ -418,7 +418,7 @@ public class DiagnosticsServiceImpl extends ManagerBase implements PluggableServ
         Map<String, String> accessDetails = networkManager.getSystemVMAccessDetails(vmInstance);
         String controlIP = accessDetails.get(NetworkElementCommand.ROUTER_IP);
         if (StringUtils.isBlank(controlIP)) {
-            throw new CloudRuntimeException("Unable to find system vm ssh/control IP for  vm with ID: " + vmInstance.getId());
+            throw new CloudRuntimeException(String.format("Unable to find system vm ssh/control IP for vm: %s", vmInstance));
         }
         return controlIP;
     }
