@@ -341,6 +341,11 @@ public class MockNetworkModelImpl extends ManagerBase implements NetworkModel {
         return false;
     }
 
+    @Override
+    public boolean isAnyServiceSupportedInNetwork(long networkId, Provider provider, Service... services) {
+        return false;
+    }
+
     /* (non-Javadoc)
      * @see com.cloud.network.NetworkModel#isProviderEnabledInPhysicalNetwork(long, java.lang.String)
      */
@@ -938,4 +943,14 @@ public class MockNetworkModelImpl extends ManagerBase implements NetworkModel {
 
     @Override
     public void verifyIp6DnsPair(String ip4Dns1, String ip4Dns2) {}
+
+    @Override
+    public boolean isSecurityGroupSupportedForZone(Long zoneId) {
+        return false;
+    }
+
+    @Override
+    public boolean checkSecurityGroupSupportForNetwork(Account account, DataCenter zone, List<Long> networkIds, List<Long> securityGroupsIds) {
+        return false;
+    }
 }
