@@ -65,6 +65,7 @@ import com.cloud.network.router.VirtualRouter;
 import com.cloud.network.router.VirtualRouter.RedundantState;
 import com.cloud.network.router.VpcVirtualNetworkApplianceManagerImpl;
 import com.cloud.network.rules.dao.PortForwardingRulesDao;
+import com.cloud.network.vpc.VpcVO;
 import com.cloud.offering.NetworkOffering;
 import com.cloud.offerings.NetworkOfferingVO;
 import com.cloud.offerings.dao.NetworkOfferingDao;
@@ -98,7 +99,11 @@ import com.cloud.vm.dao.UserVmDetailsDao;
 import com.cloud.vm.dao.VMInstanceDao;
 import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
+import org.apache.cloudstack.network.BgpPeerVO;
 import org.apache.cloudstack.network.router.deployment.RouterDeploymentDefinitionBuilder;
+import org.apache.cloudstack.network.topology.NetworkTopology;
+import org.apache.cloudstack.network.topology.NetworkTopologyContext;
+import org.junit.Assert;
 import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -111,6 +116,7 @@ import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.stream.Collectors;
 
@@ -122,6 +128,7 @@ import static org.mockito.ArgumentMatchers.anyList;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.lenient;
+import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
@@ -178,6 +185,7 @@ public class VirtualRouterElementTest {
     @Mock private ResourceManager _resourceMgr;
     @Mock private UserVmManager _userVmMgr;
     @Mock private VirtualMachineManager _itMgr;
+    @Mock private NetworkTopologyContext networkTopologyContext;
 
     @InjectMocks
     private RouterDeploymentDefinitionBuilder routerDeploymentDefinitionBuilder;
@@ -517,4 +525,52 @@ public class VirtualRouterElementTest {
         assertTrue(counterNames.contains(AutoScaleCounterType.Memory.getName()));
         assertTrue(counterNames.contains(AutoScaleCounterType.VirtualRouter.getName()));
     }
+
+    @Test
+    public void testApplyBgpPeersForVpc() throws ResourceUnavailableException {
+        List<BgpPeerVO> bgpPeers = Mockito.mock(List.class);
+        VpcVO vpc = Mockito.mock(VpcVO.class);
+
+        DomainRouterVO router = Mockito.mock(DomainRouterVO.class);
+        when(router.getState()).thenReturn(VirtualMachine.State.Running);
+        long zoneId = 10L;
+        long vpcId = 11L;
+        when(vpc.getId()).thenReturn(vpcId);
+        when(vpc.getZoneId()).thenReturn(zoneId);
+        when(_routerDao.listByVpcId(vpcId)).thenReturn(Arrays.asList(router));
+        DataCenterVO dc = Mockito.mock(DataCenterVO.class);
+        when(_dcDao.findById(zoneId)).thenReturn(dc);
+        NetworkTopology networkTopology = Mockito.mock(NetworkTopology.class);
+        when(networkTopologyContext.retrieveNetworkTopology(dc)).thenReturn(networkTopology);
+        doReturn(true).when(networkTopology).applyBgpPeers(any(), any(), any());
+
+        boolean result = virtualRouterElement.applyBgpPeers(vpc, null, bgpPeers);
+
+        Assert.assertTrue(result);
+        verify(networkTopology).applyBgpPeers(any(), any(), any());
+    }
+
+    @Test
+    public void testApplyBgpPeersForNetwork() throws ResourceUnavailableException {
+        List<BgpPeerVO> bgpPeers = Mockito.mock(List.class);
+        NetworkVO network = Mockito.mock(NetworkVO.class);
+
+        DomainRouterVO router = Mockito.mock(DomainRouterVO.class);
+        when(router.getState()).thenReturn(VirtualMachine.State.Running);
+        long zoneId = 10L;
+        long networkId = 11L;
+        when(network.getId()).thenReturn(networkId);
+        when(network.getDataCenterId()).thenReturn(zoneId);
+        when(_routerDao.listByNetworkAndRole(networkId, VirtualRouter.Role.VIRTUAL_ROUTER)).thenReturn(Arrays.asList(router));
+        DataCenterVO dc = Mockito.mock(DataCenterVO.class);
+        when(_dcDao.findById(zoneId)).thenReturn(dc);
+        NetworkTopology networkTopology = Mockito.mock(NetworkTopology.class);
+        when(networkTopologyContext.retrieveNetworkTopology(dc)).thenReturn(networkTopology);
+        doReturn(true).when(networkTopology).applyBgpPeers(any(), any(), any());
+
+        boolean result = virtualRouterElement.applyBgpPeers(null, network, bgpPeers);
+
+        Assert.assertTrue(result);
+        verify(networkTopology).applyBgpPeers(any(), any(), any());
+    }
 }
