@@ -18,7 +18,6 @@ package com.cloud.consoleproxy;
 
 import com.cloud.utils.net.NetUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 import org.eclipse.jetty.websocket.api.Session;
 import org.eclipse.jetty.websocket.api.WebSocketException;
 import org.eclipse.jetty.websocket.api.extensions.Frame;
@@ -30,10 +29,13 @@ import java.nio.ByteBuffer;
 import java.nio.charset.StandardCharsets;
 import java.util.List;
 
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
+
 import com.cloud.consoleproxy.vnc.NoVncClient;
 
 public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
-    private static final Logger s_logger = Logger.getLogger(ConsoleProxyNoVncClient.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private static int nextClientId = 0;
 
     private NoVncClient client;
@@ -73,9 +75,9 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
 
     @Override
     public boolean isFrontEndAlive() {
-        if (!connectionAlive || System.currentTimeMillis()
-                - getClientLastFrontEndActivityTime() > ConsoleProxy.VIEWER_LINGER_SECONDS * 1000) {
-            s_logger.info("Front end has been idle for too long");
+        long unusedTime = System.currentTimeMillis() - getClientLastFrontEndActivityTime();
+        if (!connectionAlive || unusedTime > ConsoleProxy.VIEWER_LINGER_SECONDS * 1000) {
+            logger.info("Front end has been idle for too long ({} ms).", unusedTime);
             return false;
         }
         return true;
@@ -93,23 +95,24 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
         client = new NoVncClient();
         connectionAlive = true;
         this.sessionUuid = param.getSessionUuid();
+        String clientSourceIp = param.getClientIp();
+        logger.debug("Initializing client from IP {}.", clientSourceIp);
 
         updateFrontEndActivityTime();
         Thread worker = new Thread(new Runnable() {
             public void run() {
                 try {
-
                     String tunnelUrl = param.getClientTunnelUrl();
                     String tunnelSession = param.getClientTunnelSession();
                     String websocketUrl = param.getWebsocketUrl();
 
                     connectClientToVNCServer(tunnelUrl, tunnelSession, websocketUrl);
-
-                    authenticateToVNCServer();
+                    authenticateToVNCServer(clientSourceIp);
 
                     int readBytes;
                     byte[] b;
                     while (connectionAlive) {
+                        logger.trace("Connection with client [{}] [IP: {}] is alive.", clientId, clientSourceIp);
                         if (client.isVncOverWebSocketConnection()) {
                             if (client.isVncOverWebSocketConnectionOpen()) {
                                 updateFrontEndActivityTime();
@@ -120,7 +123,7 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
                             int nextBytes = client.getNextBytes();
                             bytesArr = new byte[nextBytes];
                             client.readBytes(bytesArr, nextBytes);
-                            s_logger.trace(String.format("Read [%s] bytes from client [%s]", nextBytes, clientId));
+                            logger.trace("Read [{}] bytes from client [{}].", nextBytes, clientId);
                             if (nextBytes > 0) {
                                 session.getRemote().sendBytes(ByteBuffer.wrap(bytesArr));
                                 updateFrontEndActivityTime();
@@ -130,7 +133,7 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
                         } else {
                             b = new byte[100];
                             readBytes = client.read(b);
-                            s_logger.trace(String.format("Read [%s] bytes from client [%s]", readBytes, clientId));
+                            logger.trace("Read [{}] bytes from client [{}].", readBytes, clientId);
                             if (readBytes == -1 || (readBytes > 0 && !sendReadBytesToNoVNC(b, readBytes))) {
                                 connectionAlive = false;
                             }
@@ -138,12 +141,12 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
                         try {
                             Thread.sleep(1);
                         } catch (InterruptedException e) {
-                            s_logger.error("Error on sleep for vnc sessions", e);
+                            logger.error("Error on sleep for vnc sessions", e);
                         }
                     }
-                    s_logger.info(String.format("Connection with client [%s] is dead.", clientId));
+                    logger.info("Connection with client [{}] [IP: {}] is dead.", clientId, clientSourceIp);
                 } catch (IOException e) {
-                    s_logger.error("Error on VNC client", e);
+                    logger.error("Error on VNC client", e);
                 }
             }
 
@@ -156,7 +159,7 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
             session.getRemote().sendBytes(ByteBuffer.wrap(b, 0, readBytes));
             updateFrontEndActivityTime();
         } catch (WebSocketException | IOException e) {
-            s_logger.debug("Connection exception", e);
+            logger.error("VNC server connection exception.", e);
             return false;
         }
         return true;
@@ -174,20 +177,24 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
      *
      * Reference: https://github.com/rfbproto/rfbproto/blob/master/rfbproto.rst#7protocol-messages
      */
-    private void authenticateToVNCServer() throws IOException {
+    private void authenticateToVNCServer(String clientSourceIp) throws IOException {
         if (client.isVncOverWebSocketConnection()) {
+            logger.debug("Authentication skipped for client [{}] [IP: {}] to VNC server due to WebSocket protocol usage.", clientId, clientSourceIp);
             return;
         }
 
         if (!client.isVncOverNioSocket()) {
+            logger.debug("Authenticating client [{}] [IP: {}] to VNC server.", clientId, clientSourceIp);
             String ver = client.handshake();
             session.getRemote().sendBytes(ByteBuffer.wrap(ver.getBytes(), 0, ver.length()));
 
             byte[] b = client.authenticateTunnel(getClientHostPassword());
             session.getRemote().sendBytes(ByteBuffer.wrap(b, 0, 4));
         } else {
+            logger.debug("Authenticating client [{}] [IP: {}] to VNC server through NIO Socket.", clientId, clientSourceIp);
             authenticateVNCServerThroughNioSocket();
         }
+        logger.debug("Client [{}] [IP: {}] has been authenticated successfully to VNC server.", clientId, clientSourceIp);
     }
 
     /**
@@ -231,9 +238,6 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
     protected void authenticateVNCServerThroughNioSocket() {
         handshakePhase();
         initialisationPhase();
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Authenticated successfully");
-        }
     }
 
     /**
@@ -262,7 +266,7 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
         try {
             session.getRemote().sendBytes(ByteBuffer.wrap(arr, 0, length));
         } catch (IOException e) {
-            s_logger.error("Error sending a message to the noVNC client", e);
+            logger.error("Error sending a message to the noVNC client", e);
         }
     }
 
@@ -284,26 +288,27 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
     private void connectClientToVNCServer(String tunnelUrl, String tunnelSession, String websocketUrl) {
         try {
             if (StringUtils.isNotBlank(websocketUrl)) {
-                s_logger.info(String.format("Connect to VNC over websocket URL: %s", websocketUrl));
+                logger.info(String.format("Connect to VNC over websocket URL: %s", websocketUrl));
                 ConsoleProxy.ensureRoute(NetUtils.extractHost(websocketUrl));
                 client.connectToWebSocket(websocketUrl, session);
-            } else if (tunnelUrl != null && !tunnelUrl.isEmpty() && tunnelSession != null
-                    && !tunnelSession.isEmpty()) {
+            } else if (StringUtils.isNotBlank(tunnelUrl) && StringUtils.isNotBlank(tunnelSession)) {
                 URI uri = new URI(tunnelUrl);
-                s_logger.info(String.format("Connect to VNC server via tunnel. url: %s, session: %s",
+                logger.info(String.format("Connect to VNC server via tunnel. url: %s, session: %s",
                         tunnelUrl, tunnelSession));
 
                 ConsoleProxy.ensureRoute(uri.getHost());
                 client.connectTo(uri.getHost(), uri.getPort(), uri.getPath() + "?" + uri.getQuery(),
                         tunnelSession, "https".equalsIgnoreCase(uri.getScheme()));
             } else {
-                s_logger.info(String.format("Connect to VNC server directly. host: %s, port: %s",
+                logger.info(String.format("Connect to VNC server directly. host: %s, port: %s",
                         getClientHostAddress(), getClientHostPort()));
                 ConsoleProxy.ensureRoute(getClientHostAddress());
                 client.connectTo(getClientHostAddress(), getClientHostPort());
             }
+
+            logger.info("Connection to VNC server has been established successfully.");
         } catch (Throwable e) {
-            s_logger.error("Unexpected exception", e);
+            logger.error("Unexpected exception while connecting to VNC server.", e);
         }
     }
 
@@ -368,6 +373,7 @@ public class ConsoleProxyNoVncClient implements ConsoleProxyClient {
     }
 
     public void updateFrontEndActivityTime() {
+        logger.trace("Updating last front end activity time.");
         lastFrontEndActivityTime = System.currentTimeMillis();
     }
 
