@@ -17,7 +17,8 @@
 package com.cloud.consoleproxy;
 
 import org.apache.commons.codec.binary.Base64;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
@@ -26,7 +27,7 @@ import com.cloud.utils.crypt.AeadBase64Encryptor;
 import com.cloud.utils.crypt.Base64Encryptor;
 
 public class ConsoleProxyPasswordBasedEncryptor {
-    private static final Logger s_logger = Logger.getLogger(ConsoleProxyPasswordBasedEncryptor.class);
+    protected Logger logger = LogManager.getLogger(getClass());
 
     private Gson gson;
 
