@@ -16,25 +16,26 @@
 # under the License.
 """ P1 tests for memory resource limits
 """
+from marvin.cloudstackTestCase import cloudstackTestCase
+from marvin.codes import ERROR_NO_HOST_FOR_MIGRATION
+from marvin.lib.base import (
+    Account,
+    ServiceOffering,
+    VirtualMachine,
+    Resources,
+    Domain
+)
+from marvin.lib.common import (get_domain,
+                               get_zone,
+                               get_template,
+                               wait_for_cleanup,
+                               findSuitableHostForMigration,
+                               get_resource_type
+                               )
+from marvin.lib.utils import cleanup_resources
 # Import Local Modules
 from nose.plugins.attrib import attr
-from marvin.cloudstackTestCase import cloudstackTestCase, unittest
-from marvin.lib.base import (
-                                        Account,
-                                        ServiceOffering,
-                                        VirtualMachine,
-                                        Resources,
-                                        Domain
-                                        )
-from marvin.lib.common import (get_domain,
-                                        get_zone,
-                                        get_template,
-                                        wait_for_cleanup,
-                                        findSuitableHostForMigration,
-                                        get_resource_type
-                                        )
-from marvin.lib.utils import cleanup_resources
-from marvin.codes import ERROR_NO_HOST_FOR_MIGRATION
+
 
 class Services:
     """Test memory resource limit services
@@ -42,50 +43,51 @@ class Services:
 
     def __init__(self):
         self.services = {
-                        "account": {
-                                "email": "test@test.com",
-                                "firstname": "Test",
-                                "lastname": "User",
-                                "username": "resource",
-                                # Random characters are appended for unique
-                                # username
-                                "password": "password",
-                         },
-                         "service_offering": {
-                                "name": "Tiny Instance",
-                                "displaytext": "Tiny Instance",
-                                "cpunumber": 1,
-                                "cpuspeed": 100,    # in MHz
-                                "memory": 2048,    # In MBs
-                        },
-                        "virtual_machine": {
-                                "displayname": "TestVM",
-                                "username": "root",
-                                "password": "password",
-                                "ssh_port": 22,
-                                "hypervisor": 'KVM',
-                                "privateport": 22,
-                                "publicport": 22,
-                                "protocol": 'TCP',
-                                },
-                         "network": {
-                                "name": "Test Network",
-                                "displaytext": "Test Network",
-                                "netmask": '255.255.255.0'
-                                },
-                         "project": {
-                                "name": "Project",
-                                "displaytext": "Test project",
-                                },
-                         "domain": {
-                                "name": "Domain",
-                                },
-                        "ostype": 'CentOS 5.3 (64-bit)',
-                        "sleep": 60,
-                        "timeout": 10,
-                        "mode": 'advanced',
-                        # Networking mode: Advanced, Basic
-                    }
+            "account": {
+                "email": "test@test.com",
+                "firstname": "Test",
+                "lastname": "User",
+                "username": "resource",
+                # Random characters are appended for unique
+                # username
+                "password": "password",
+            },
+            "service_offering": {
+                "name": "Tiny Instance",
+                "displaytext": "Tiny Instance",
+                "cpunumber": 1,
+                "cpuspeed": 100,  # in MHz
+                "memory": 2048,  # In MBs
+            },
+            "virtual_machine": {
+                "displayname": "TestVM",
+                "username": "root",
+                "password": "password",
+                "ssh_port": 22,
+                "hypervisor": 'KVM',
+                "privateport": 22,
+                "publicport": 22,
+                "protocol": 'TCP',
+            },
+            "network": {
+                "name": "Test Network",
+                "displaytext": "Test Network",
+                "netmask": '255.255.255.0'
+            },
+            "project": {
+                "name": "Project",
+                "displaytext": "Test project",
+            },
+            "domain": {
+                "name": "Domain",
+            },
+            "ostype": 'CentOS 5.3 (64-bit)',
+            "sleep": 60,
+            "timeout": 10,
+            "mode": 'advanced',
+            # Networking mode: Advanced, Basic
+        }
+
 
 class TestMemoryLimits(cloudstackTestCase):
 
@@ -102,17 +104,17 @@ class TestMemoryLimits(cloudstackTestCase):
         cls.services["mode"] = cls.zone.networktype
 
         cls.template = get_template(
-                            cls.api_client,
-                            cls.zone.id,
-                            cls.services["ostype"]
-                            )
+            cls.api_client,
+            cls.zone.id,
+            cls.services["ostype"]
+        )
 
         cls.services["virtual_machine"]["zoneid"] = cls.zone.id
 
         cls.service_offering = ServiceOffering.create(
-                                            cls.api_client,
-                                            cls.services["service_offering"]
-                                            )
+            cls.api_client,
+            cls.services["service_offering"]
+        )
 
         cls._cleanup = [cls.service_offering, ]
         return
@@ -130,13 +132,13 @@ class TestMemoryLimits(cloudstackTestCase):
         self.apiclient = self.testClient.getApiClient()
         self.dbclient = self.testClient.getDbConnection()
         self.account = Account.create(
-                            self.apiclient,
-                            self.services["account"],
-                            admin=True
-                            )
+            self.apiclient,
+            self.services["account"],
+            admin=True
+        )
 
         self.debug("Creating an instance with service offering: %s" %
-                                                    self.service_offering.name)
+                   self.service_offering.name)
         self.vm = self.createInstance(service_off=self.service_offering)
 
         self.cleanup = [self.account, ]
@@ -153,20 +155,20 @@ class TestMemoryLimits(cloudstackTestCase):
     def createInstance(self, service_off, networks=None, api_client=None):
         """Creates an instance in account"""
         self.debug("Deploying an instance in account: %s" %
-                                                self.account.name)
+                   self.account.name)
 
         if api_client is None:
-	        api_client = self.apiclient
+            api_client = self.apiclient
 
         try:
             vm = VirtualMachine.create(
-                                api_client,
-                                self.services["virtual_machine"],
-                                templateid=self.template.id,
-                                accountid=self.account.name,
-                                domainid=self.account.domainid,
-                                networkids=networks,
-                                serviceofferingid=service_off.id)
+                api_client,
+                self.services["virtual_machine"],
+                templateid=self.template.id,
+                accountid=self.account.name,
+                domainid=self.account.domainid,
+                networkids=networks,
+                serviceofferingid=service_off.id)
             vms = VirtualMachine.list(api_client, id=vm.id, listall=True)
             self.assertIsInstance(vms,
                                   list,
@@ -177,7 +179,7 @@ class TestMemoryLimits(cloudstackTestCase):
         except Exception as e:
             self.fail("Failed to deploy an instance: %s" % e)
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="false")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="false")
     def test_01_stop_start_instance(self):
         """Test Deploy VM with specified RAM & verify the usage"""
 
@@ -229,7 +231,7 @@ class TestMemoryLimits(cloudstackTestCase):
                          "Resource count should be same after stopping the instance")
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="true")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="true")
     def test_02_migrate_instance(self):
         """Test Deploy VM with specified RAM & verify the usage"""
 
@@ -273,7 +275,7 @@ class TestMemoryLimits(cloudstackTestCase):
                          "Resource count should be same after stopping the instance")
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="false")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="false")
     def test_03_delete_instance(self):
         """Test Deploy VM with specified GB RAM & verify the usage"""
 
@@ -300,8 +302,8 @@ class TestMemoryLimits(cloudstackTestCase):
         except Exception as e:
             self.fail("Failed to delete instance: %s" % e)
 
-	    # Wait for expunge interval to cleanup Memory
-	    wait_for_cleanup(self.apiclient, ["expunge.delay", "expunge.interval"])
+            # Wait for expunge interval to cleanup Memory
+            wait_for_cleanup(self.apiclient, ["expunge.delay", "expunge.interval"])
 
         account_list = Account.list(self.apiclient, id=self.account.id)
         self.assertIsInstance(account_list,
@@ -309,10 +311,10 @@ class TestMemoryLimits(cloudstackTestCase):
                               "List Accounts should return a valid response"
                               )
         resource_count_after_delete = account_list[0].memorytotal
-        self.assertEqual(resource_count_after_delete, 0 , "Resource count for %s should be 0" % get_resource_type(resource_id=9))#RAM
+        self.assertEqual(resource_count_after_delete, 0, "Resource count for %s should be 0" % get_resource_type(resource_id=9))  # RAM
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="false")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="false")
     def test_04_deploy_multiple_vm(self):
         """Test Deploy multiple VM with specified RAM & verify the usage"""
 
@@ -335,7 +337,7 @@ class TestMemoryLimits(cloudstackTestCase):
                          "Resource count should match with the expected resource count")
 
         self.debug("Creating two instances with service offering: %s" %
-                                                    self.service_offering.name)
+                   self.service_offering.name)
         vm_1 = self.createInstance(service_off=self.service_offering)
         self.createInstance(service_off=self.service_offering)
 
@@ -346,7 +348,7 @@ class TestMemoryLimits(cloudstackTestCase):
                               )
         resource_count_new = account_list[0].memorytotal
 
-        expected_resource_count = int(self.services["service_offering"]["memory"]) * 3 #Total 3 VMs
+        expected_resource_count = int(self.services["service_offering"]["memory"]) * 3  # Total 3 VMs
 
         self.assertEqual(resource_count_new, expected_resource_count,
                          "Resource count should match with the expected resource count")
@@ -370,6 +372,7 @@ class TestMemoryLimits(cloudstackTestCase):
                          "Resource count should match with the expected resource count")
         return
 
+
 class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
 
     @classmethod
@@ -384,17 +387,17 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         cls.services["mode"] = cls.zone.networktype
 
         cls.template = get_template(
-                            cls.api_client,
-                            cls.zone.id,
-                            cls.services["ostype"]
-                            )
+            cls.api_client,
+            cls.zone.id,
+            cls.services["ostype"]
+        )
 
         cls.services["virtual_machine"]["zoneid"] = cls.zone.id
 
         cls.service_offering = ServiceOffering.create(
-                                            cls.api_client,
-                                            cls.services["service_offering"]
-                                            )
+            cls.api_client,
+            cls.services["service_offering"]
+        )
 
         cls._cleanup = [cls.service_offering, ]
         return
@@ -426,20 +429,20 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
     def createInstance(self, service_off, networks=None, api_client=None):
         """Creates an instance in account"""
         self.debug("Deploying an instance in account: %s" %
-                                                self.account.name)
+                   self.account.name)
 
         if api_client is None:
-	        api_client = self.apiclient
+            api_client = self.apiclient
 
         try:
             vm = VirtualMachine.create(
-                                api_client,
-                                self.services["virtual_machine"],
-                                templateid=self.template.id,
-                                accountid=self.account.name,
-                                domainid=self.account.domainid,
-                                networkids=networks,
-                                serviceofferingid=service_off.id)
+                api_client,
+                self.services["virtual_machine"],
+                templateid=self.template.id,
+                accountid=self.account.name,
+                domainid=self.account.domainid,
+                networkids=networks,
+                serviceofferingid=service_off.id)
             vms = VirtualMachine.list(api_client, id=vm.id, listall=True)
             self.assertIsInstance(vms,
                                   list,
@@ -458,11 +461,11 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
                                             parentdomainid=self.domain.id)
 
         self.child_do_admin_1 = Account.create(
-                                self.apiclient,
-                                self.services["account"],
-                                admin=True,
-                                domainid=self.child_domain_1.id
-                                )
+            self.apiclient,
+            self.services["account"],
+            admin=True,
+            domainid=self.child_domain_1.id
+        )
         # Cleanup the resources created at end of test
         self.cleanup.append(self.child_do_admin_1)
         self.cleanup.append(self.child_domain_1)
@@ -470,21 +473,21 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         self.debug("Creating a domain under: %s" % self.domain.name)
 
         self.child_domain_2 = Domain.create(self.apiclient,
-                                              services=self.services["domain"],
-                                              parentdomainid=self.domain.id)
+                                            services=self.services["domain"],
+                                            parentdomainid=self.domain.id)
 
         self.child_do_admin_2 = Account.create(
-                                    self.apiclient,
-                                    self.services["account"],
-                                    admin=True,
-                                    domainid=self.child_domain_2.id)
+            self.apiclient,
+            self.services["account"],
+            admin=True,
+            domainid=self.child_domain_2.id)
         # Cleanup the resources created at end of test
         self.cleanup.append(self.child_do_admin_2)
         self.cleanup.append(self.child_domain_2)
 
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="false")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="false")
     def test_01_stop_start_instance(self):
         """Test Deploy VM with 5 GB memory & verify the usage"""
 
@@ -499,16 +502,16 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         users = {self.child_domain_1: self.child_do_admin_1,
                  self.child_domain_2: self.child_do_admin_2
                  }
-        for domain, admin in users.items():
+        for domain, admin in list(users.items()):
             self.account = admin
             self.domain = domain
 
             api_client = self.testClient.getUserApiClient(
-                             UserName=self.account.name,
-                             DomainName=self.account.domain)
+                UserName=self.account.name,
+                DomainName=self.account.domain)
 
             self.debug("Creating an instance with service offering: %s" %
-                                                    self.service_offering.name)
+                       self.service_offering.name)
             vm = self.createInstance(service_off=self.service_offering, api_client=api_client)
 
             account_list = Account.list(self.apiclient, id=self.account.id)
@@ -521,7 +524,7 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             expected_resource_count = int(self.services["service_offering"]["memory"])
 
             self.assertEqual(resource_count, expected_resource_count,
-                         "Initial resource count should match with the expected resource count")
+                             "Initial resource count should match with the expected resource count")
 
             self.debug("Stopping instance: %s" % vm.name)
             try:
@@ -537,7 +540,7 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             resource_count_after_stop = account_list[0].memorytotal
 
             self.assertEqual(resource_count, resource_count_after_stop,
-                         "Resource count should be same after stopping the instance")
+                             "Resource count should be same after stopping the instance")
 
             self.debug("Starting instance: %s" % vm.name)
             try:
@@ -553,10 +556,10 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             resource_count_after_start = account_list[0].memorytotal
 
             self.assertEqual(resource_count_after_stop, resource_count_after_start,
-                         "Resource count should be same after starting the instance")
+                             "Resource count should be same after starting the instance")
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="true")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="true")
     def test_02_migrate_instance(self):
         """Test Deploy VM with specified memory & verify the usage"""
 
@@ -574,16 +577,16 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         users = {self.child_domain_1: self.child_do_admin_1,
                  self.child_domain_2: self.child_do_admin_2
                  }
-        for domain, admin in users.items():
+        for domain, admin in list(users.items()):
             self.account = admin
             self.domain = domain
 
             api_client = self.testClient.getUserApiClient(
-                             UserName=self.account.name,
-                             DomainName=self.account.domain)
+                UserName=self.account.name,
+                DomainName=self.account.domain)
 
             self.debug("Creating an instance with service offering: %s" %
-                                                    self.service_offering.name)
+                       self.service_offering.name)
             vm = self.createInstance(service_off=self.service_offering, api_client=api_client)
 
             account_list = Account.list(self.apiclient, id=self.account.id)
@@ -596,13 +599,13 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             expected_resource_count = int(self.services["service_offering"]["memory"])
 
             self.assertEqual(resource_count, expected_resource_count,
-                         "Initial resource count should with the expected resource count")
+                             "Initial resource count should with the expected resource count")
 
             host = findSuitableHostForMigration(self.apiclient, vm.id)
             if host is None:
                 self.skipTest(ERROR_NO_HOST_FOR_MIGRATION)
             self.debug("Migrating instance: %s to host: %s" %
-                                                        (vm.name, host.name))
+                       (vm.name, host.name))
             try:
                 vm.migrate(self.apiclient, host.id)
             except Exception as e:
@@ -616,10 +619,10 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             resource_count_after_migrate = account_list[0].memorytotal
 
             self.assertEqual(resource_count, resource_count_after_migrate,
-                         "Resource count should be same after starting the instance")
+                             "Resource count should be same after starting the instance")
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"], required_hardware="false")
+    @attr(tags=["advanced", "advancedns", "simulator"], required_hardware="false")
     def test_03_delete_instance(self):
         """Test Deploy VM with specified RAM & verify the usage"""
 
@@ -634,16 +637,16 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         users = {self.child_domain_1: self.child_do_admin_1,
                  self.child_domain_2: self.child_do_admin_2
                  }
-        for domain, admin in users.items():
+        for domain, admin in list(users.items()):
             self.account = admin
             self.domain = domain
 
             api_client = self.testClient.getUserApiClient(
-                             UserName=self.account.name,
-                             DomainName=self.account.domain)
+                UserName=self.account.name,
+                DomainName=self.account.domain)
 
             self.debug("Creating an instance with service offering: %s" %
-                                                    self.service_offering.name)
+                       self.service_offering.name)
             vm = self.createInstance(service_off=self.service_offering, api_client=api_client)
 
             account_list = Account.list(self.apiclient, id=self.account.id)
@@ -656,7 +659,7 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             expected_resource_count = int(self.services["service_offering"]["memory"])
 
             self.assertEqual(resource_count, expected_resource_count,
-                         "Initial resource count should match with the expected resource count")
+                             "Initial resource count should match with the expected resource count")
 
             self.debug("Destroying instance: %s" % vm.name)
             try:
@@ -670,14 +673,14 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
                                   "List Accounts should return a valid response"
                                   )
             resource_count = account_list[0].memorytotal
-            self.assertEqual(resource_count, 0 , "Resource count for %s should be 0" % get_resource_type(resource_id=9))#RAM
+            self.assertEqual(resource_count, 0, "Resource count for %s should be 0" % get_resource_type(resource_id=9))  # RAM
         return
 
-    @attr(tags=["advanced", "advancedns","simulator"])
+    @attr(tags=["advanced", "advancedns", "simulator"])
     @attr(configuration='max.account.memory')
     def test_04_deploy_multiple_vm(self):
         """Test Deploy multiple VM with 2 GB memory & verify the usage"""
-	    #keep the configuration value - max.account.memory = 8192 (maximum 4 instances per account with 2 GB RAM)
+        # keep the configuration value - max.account.memory = 8192 (maximum 4 instances per account with 2 GB RAM)
 
         # Validate the following
         # 1. Create compute offering with 2 GB RAM
@@ -687,9 +690,9 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
 
         self.debug("Creating service offering with 2 GB RAM")
         self.service_offering = ServiceOffering.create(
-                                            self.apiclient,
-                                            self.services["service_offering"]
-                                            )
+            self.apiclient,
+            self.services["service_offering"]
+        )
         # Adding to cleanup list after execution
         self.cleanup.append(self.service_offering)
 
@@ -698,25 +701,25 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
         users = {self.child_domain_1: self.child_do_admin_1,
                  self.child_domain_2: self.child_do_admin_2
                  }
-        for domain, admin in users.items():
+        for domain, admin in list(users.items()):
             self.account = admin
             self.domain = domain
 
             memory_account_gc = Resources.list(self.apiclient,
-                                resourcetype = 9, #Memory
-                                account = self.account.name,
-                                domainid = self.domain.id
-                                )
+                                               resourcetype=9,  # Memory
+                                               account=self.account.name,
+                                               domainid=self.domain.id
+                                               )
 
             if memory_account_gc[0].max != 8192:
                 self.skipTest("This test case requires configuration value max.account.memory to be 8192")
 
-	        api_client = self.testClient.getUserApiClient(
-                             UserName=self.account.name,
-                             DomainName=self.account.domain)
+                api_client = self.testClient.getUserApiClient(
+                    UserName=self.account.name,
+                    DomainName=self.account.domain)
 
             self.debug("Creating an instance with service offering: %s" %
-                                                    self.service_offering.name)
+                       self.service_offering.name)
             vm_1 = self.createInstance(service_off=self.service_offering, api_client=api_client)
             vm_2 = self.createInstance(service_off=self.service_offering, api_client=api_client)
             self.createInstance(service_off=self.service_offering, api_client=api_client)
@@ -733,10 +736,10 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
                                   )
             resource_count = account_list[0].memorytotal
 
-            expected_resource_count = int(self.services["service_offering"]["memory"]) * 4 #Total 4 vms
+            expected_resource_count = int(self.services["service_offering"]["memory"]) * 4  # Total 4 vms
 
             self.assertEqual(resource_count, expected_resource_count,
-                         "Initial resource count should with the expected resource count")
+                             "Initial resource count should with the expected resource count")
 
             self.debug("Destroying instance: %s" % vm_1.name)
             try:
@@ -754,7 +757,7 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
             expected_resource_count -= int(self.services["service_offering"]["memory"])
 
             self.assertEqual(resource_count_after_delete, expected_resource_count,
-                         "Resource count should match with the expected resource count")
+                             "Resource count should match with the expected resource count")
 
             host = findSuitableHostForMigration(self.apiclient, vm_2.id)
             if host is None:
@@ -775,5 +778,5 @@ class TestDomainMemoryLimitsConfiguration(cloudstackTestCase):
 
             self.debug(resource_count_after_migrate)
             self.assertEqual(resource_count_after_delete, resource_count_after_migrate,
-                         "Resource count should be same after migrating the instance")
+                             "Resource count should be same after migrating the instance")
         return
