@@ -22,7 +22,8 @@ from marvin.cloudstackTestCase import cloudstackTestCase
 from marvin.cloudstackAPI import (stopRouter,
                                   restartNetwork,
                                   startRouter,
-                                  rebootRouter)
+                                  rebootRouter,
+                                  getRouterHealthCheckResults)
 from marvin.lib.utils import (cleanup_resources,
                               get_process_status,
                               get_host_credentials)
@@ -303,7 +304,81 @@ class TestRouterServices(cloudstackTestCase):
             "Check haproxy service is running or not"
         )
         self.debug("Haproxy process status: %s" % res)
-        return
+
+        routers = list_routers(
+            self.apiclient,
+            account=self.account.name,
+            domainid=self.account.domainid,
+            fetchhealthcheckresults=True
+        )
+
+        self.assertEqual(isinstance(routers, list), True,
+            "Check for list routers response return valid data"
+        )
+        self.assertNotEqual(
+            len(routers), 0,
+            "Check list router response"
+        )
+
+        router = routers[0]
+        self.info("Router ID: %s & Router state: %s" % (
+            router.id, router.state
+        ))
+
+        self.assertEqual(isinstance(router.healthcheckresults, list), True,
+            "Router response should contain it's health check result as list"
+        )
+
+        cmd = getRouterHealthCheckResults.getRouterHealthCheckResultsCmd()
+        cmd.routerid = router.id
+        cmd.performfreshchecks = True # Perform fresh checks as a newly created router may not have results
+        healthData = self.apiclient.getRouterHealthCheckResults(cmd)
+        self.info("Router ID: %s & Router state: %s" % (
+            router.id, router.state
+        ))
+
+        self.assertEqual(router.id, healthData.routerid,
+            "Router response should contain it's health check result so id should match"
+        )
+        self.assertEqual(isinstance(healthData.healthchecks, list), True,
+            "Router response should contain it's health check result as list"
+        )
+
+        self.verifyCheckTypes(healthData.healthchecks)
+        self.verifyCheckNames(healthData.healthchecks)
+        self.verifyCheckResults(healthData.healthchecks)
+
+    def verifyCheckTypes(self, healthChecks):
+        for checkType in ["basic", "advanced"]:
+            foundType = False
+            for check in healthChecks:
+                if check.checktype == checkType:
+                    foundType = True
+                    break
+            self.assertTrue(foundType,
+                "Router should contain health check results info for type: " + checkType
+            )
+
+    def verifyCheckNames(self, healthChecks):
+        for checkName in ["dns_check.py", "dhcp_check.py", "haproxy_check.py", "disk_space_check.py", "iptables_check.py", "gateways_check.py", "router_version_check.py"]:
+            foundCheck = False
+            for check in healthChecks:
+                if check.checkname == checkName:
+                    foundCheck = True
+                    break
+            self.assertTrue(foundCheck,
+                "Router should contain health check results info for check name: " + checkName
+            )
+
+    def verifyCheckResults(self, healthChecks):
+        failedCheck = 0
+        for check in healthChecks:
+            if check.success:
+                print("check %s is good" % check.checkname)
+            else:
+                print("check %s failed due to %s" % (check.checkname, check.details))
+                failedCheck = failedCheck + 1
+        self.assertEquals(failedCheck, 0)
 
     @attr(
         tags=[
