@@ -23,8 +23,8 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.HttpURLConnection;
-import java.net.Inet6Address;
 import java.net.InetAddress;
+import java.net.Inet6Address;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URLEncoder;
@@ -57,7 +57,8 @@ import org.apache.http.NameValuePair;
 import org.apache.http.client.utils.URIBuilder;
 import org.apache.http.client.utils.URLEncodedUtils;
 import org.apache.http.message.BasicNameValuePair;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
@@ -71,7 +72,7 @@ import com.google.common.collect.ImmutableSet;
 
 public class UriUtils {
 
-    public static final Logger s_logger = Logger.getLogger(UriUtils.class.getName());
+    protected static Logger LOGGER = LogManager.getLogger(UriUtils.class);
 
     public static String formNfsUri(String host, String path) {
         try {
@@ -128,7 +129,7 @@ public class UriUtils {
     public static String getCifsUriParametersProblems(URI uri) {
         if (!UriUtils.hostAndPathPresent(uri)) {
             String errMsg = "cifs URI missing host and/or path. Make sure it's of the format cifs://hostname/path";
-            s_logger.warn(errMsg);
+            LOGGER.warn(errMsg);
             return errMsg;
         }
         return null;
@@ -146,10 +147,10 @@ public class UriUtils {
             String name = nvp.getName();
             if (name.equals("user")) {
                 foundUser = true;
-                s_logger.debug("foundUser is" + foundUser);
+                LOGGER.debug("foundUser is" + foundUser);
             } else if (name.equals("password")) {
                 foundPswd = true;
-                s_logger.debug("foundPswd is" + foundPswd);
+                LOGGER.debug("foundPswd is" + foundPswd);
             }
         }
         return (foundUser && foundPswd);
@@ -262,10 +263,17 @@ public class UriUtils {
     }
 
     public static Pair<String, Integer> validateUrl(String format, String url) throws IllegalArgumentException {
-        return validateUrl(format, url, false);
+        return validateUrl(format, url, false, false);
     }
 
-    public static Pair<String, Integer> validateUrl(String format, String url, boolean skipIpv6Check) throws IllegalArgumentException {
+    /**
+     * Verifies whether the provided URL is valid.
+     * @param skipHostCheck if false, this function will verify whether the provided URL is resolvable, if it is a legal address and if it does not use IPv6 (configured by `skipIpv6Check`). If any of these conditions are false, an exception will be thrown.
+     * @param skipIpv6Check if false, this function will verify whether the host uses IPv6 and, if it does, an exception will be thrown. This check is also skipped if `skipHostCheck` is true.
+     * @return a pair containing the host and the corresponding port.
+     * @throws IllegalArgumentException if the provided URL is invalid.
+     */
+    public static Pair<String, Integer> validateUrl(String format, String url, boolean skipHostCheck, boolean skipIpv6Check) throws IllegalArgumentException {
         try {
             URI uri = new URI(url);
             if ((uri.getScheme() == null) ||
@@ -281,16 +289,8 @@ public class UriUtils {
             }
 
             String host = uri.getHost();
-            try {
-                InetAddress hostAddr = InetAddress.getByName(host);
-                if (hostAddr.isAnyLocalAddress() || hostAddr.isLinkLocalAddress() || hostAddr.isLoopbackAddress() || hostAddr.isMulticastAddress()) {
-                    throw new IllegalArgumentException("Illegal host specified in url");
-                }
-                if (!skipIpv6Check && hostAddr instanceof Inet6Address) {
-                    throw new IllegalArgumentException("IPV6 addresses not supported (" + hostAddr.getHostAddress() + ")");
-                }
-            } catch (UnknownHostException uhe) {
-                throw new IllegalArgumentException("Unable to resolve " + host);
+            if (!skipHostCheck) {
+                checkHost(host, skipIpv6Check);
             }
 
             // verify format
@@ -304,6 +304,28 @@ public class UriUtils {
         }
     }
 
+    /**
+     * Verifies whether the provided host is valid. Throws an `IllegalArgumentException` if:
+     * <ul>
+     *     <li>The host is not resolvable;</li>
+     *     <li>The host address is illegal (any local, link local, loopback or multicast address);</li>
+     *     <li>The host uses IPv6. This check is skipped if `skipIv6Check` is set to true.</li>
+     * </ul>
+     */
+    private static void checkHost(String host, boolean skipIpv6Check) {
+        try {
+            InetAddress hostAddr = InetAddress.getByName(host);
+            if (hostAddr.isAnyLocalAddress() || hostAddr.isLinkLocalAddress() || hostAddr.isLoopbackAddress() || hostAddr.isMulticastAddress()) {
+                throw new IllegalArgumentException("Illegal host specified in URL.");
+            }
+            if (!skipIpv6Check && hostAddr instanceof Inet6Address) {
+                throw new IllegalArgumentException(String.format("IPv6 addresses are not supported (%s).", hostAddr.getHostAddress()));
+            }
+        } catch (UnknownHostException uhe) {
+            throw new IllegalArgumentException(String.format("Unable to resolve %s.", host));
+        }
+    }
+
     /**
      * Add element to priority list examining node attributes: priority (for urls) and type (for checksums)
      */
@@ -360,7 +382,7 @@ public class UriUtils {
             for (int i = 0; i < tagNames.length; i++) {
                 NodeList targetNodes = rootElement.getElementsByTagName(tagNames[i]);
                 if (targetNodes.getLength() <= 0) {
-                    s_logger.error("no " + tagNames[i] + " tag in XML response...");
+                    LOGGER.error("no " + tagNames[i] + " tag in XML response...");
                 } else {
                     List<Pair<String, Integer>> priorityList = new ArrayList<>();
                     for (int j = 0; j < targetNodes.getLength(); j++) {
@@ -372,7 +394,7 @@ public class UriUtils {
                 }
             }
         } catch (Exception ex) {
-            s_logger.error(ex);
+            LOGGER.error(ex);
         }
         return returnValues;
     }
@@ -388,7 +410,7 @@ public class UriUtils {
         try {
             status = httpClient.executeMethod(getMethod);
         } catch (IOException e) {
-            s_logger.error("Error retrieving urls form metalink: " + metalinkUrl);
+            LOGGER.error("Error retrieving urls form metalink: " + metalinkUrl);
             getMethod.releaseConnection();
             return null;
         }
@@ -402,7 +424,7 @@ public class UriUtils {
                 }
             }
         } catch (IOException e) {
-            s_logger.warn(e.getMessage());
+            LOGGER.warn(e.getMessage());
         } finally {
             getMethod.releaseConnection();
         }
@@ -479,20 +501,20 @@ public class UriUtils {
                 httpclient.getParams().setAuthenticationPreemptive(true);
                 Credentials defaultcreds = new UsernamePasswordCredentials(user, password);
                 httpclient.getState().setCredentials(new AuthScope(hostAndPort.first(), hostAndPort.second(), AuthScope.ANY_REALM), defaultcreds);
-                s_logger.info("Added username=" + user + ", password=" + password + "for host " + hostAndPort.first() + ":" + hostAndPort.second());
+                LOGGER.info("Added username=" + user + ", password=" + password + "for host " + hostAndPort.first() + ":" + hostAndPort.second());
             }
             // Execute the method.
             GetMethod method = new GetMethod(url);
             int statusCode = httpclient.executeMethod(method);
 
             if (statusCode != HttpStatus.SC_OK) {
-                s_logger.error("Failed to read from URL: " + url);
+                LOGGER.error("Failed to read from URL: " + url);
                 return null;
             }
 
             return method.getResponseBodyAsStream();
         } catch (Exception ex) {
-            s_logger.error("Failed to read from URL: " + url);
+            LOGGER.error("Failed to read from URL: " + url);
             return null;
         }
     }
