@@ -32,6 +32,7 @@ import java.nio.channels.SelectionKey;
 import java.nio.channels.Selector;
 import java.nio.channels.ServerSocketChannel;
 import java.nio.channels.SocketChannel;
+import java.security.GeneralSecurityException;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -41,6 +42,8 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.SynchronousQueue;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
@@ -48,8 +51,8 @@ import javax.net.ssl.SSLEngine;
 
 import org.apache.cloudstack.framework.ca.CAService;
 import org.apache.cloudstack.utils.security.SSLUtils;
-import org.apache.logging.log4j.Logger;
 import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 
 import com.cloud.utils.concurrency.NamedThreadFactory;
 import com.cloud.utils.exception.NioConnectionException;
@@ -60,6 +63,7 @@ import com.cloud.utils.exception.NioConnectionException;
  */
 public abstract class NioConnection implements Callable<Boolean> {
     protected Logger logger = LogManager.getLogger(getClass());
+    public static final String SERVER_BUSY_MESSAGE = "Server is busy.";
 
     protected Selector _selector;
     protected ExecutorService _threadExecutor;
@@ -74,6 +78,8 @@ public abstract class NioConnection implements Callable<Boolean> {
     protected ExecutorService _executor;
     protected ExecutorService _sslHandshakeExecutor;
     protected CAService caService;
+    protected Integer sslHandshakeTimeout = null;
+    private final int factoryMaxNewConnectionsCount;
 
     public NioConnection(final String name, final int port, final int workers, final HandlerFactory factory) {
         _name = name;
@@ -81,8 +87,18 @@ public abstract class NioConnection implements Callable<Boolean> {
         _selector = null;
         _port = port;
         _factory = factory;
-        _executor = new ThreadPoolExecutor(workers, 5 * workers, 1, TimeUnit.DAYS, new LinkedBlockingQueue<Runnable>(), new NamedThreadFactory(name + "-Handler"));
-        _sslHandshakeExecutor = Executors.newCachedThreadPool(new NamedThreadFactory(name + "-SSLHandshakeHandler"));
+        this.factoryMaxNewConnectionsCount = factory.getMaxConcurrentNewConnectionsCount();
+        _executor = new ThreadPoolExecutor(workers, 5 * workers, 1, TimeUnit.DAYS,
+                new LinkedBlockingQueue<>(5 * workers), new NamedThreadFactory(name + "-Handler"),
+                new ThreadPoolExecutor.AbortPolicy());
+        String sslHandshakeHandlerName = name + "-SSLHandshakeHandler";
+        if (factoryMaxNewConnectionsCount > 0) {
+            _sslHandshakeExecutor = new ThreadPoolExecutor(0, this.factoryMaxNewConnectionsCount, 30,
+                    TimeUnit.MINUTES, new SynchronousQueue<>(), new NamedThreadFactory(sslHandshakeHandlerName),
+                    new ThreadPoolExecutor.AbortPolicy());
+        } else {
+            _sslHandshakeExecutor = Executors.newCachedThreadPool(new NamedThreadFactory(sslHandshakeHandlerName));
+        }
     }
 
     public void setCAService(final CAService caService) {
@@ -95,8 +111,8 @@ public abstract class NioConnection implements Callable<Boolean> {
         try {
             init();
         } catch (final ConnectException e) {
-            logger.warn("Unable to connect to remote: is there a server running on port " + _port);
-            return;
+            logger.warn("Unable to connect to remote: is there a server running on port {}?", _port, e);
+            throw new NioConnectionException(e.getMessage(), e);
         } catch (final IOException e) {
             logger.error("Unable to initialize the threads.", e);
             throw new NioConnectionException(e.getMessage(), e);
@@ -113,6 +129,7 @@ public abstract class NioConnection implements Callable<Boolean> {
 
     public void stop() {
         _executor.shutdown();
+        _sslHandshakeExecutor.shutdown();
         _isRunning = false;
         if (_threadExecutor != null) {
             _futureTask.cancel(false);
@@ -190,9 +207,24 @@ public abstract class NioConnection implements Callable<Boolean> {
 
     abstract void unregisterLink(InetSocketAddress saddr);
 
+    protected boolean rejectConnectionIfBusy(final SocketChannel socketChannel) throws IOException {
+        if (factoryMaxNewConnectionsCount <= 0  || _factory.getNewConnectionsCount() < factoryMaxNewConnectionsCount) {
+            return false;
+        }
+        // Reject new connection if the server is busy
+        logger.warn("{} Rejecting new connection. {} active connections currently",
+                SERVER_BUSY_MESSAGE, factoryMaxNewConnectionsCount);
+        socketChannel.close();
+        _selector.wakeup();
+        return true;
+    }
+
     protected void accept(final SelectionKey key) throws IOException {
         final ServerSocketChannel serverSocketChannel = (ServerSocketChannel)key.channel();
         final SocketChannel socketChannel = serverSocketChannel.accept();
+        if (rejectConnectionIfBusy(socketChannel)) {
+            return;
+        }
         socketChannel.configureBlocking(false);
 
         final Socket socket = socketChannel.socket();
@@ -202,61 +234,54 @@ public abstract class NioConnection implements Callable<Boolean> {
             logger.trace("Connection accepted for " + socket);
         }
 
-        final SSLEngine sslEngine;
         try {
-            sslEngine = Link.initServerSSLEngine(caService, socketChannel.getRemoteAddress().toString());
-            sslEngine.setUseClientMode(false);
-            sslEngine.setEnabledProtocols(SSLUtils.getSupportedProtocols(sslEngine.getEnabledProtocols()));
             final NioConnection nioConnection = this;
-            _sslHandshakeExecutor.submit(new Runnable() {
-                @Override
-                public void run() {
-                    _selector.wakeup();
-                    try {
-                        sslEngine.beginHandshake();
-                        if (!Link.doHandshake(socketChannel, sslEngine)) {
-                            throw new IOException("SSL handshake timed out with " + socketChannel.getRemoteAddress());
-                        }
-                        if (logger.isTraceEnabled()) {
-                            logger.trace("SSL: Handshake done");
-                        }
-                        final InetSocketAddress saddr = (InetSocketAddress)socket.getRemoteSocketAddress();
-                        final Link link = new Link(saddr, nioConnection);
-                        link.setSSLEngine(sslEngine);
-                        link.setKey(socketChannel.register(key.selector(), SelectionKey.OP_READ, link));
-                        final Task task = _factory.create(Task.Type.CONNECT, link, null);
-                        registerLink(saddr, link);
-                        _executor.submit(task);
-                    } catch (IOException e) {
-                        if (logger.isTraceEnabled()) {
-                            logger.trace("Connection closed due to failure: " + e.getMessage());
-                        }
-                        closeAutoCloseable(socket, "accepting socket");
-                        closeAutoCloseable(socketChannel, "accepting socketChannel");
-                    } finally {
-                        _selector.wakeup();
+            _sslHandshakeExecutor.submit(() -> {
+                final InetSocketAddress socketAddress = (InetSocketAddress)socket.getRemoteSocketAddress();
+                _factory.registerNewConnection(socketAddress);
+                _selector.wakeup();
+                try {
+                    final SSLEngine sslEngine = Link.initServerSSLEngine(caService, socketChannel.getRemoteAddress().toString());
+                    sslEngine.setUseClientMode(false);
+                    sslEngine.setEnabledProtocols(SSLUtils.getSupportedProtocols(sslEngine.getEnabledProtocols()));
+                    sslEngine.beginHandshake();
+                    if (!Link.doHandshake(socketChannel, sslEngine, getSslHandshakeTimeout())) {
+                        throw new IOException("SSL handshake timed out with " + socketAddress);
                     }
+                    logger.trace("SSL: Handshake done");
+                    final Link link = new Link(socketAddress, nioConnection);
+                    link.setSSLEngine(sslEngine);
+                    link.setKey(socketChannel.register(key.selector(), SelectionKey.OP_READ, link));
+                    final Task task = _factory.create(Task.Type.CONNECT, link, null);
+                    registerLink(socketAddress, link);
+                    _executor.submit(task);
+                } catch (final GeneralSecurityException | IOException e) {
+                    _factory.unregisterNewConnection(socketAddress);
+                    logger.trace("Connection closed with {} due to failure: {}", socket.getRemoteSocketAddress(), e.getMessage());
+                    closeAutoCloseable(socket, "accepting socket");
+                    closeAutoCloseable(socketChannel, "accepting socketChannel");
+                } finally {
+                    _selector.wakeup();
                 }
             });
-        } catch (final Exception e) {
-            if (logger.isTraceEnabled()) {
-                logger.trace("Connection closed due to failure: " + e.getMessage());
-            }
-            closeAutoCloseable(socket, "accepting socket");
-            closeAutoCloseable(socketChannel, "accepting socketChannel");
+        } catch (final RejectedExecutionException e) {
+            logger.trace("{} Accept Task rejected: {}", socket.getRemoteSocketAddress(), e.getMessage());
+            closeAutoCloseable(socket, "Rejecting connection - accepting socket");
+            closeAutoCloseable(socketChannel, "Rejecting connection - accepting socketChannel");
         } finally {
             _selector.wakeup();
         }
     }
 
-    protected void terminate(final SelectionKey key) {
+    protected void terminate(final SelectionKey key, String msg) {
         final Link link = (Link)key.attachment();
         closeConnection(key);
         if (link != null) {
+            logger.trace("Will terminate connection due to: {}", msg);
             link.terminated();
             final Task task = _factory.create(Task.Type.DISCONNECT, link, null);
             unregisterLink(link.getSocketAddress());
-
+            _factory.unregisterNewConnection(link.getSocketAddress());
             try {
                 _executor.submit(task);
             } catch (final Exception e) {
@@ -288,7 +313,7 @@ public abstract class NioConnection implements Callable<Boolean> {
             }
         } catch (final Exception e) {
             logDebug(e, key, 1);
-            terminate(key);
+            terminate(key, e.getMessage());
         }
     }
 
@@ -413,11 +438,11 @@ public abstract class NioConnection implements Callable<Boolean> {
             try {
                 _executor.submit(task);
             } catch (final Exception e) {
-                logger.warn("Exception occurred when submitting the task", e);
+                logger.warn("Exception occurred when submitting the task for connect: {}", socket, e);
             }
         } catch (final IOException e) {
             logTrace(e, key, 2);
-            terminate(key);
+            terminate(key, e.getMessage());
         }
     }
 
@@ -444,7 +469,7 @@ public abstract class NioConnection implements Callable<Boolean> {
             }
         } catch (final Exception e) {
             logDebug(e, key, 3);
-            terminate(key);
+            terminate(key, e.getMessage());
         }
     }
 
@@ -491,7 +516,8 @@ public abstract class NioConnection implements Callable<Boolean> {
 
     /* Release the resource used by the instance */
     public void cleanUp() throws IOException {
-        if (_selector != null) {
+        if (_selector != null && _selector.isOpen()) {
+            _selector.wakeup();
             _selector.close();
         }
     }
@@ -513,4 +539,12 @@ public abstract class NioConnection implements Callable<Boolean> {
             this.att = att;
         }
     }
+
+    public Integer getSslHandshakeTimeout() {
+        return sslHandshakeTimeout;
+    }
+
+    public void setSslHandshakeTimeout(Integer sslHandshakeTimeout) {
+        this.sslHandshakeTimeout = sslHandshakeTimeout;
+    }
 }
